@@ -7,6 +7,11 @@
 #include "checkerDetector.hpp"
 
 #include <aliceVision/system/Logger.hpp>
+#include <aliceVision/image/conversion.hpp>
+#include <aliceVision/image/drawing.hpp>
+#include <aliceVision/image/Sampler.hpp>
+#include <aliceVision/image/filtering.hpp>
+#include <aliceVision/image/convolution.hpp>
 
 #include <OpenImageIO/imagebufalgo.h>
 
@@ -31,7 +36,7 @@ bool CheckerDetector::process(const image::Image<image::RGBColor>& source, bool
     image::Image<float> grayscale;
     image::ConvertPixelType(source, &grayscale);
 
-    const Vec2 center(grayscale.Width() / 2, grayscale.Height() / 2);
+    const Vec2 center(grayscale.width() / 2, grayscale.height() / 2);
 
     const double scales[] = {1.0, 0.75, 0.5, 0.25};
 
@@ -106,7 +111,7 @@ bool CheckerDetector::process(const image::Image<image::RGBColor>& source, bool
 
     ALICEVISION_LOG_INFO("[CheckerDetector] extracting checkerboards with " << _corners.size() << " corners");
 
-    buildCheckerboards(_boards, _corners, normalized);
+    buildCheckerboards(_boards, _corners);
 
     ALICEVISION_LOG_DEBUG("[CheckerDetector] built " << _boards.size() << " checkerboards");
 
@@ -150,19 +155,19 @@ bool CheckerDetector::process(const image::Image<image::RGBColor>& source, bool
 bool CheckerDetector::processLevel(std::vector<Vec2>& corners, const image::Image<float>& input, double scale) const
 {
     // Get resized size
-    const unsigned int w = input.Width();
-    const unsigned int h = input.Height();
+    const unsigned int w = input.width();
+    const unsigned int h = input.height();
     const unsigned int nw = static_cast<unsigned int>(floor(static_cast<float>(w) * scale));
     const unsigned int nh = static_cast<unsigned int>(floor(static_cast<float>(h) * scale));
 
     // Resize image
     image::Image<float> toUpdate = input;
     image::Image<float> rescaled(nw, nh);
-    const oiio::ImageSpec imageSpecResized(nw, nh, 1, oiio::TypeDesc::FLOAT);
-    const oiio::ImageSpec imageSpecOrigin(w, h, 1, oiio::TypeDesc::FLOAT);
-    const oiio::ImageBuf inBuf(imageSpecOrigin, toUpdate.data());
-    oiio::ImageBuf outBuf(imageSpecResized, rescaled.data());
-    oiio::ImageBufAlgo::resize(outBuf, inBuf);
+    const OIIO::ImageSpec imageSpecResized(nw, nh, 1, OIIO::TypeDesc::FLOAT);
+    const OIIO::ImageSpec imageSpecOrigin(w, h, 1, OIIO::TypeDesc::FLOAT);
+    const OIIO::ImageBuf inBuf(imageSpecOrigin, toUpdate.data());
+    OIIO::ImageBuf outBuf(imageSpecResized, rescaled.data());
+    OIIO::ImageBufAlgo::resize(outBuf, inBuf);
 
     // Normalize image between 0 and 1
     image::Image<float> normalized;
@@ -249,10 +254,10 @@ void CheckerDetector::normalizeImage(image::Image<float>& output, const image::I
     float min = 0.0f, max = 0.0f;
     getMinMax(min, max, input);
 
-    output.resize(input.Width(), input.Height());
-    for (int y = 0; y < output.Height(); ++y)
+    output.resize(input.width(), input.height());
+    for (int y = 0; y < output.height(); ++y)
     {
-        for (int x = 0; x < output.Width(); ++x)
+        for (int x = 0; x < output.width(); ++x)
         {
             output(y, x) = (input(y, x) - min) / (max - min);
         }
@@ -262,23 +267,23 @@ void CheckerDetector::normalizeImage(image::Image<float>& output, const image::I
 void CheckerDetector::computeHessianResponse(image::Image<float>& output, const image::Image<float>& input) const
 {
     image::Image<float> smoothed;
-    image::ImageGaussianFilter(input, 1.5, smoothed, 2);
+    image::imageGaussianFilter(input, 1.5, smoothed, 2);
 
     // First order derivatives
     image::Image<float> gx, gy;
-    ImageXDerivative(smoothed, gx, true);
-    ImageYDerivative(smoothed, gy, true);
+    imageXDerivative(smoothed, gx, true);
+    imageYDerivative(smoothed, gy, true);
 
     // Second order derivatives
     image::Image<float> gxx, gxy, gyy;
-    ImageXDerivative(gx, gxx, true);
-    ImageXDerivative(gy, gxy, true);
-    ImageYDerivative(gy, gyy, true);
+    imageXDerivative(gx, gxx, true);
+    imageXDerivative(gy, gxy, true);
+    imageYDerivative(gy, gyy, true);
 
-    output.resize(input.Width(), input.Height());
-    for (int y = 0; y < input.Height(); ++y)
+    output.resize(input.width(), input.height());
+    for (int y = 0; y < input.height(); ++y)
     {
-        for (int x = 0; x < input.Width(); ++x)
+        for (int x = 0; x < input.width(); ++x)
         {
             output(y, x) = std::abs(gxx(y, x) * gyy(y, x) - 2.0 * gxy(y, x));
         }
@@ -294,10 +299,10 @@ void CheckerDetector::extractCorners(std::vector<Vec2>& rawCorners, const image:
     const int radius = 7;
 
     // Find peaks (local maxima) of the Hessian response
-    image::Image<float> output(hessianResponse.Width(), hessianResponse.Height(), true, 0.0f);
-    for (int i = radius; i < hessianResponse.Height() - radius; ++i)
+    image::Image<float> output(hessianResponse.width(), hessianResponse.height(), true, 0.0f);
+    for (int i = radius; i < hessianResponse.height() - radius; ++i)
     {
-        for (int j = radius; j < hessianResponse.Width() - radius; ++j)
+        for (int j = radius; j < hessianResponse.width() - radius; ++j)
         {
             bool isMaximal = true;
             const float val = hessianResponse(i, j);
@@ -330,9 +335,9 @@ void CheckerDetector::getMinMax(float& min, float& max, const image::Image<float
 {
     min = std::numeric_limits<float>::max();
     max = std::numeric_limits<float>::min();
-    for (int y = 0; y < input.Height(); ++y)
+    for (int y = 0; y < input.height(); ++y)
     {
-        for (int x = 0; x < input.Width(); ++x)
+        for (int x = 0; x < input.width(); ++x)
         {
             min = std::min(min, input(y, x));
             max = std::max(max, input(y, x));
@@ -343,8 +348,8 @@ void CheckerDetector::getMinMax(float& min, float& max, const image::Image<float
 void CheckerDetector::refineCorners(std::vector<Vec2>& refinedCorners, const std::vector<Vec2>& rawCorners, const image::Image<float>& input) const
 {
     image::Image<float> gx, gy;
-    ImageXDerivative(input, gx, true);
-    ImageYDerivative(input, gy, true);
+    imageXDerivative(input, gx, true);
+    imageYDerivative(input, gy, true);
 
     const int radius = 5;
 
@@ -354,9 +359,9 @@ void CheckerDetector::refineCorners(std::vector<Vec2>& refinedCorners, const std
             continue;
         if (pt.y() < radius)
             continue;
-        if (pt.x() >= gx.Width() - radius)
+        if (pt.x() >= gx.width() - radius)
             continue;
-        if (pt.y() >= gx.Height() - radius)
+        if (pt.y() >= gx.height() - radius)
             continue;
 
         Eigen::Matrix2d A = Eigen::Matrix2d::Zero();
@@ -429,7 +434,7 @@ void CheckerDetector::fitCorners(std::vector<CheckerBoardCorner>& refinedCorners
     kernel /= norm;
 
     image::Image<float> filtered;
-    image::ImageConvolution(input, kernel, filtered);
+    image::imageConvolution(input, kernel, filtered);
 
     Eigen::MatrixXd AtA(6, 6);
     Eigen::Vector<double, 6> Atb;
@@ -441,9 +446,6 @@ void CheckerDetector::fitCorners(std::vector<CheckerBoardCorner>& refinedCorners
         Vec2 corner = sc.center;
         bool isValid = true;
 
-        const double cx = corner(0);
-        const double cy = corner(1);
-
         for (int iter = 0; iter < 20; ++iter)
         {
             AtA.fill(0);
@@ -484,7 +486,6 @@ void CheckerDetector::fitCorners(std::vector<CheckerBoardCorner>& refinedCorners
             const double a3 = x(2);
             const double a4 = x(3);
             const double a5 = x(4);
-            const double a6 = x(5);
 
             const double determinantH = 4.0 * a1 * a3 - a2 * a2;
             if (std::abs(determinantH) < 1e-6)
@@ -515,7 +516,7 @@ void CheckerDetector::fitCorners(std::vector<CheckerBoardCorner>& refinedCorners
                 break;
             }
 
-            if (corner(0) < radius || corner(0) >= input.Width() - radius || corner(1) < radius || corner(1) >= input.Height() - radius)
+            if (corner(0) < radius || corner(0) >= input.width() - radius || corner(1) < radius || corner(1) >= input.height() - radius)
             {
                 isValid = false;
                 break;
@@ -533,9 +534,6 @@ void CheckerDetector::fitCorners(std::vector<CheckerBoardCorner>& refinedCorners
 
     for (CheckerBoardCorner& corner : refinedCorners)
     {
-        const double cx = corner.center(0);
-        const double cy = corner.center(1);
-
         AtA.fill(0);
         Atb.fill(0);
 
@@ -563,9 +561,6 @@ void CheckerDetector::fitCorners(std::vector<CheckerBoardCorner>& refinedCorners
         }
 
         Eigen::Vector<double, 6> x = AtA.inverse() * Atb;
-        const double c1 = x(0);
-        const double c2 = x(1);
-        const double c3 = x(2);
         const double c4 = x(3);
         const double c5 = x(4);
         const double c6 = x(5);
@@ -596,7 +591,6 @@ IndexT CheckerDetector::findClosestCorner(const Vec2& center, const Vec2& dir, c
 {
     IndexT ret = UndefinedIndexT;
     double min = std::numeric_limits<double>::max();
-    double angle = 0.0;
 
     for (IndexT cid = 0; cid < refinedCorners.size(); ++cid)
     {
@@ -617,7 +611,6 @@ IndexT CheckerDetector::findClosestCorner(const Vec2& center, const Vec2& dir, c
         {
             min = dist;
             ret = cid;
-            angle = std::abs(std::atan2(diff.y(), diff.x()) - std::atan2(dir.y(), dir.x()));
         }
     }
 
@@ -1027,16 +1020,11 @@ bool CheckerDetector::growIteration(CheckerBoard& board, const std::vector<Check
     return false;
 }
 
-void CheckerDetector::buildCheckerboards(std::vector<CheckerBoard>& boards,
-                                         const std::vector<CheckerBoardCorner>& refinedCorners,
-                                         const image::Image<float>& input) const
+void CheckerDetector::buildCheckerboards(std::vector<CheckerBoard>& boards, const std::vector<CheckerBoardCorner>& refinedCorners) const
 {
-    double minE = std::numeric_limits<double>::max();
-
     std::vector<bool> used(refinedCorners.size(), false);
     for (IndexT cid = 0; cid < refinedCorners.size(); ++cid)
     {
-        const CheckerBoardCorner& seed = refinedCorners[cid];
         if (used[cid])
             continue;
 
@@ -1108,8 +1096,8 @@ void CheckerDetector::drawCheckerBoard(image::Image<image::RGBColor>& img, bool
 {
     for (auto c : _corners)
     {
-        image::DrawLine(c.center.x() + 2.0, c.center.y(), c.center.x() - 2.0, c.center.y(), image::RGBColor(255, 255, 0), &img);
-        image::DrawLine(c.center.x(), c.center.y() + 2.0, c.center.x(), c.center.y() - 2.0, image::RGBColor(255, 255, 0), &img);
+        image::drawLine(c.center.x() + 2.0, c.center.y(), c.center.x() - 2.0, c.center.y(), image::RGBColor(255, 255, 0), &img);
+        image::drawLine(c.center.x(), c.center.y() + 2.0, c.center.x(), c.center.y() - 2.0, image::RGBColor(255, 255, 0), &img);
     }
 
     std::vector<image::RGBColor> colors;
@@ -1151,7 +1139,7 @@ void CheckerDetector::drawCheckerBoard(image::Image<image::RGBColor>& img, bool
                 const CheckerBoardCorner& c1 = _corners[p1];
                 const CheckerBoardCorner& c2 = _corners[p2];
 
-                image::DrawLineThickness(c1.center.x(), c1.center.y(), c2.center.x(), c2.center.y(), color, 5, &img);
+                image::drawLineThickness(c1.center.x(), c1.center.y(), c2.center.x(), c2.center.y(), color, 5, &img);
             }
         }
     };
@@ -1372,7 +1360,7 @@ bool CheckerDetector::mergeCheckerboards()
         {
             const CheckerBoard baseBoard = checkers[idRef].first;
 
-            // Build dictionnary of corners for faster lookup
+            // Build dictionary of corners for faster lookup
             std::unordered_map<IndexT, Vec2i> baseCorners;
             for (int i = 0; i < baseBoard.rows(); ++i)
             {
@@ -1446,11 +1434,44 @@ bool CheckerDetector::removeInvalidCheckerboards()
 
         const Vec2i delta = horizontal ? Vec2i{1, 0} : Vec2i{0, 1};
 
+        /**
+         * Check squares for not too important angles
+         */
+        for (int i = 0; i < board.rows() - 1; ++i)
+        {
+            for (int j = 0; j < board.cols() - 1; j++)
+            {
+                const IndexT c00 = board(i, j);
+                const IndexT c01 = board(i, j + 1);
+                const IndexT c10 = board(i + 1, j);
+                const IndexT c11 = board(i + 1, j + 1);
+
+                if (c00 == UndefinedIndexT || c01 == UndefinedIndexT || c10 == UndefinedIndexT || c11 == UndefinedIndexT)
+                {
+                    continue;
+                }
+
+                Vec2 dir1 = (_corners[c01].center - _corners[c00].center).normalized();
+                Vec2 dir2 = (_corners[c10].center - _corners[c00].center).normalized();
+
+                double a1 = std::acos(dir1.dot(dir2));
+                double a2 = std::acos(dir1.dot(dir2));
+
+                if (a1 < M_PI_4 || a1 > 3.0 * M_PI_4)
+                {
+                    return true;
+                }
+
+                if (a2 < M_PI_4 || a2 > 3.0 * M_PI_4)
+                {
+                    return true;
+                }
+            }
+        }
+
         for (int i = 0; i < board.rows() - delta.y(); ++i)
         {
             Vec2 sum{0, 0};
-            int count = 0;
-
             std::vector<Vec2> dirs;
 
             // Store directions between consecutive corners in row
@@ -1610,9 +1631,8 @@ void CheckerDetector::filterNestedCheckerBoards(const size_t& height, const size
         }
 
         double mean_area = mean_squares / count_squares;
-
         // Check that square size function is increasing
-        if (mean_area < previous_area * 0.8)
+        if (mean_area < previous_area * 0.5)
             continue;
 
         previous_area = mean_area;
