@@ -29,8 +29,13 @@ class DistortionBrown : public Distortion
     /// Remove distortion (return p' such that disto(p') = p)
     Vec2 removeDistortion(const Vec2& p) const override;
 
-    // Functor to calculate distortion offset accounting for both radial and tangential distortion
-    static Vec2 distoFunction(const std::vector<double>& params, const Vec2& p);
+    Eigen::Matrix2d getDerivativeAddDistoWrtPt(const Vec2& p) const override;
+
+    Eigen::MatrixXd getDerivativeAddDistoWrtDisto(const Vec2& p) const override;
+
+    Eigen::Matrix2d getDerivativeRemoveDistoWrtPt(const Vec2& p) const override;
+
+    Eigen::MatrixXd getDerivativeRemoveDistoWrtDisto(const Vec2& p) const override;
 
     ~DistortionBrown() override = default;
 };
