@@ -7,6 +7,7 @@
 
 #pragma once
 
+#include <aliceVision/types.hpp>
 #include <aliceVision/numeric/numeric.hpp>
 #include <aliceVision/camera/cameraCommon.hpp>
 #include <aliceVision/camera/IntrinsicInitMode.hpp>
@@ -25,6 +26,10 @@ namespace camera {
  */
 class IntrinsicBase
 {
+  public:
+    using sptr = std::shared_ptr<IntrinsicBase>;
+    using ptr = IntrinsicBase*;
+
   public:
     explicit IntrinsicBase(unsigned int width, unsigned int height, const std::string& serialNumber = "")
       : _w(width),
@@ -36,7 +41,7 @@ class IntrinsicBase
 
     /**
      * @brief Get the lock state of the intrinsic
-     * @return true if the intrinsic is locked
+     * @return True if the intrinsic is locked, false otherwise
      */
     inline bool isLocked() const { return _locked; }
 
@@ -88,102 +93,101 @@ class IntrinsicBase
     /**
      * @brief Projection of a 3D point into the camera plane (Apply pose, disto (if any) and Intrinsics)
      * @param[in] pose The pose
-     * @param[in] pt3D The 3d point
-     * @param[in] applyDistortion If true apply distrortion if any
-     * @return The 2d projection in the camera plane
+     * @param[in] pt3D The 3D point
+     * @param[in] applyDistortion If true, apply the distortion if there is any
+     * @return The 2D projection in the camera plane
      */
-    Vec2 project(const geometry::Pose3& pose, const Vec4& pt3D, bool applyDistortion = true) const
+    Vec2 transformProject(const geometry::Pose3& pose, const Vec4& pt3D, bool applyDistortion = true) const
     {
-        return project(pose.getHomogeneous(), pt3D, applyDistortion);
+        return transformProject(pose.getHomogeneous(), pt3D, applyDistortion);
     }
 
     /**
      * @brief Projection of a 3D point into the camera plane (Apply pose, disto (if any) and Intrinsics)
      * @param[in] pose The pose
-     * @param[in] pt3D The 3d point
-     * @param[in] applyDistortion If true apply distrortion if any
-     * @return The 2d projection in the camera plane
+     * @param[in] pt3D The 3D point
+     * @param[in] applyDistortion If true, apply the distortion if there is any
+     * @return The 2D projection in the camera plane
      */
-    virtual Vec2 project(const Eigen::Matrix4d& pose, const Vec4& pt3D, bool applyDistortion = true) const = 0;
+    virtual Vec2 transformProject(const Eigen::Matrix4d& pose, const Vec4& pt3D, bool applyDistortion = true) const = 0;
+
+    /**
+     * @brief Projection of a 3D point into the camera plane (Apply disto (if any) and Intrinsics)
+     * @param[in] pt3D The 3D point
+     * @param[in] applyDistortion If true, apply the distortion if there is any
+     * @return The 2D projection in the camera plane
+     */
+    virtual Vec2 project(const Vec4& pt3D, bool applyDistortion = true) const = 0;
 
     /**
      * @brief Back-projection of a 2D point at a specific depth into a 3D point
-     * @param[in] pt2D The 2d point
-     * @param[in] applyDistortion If true apply distrortion if any
+     * @param[in] pt2D The 2D point
+     * @param[in] applyDistortion If true, apply the distortion if there is any
      * @param[in] pose The camera pose
      * @param[in] depth The depth
-     * @return The 3d point
+     * @return The 3D point
      */
-    Vec3 backproject(const Vec2& pt2D, bool applyUndistortion = true, const geometry::Pose3& pose = geometry::Pose3(), double depth = 1.0) const;
+    Vec3 backprojectTransform(const Vec2& pt2D,
+                              bool applyUndistortion = true,
+                              const geometry::Pose3& pose = geometry::Pose3(),
+                              double depth = 1.0) const;
+
+    /**
+     * @brief Back-projection of a 2D point on a unitsphere
+     * @param[in] pt2D The 2D point
+     * @return The 3D point
+     */
+    Vec3 backProjectUnit(const Vec2& pt2D) const;
 
     Vec4 getCartesianfromSphericalCoordinates(const Vec3& pt);
 
     Eigen::Matrix<double, 4, 3> getDerivativeCartesianfromSphericalCoordinates(const Vec3& pt);
 
     /**
-     * @brief get derivative of a projection of a 3D point into the camera plane
+     * @brief Get the derivative of a projection of a 3D point into the camera plane
      * @param[in] pose The pose
-     * @param[in] pt3D The 3d point
-     * @param[in] applyDistortion If true apply distrortion if any
-     * @return The projection jacobian  wrt pose
+     * @param[in] pt3D The 3D point
+     * @return The projection jacobian with respect to the point
      */
-    virtual Eigen::Matrix<double, 2, 16> getDerivativeProjectWrtPose(const Eigen::Matrix4d& pose, const Vec4& pt3D) const = 0;
+    virtual Eigen::Matrix<double, 2, 3> getDerivativeTransformProjectWrtPoint3(const Eigen::Matrix4d& pose, const Vec4& pt3D) const = 0;
 
     /**
-     * @brief get derivative of a projection of a 3D point into the camera plane
+     * @brief Get the derivative of a projection of a 3D point into the camera plane
      * @param[in] pose The pose
-     * @param[in] pt3D The 3d point
-     * @param[in] applyDistortion If true apply distrortion if any
-     * @return The projection jacobian  wrt pose
+     * @param[in] pt3D The 3D point
+     * @return The projection jacobian with respect to the params
      */
-    virtual Eigen::Matrix<double, 2, 16> getDerivativeProjectWrtPoseLeft(const Eigen::Matrix4d& pose, const Vec4& pt3D) const = 0;
+    virtual Eigen::Matrix<double, 2, Eigen::Dynamic> getDerivativeTransformProjectWrtParams(const Eigen::Matrix4d& pos, const Vec4& pt3D) const = 0;
 
     /**
-     * @brief get derivative of a projection of a 3D point into the camera plane
-     * @param[in] pose The pose
-     * @param[in] pt3D The 3d point
-     * @param[in] applyDistortion If true apply distrortion if any
-     * @return The projection jacobian  wrt point
+     * @brief Get the derivative of the unit sphere backprojection
+     * @param[in] pt2D The 2D point
+     * @return The backproject jacobian with respect to the pose
      */
-    virtual Eigen::Matrix<double, 2, 4> getDerivativeProjectWrtPoint(const Eigen::Matrix4d& pose, const Vec4& pt3D) const = 0;
-
-    /**
-     * @brief get derivative of a projection of a 3D point into the camera plane
-     * @param[in] pose The pose
-     * @param[in] pt3D The 3d point
-     * @param[in] applyDistortion If true apply distrortion if any
-     * @return The projection jacobian  wrt point
-     */
-    virtual Eigen::Matrix<double, 2, 3> getDerivativeProjectWrtPoint3(const Eigen::Matrix4d& pose, const Vec4& pt3D) const = 0;
-
-    /**
-     * @brief get derivative of a projection of a 3D point into the camera plane
-     * @param[in] pose The pose
-     * @param[in] pt3D The 3d point
-     * @param[in] applyDistortion If true apply distrortion if any
-     * @return The projection jacobian wrt params
-     */
-    virtual Eigen::Matrix<double, 2, Eigen::Dynamic> getDerivativeProjectWrtParams(const Eigen::Matrix4d& pos, const Vec4& pt3D) const = 0;
+    virtual Eigen::Matrix<double, 3, Eigen::Dynamic> getDerivativeBackProjectUnitWrtParams(const Vec2& pt2D) const = 0;
 
     /**
      * @brief Compute the residual between the 3D projected point X and an image observation x
      * @param[in] pose The pose
      * @param[in] X The 3D projected point
      * @param[in] x The image observation
-     * @return residual
+     * @param[in] applyDistortion If true, apply the distortion if there is any
+     * @return residual between the 3D projected point and the image observation
      */
-    inline Vec2 residual(const geometry::Pose3& pose, const Vec4& X, const Vec2& x) const
+    inline Vec2 residual(const geometry::Pose3& pose, const Vec4& X, const Vec2& x, bool applyDistortion = true) const
     {
-        const Vec2 proj = this->project(pose, X);
-        return x - proj;
+        // We will compare to an undistorted point, so always ignore the distortion when computing coordinates
+        const Vec2 proj = this->transformProject(pose, X, false);
+
+        return ((applyDistortion) ? this->getUndistortedPixel(x) : x) - proj;
     }
 
     /**
-     * @brief Compute the residual between the 3D projected point X and an image observation x
+     * @brief Compute the residuals between the 3D projected point X and an image observation x
      * @param[in] pose The pose
      * @param[in] X The 3D projection
      * @param[in] x The image observation
-     * @return residual
+     * @return residuals between the 3D projected point and the image observation
      */
     inline Mat2X residuals(const geometry::Pose3& pose, const Mat3X& X, const Mat2X& x) const
     {
@@ -198,35 +202,35 @@ class IntrinsicBase
     }
 
     /**
-     * @brief lock the intrinsic
+     * @brief Lock the intrinsic
      */
     inline void lock() { _locked = true; }
 
     /**
-     * @brief unlock the intrinsic
+     * @brief Unlock the intrinsic
      */
     inline void unlock() { _locked = false; }
 
     /**
-     * @brief Set intrinsic image width
+     * @brief Set the intrinsic image width
      * @param[in] width The image width
      */
     inline void setWidth(unsigned int width) { _w = width; }
 
     /**
-     * @brief Set intrinsic image height
+     * @brief Set the intrinsic image height
      * @param[in] height The image height
      */
     inline void setHeight(unsigned int height) { _h = height; }
 
     /**
-     * @brief Set intrinsic sensor width
+     * @brief Set the intrinsic sensor width
      * @param[in] width The sensor width
      */
     inline void setSensorWidth(double width) { _sensorWidth = width; }
 
     /**
-     * @brief Set intrinsic sensor height
+     * @brief Set the intrinsic sensor height
      * @param[in] height The sensor height
      */
     inline void setSensorHeight(double height) { _sensorHeight = height; }
@@ -238,8 +242,8 @@ class IntrinsicBase
     inline void setSerialNumber(const std::string& serialNumber) { _serialNumber = serialNumber; }
 
     /**
-     * @brief Set The intrinsic initialization mode
-     * @param[in] initializationMode The intrintrinsic initialization mode enum
+     * @brief Set the intrinsic initialization mode
+     * @param[in] initializationMode The intrintrinsic initialization mode enum value
      */
     inline void setInitializationMode(EInitMode initializationMode) { _initializationMode = initializationMode; }
 
@@ -258,40 +262,40 @@ class IntrinsicBase
 
     /**
      * @brief Get embed camera type
-     * @return EINTRINSIC enum
+     * @return EINTRINSIC enum value
      */
     virtual EINTRINSIC getType() const = 0;
 
     /**
-     * get a string
-     * @return the string describing the intrinsic type
+     * @brief Get the string describing the intrinsic type
+     * @return The string describing the intrinsic type
      */
     std::string getTypeStr() const { return EINTRINSIC_enumToString(getType()); }
 
     /**
-     * @brief Get intrinsic parameters
-     * @return intrinsic parameters
+     * @brief Get the intrinsic parameters
+     * @return Intrinsic parameters as a vector
      */
-    virtual std::vector<double> getParams() const = 0;
+    virtual std::vector<double> getParameters() const = 0;
 
     /**
-     * @brief Get count of intrinsic parameters
-     * @return the number of intrinsic parameters
+     * @brief Get the count of intrinsic parameters
+     * @return The number of intrinsic parameters
      */
-    virtual std::size_t getParamsSize() const = 0;
+    virtual std::size_t getParametersSize() const = 0;
 
     /**
      * @brief Update intrinsic parameters
      * @param[in] intrinsic parameters
-     * @return true if done
+     * @return True if the parameters were successfully updated, false otherwise
      */
     virtual bool updateFromParams(const std::vector<double>& params) = 0;
 
     /**
-     * @brief import intrinsic parameters from external array
+     * @brief Import intrinsic parameters from external array
      * @param[in] intrinsic parameters
      * @param[in] inputVersion input source version (for optional transformation)
-     * @return true if done
+     * @return True if the parameters were successfully imported, false otherwise
      */
     virtual bool importFromParams(const std::vector<double>& params, const Version& inputVersion) = 0;
 
@@ -310,8 +314,8 @@ class IntrinsicBase
     virtual Vec2 ima2cam(const Vec2& p) const = 0;
 
     /**
-     * @brief Camera model handle a distortion field
-     * @return True if the camera model handle a distortion field
+     * @brief Camera model handles a distortion field
+     * @return True if the camera model handles a distortion field
      */
     virtual bool hasDistortion() const { return false; }
 
@@ -334,14 +338,14 @@ class IntrinsicBase
      * @param[in] p The point
      * @return The undistorted pixel
      */
-    virtual Vec2 get_ud_pixel(const Vec2& p) const = 0;
+    virtual Vec2 getUndistortedPixel(const Vec2& p) const = 0;
 
     /**
      * @brief Return the distorted pixel (with added distortion)
      * @param[in] p The undistorted point
      * @return The distorted pixel
      */
-    virtual Vec2 get_d_pixel(const Vec2& p) const = 0;
+    virtual Vec2 getDistortedPixel(const Vec2& p) const = 0;
 
     /**
      * @brief Set The intrinsic disto initialization mode
@@ -362,6 +366,12 @@ class IntrinsicBase
      */
     virtual double imagePlaneToCameraPlaneError(double value) const = 0;
 
+    /**
+     * @brief What is the probability of a pixel wrt the whole fov
+     * @return a value in radians
+     */
+    virtual double pixelProbability() const = 0;
+
     /**
      * @brief Return true if the intrinsic is valid
      * @return True if the intrinsic is valid
@@ -371,32 +381,32 @@ class IntrinsicBase
     /**
      * @brief Return true if this ray should be visible in the image
      * @param ray input ray to check for visibility
-     * @return true if this ray is visible theorically
+     * @return True if this ray is visible theoretically
      */
     virtual bool isVisibleRay(const Vec3& ray) const = 0;
 
     /**
      * @brief Return true if these pixel coordinates should be visible in the image
      * @param pix input pixel coordinates to check for visibility
-     * @return true if visible
+     * @return True if visible
      */
     virtual bool isVisible(const Vec2& pix) const;
 
     /**
      * @brief Return true if these pixel coordinates should be visible in the image
      * @param pix input pixel coordinates to check for visibility
-     * @return true if visible
+     * @return True if visible
      */
     virtual bool isVisible(const Vec2f& pix) const;
 
     /**
      * @brief Assuming the distortion is a function of radius, estimate the
      * maximal undistorted radius for a range of distorted radius.
-     * @param min_radius the minimal radius to consider
-     * @param max_radius the maximal radius to consider
-     * @return the maximal undistorted radius
+     * @param minRadius the minimal radius to consider
+     * @param maxRadius the maximal radius to consider
+     * @return The maximal undistorted radius
      */
-    virtual float getMaximalDistortion(double min_radius, double max_radius) const;
+    virtual float getMaximalDistortion(double minRadius, double maxRadius) const;
 
     /**
      * @brief Generate an unique Hash from the camera parameters (used for grouping)
@@ -406,34 +416,67 @@ class IntrinsicBase
 
     /**
      * @brief Rescale intrinsics to reflect a rescale of the camera image
-     * @param factor a scale factor
+     * @param factorW a scale factor for Width
+     * @param factorH a scale factor for Height
      */
-    virtual void rescale(float factor);
+    virtual void rescale(float factorW, float factorH);
 
     /**
-     * @brief transform a given point (in pixels) to unit sphere in meters
+     * @brief Transform a given point (in pixels) to unit sphere in meters
      * @param pt the input point
-     * @return a point on the unit sphere
+     * @return A point on the unit sphere
      */
     virtual Vec3 toUnitSphere(const Vec2& pt) const = 0;
 
     /**
-     * @Brief get horizontal fov in radians
-     * @return  horizontal fov in radians
-    */
+     * @brief Get the horizontal FOV in radians
+     * @return Horizontal FOV in radians
+     */
     virtual double getHorizontalFov() const = 0;
 
     /**
-     * @Brief get vertical fov in radians
-     * @return  vertical fov in radians
-    */
+     * @brief Get the vertical FOV in radians
+     * @return Vertical FOV in radians
+     */
     virtual double getVerticalFov() const = 0;
 
+    /**
+     * @brief Initialize state with default values
+     * The estimator state is used in the bundle adjustment to decide if we update it.
+     * It is set to constant if the intrinsic is locked
+     * It is set to refined if unlocked
+     */
+    virtual void initializeState()
+    {
+        if (_locked)
+        {
+            _state = EEstimatorParameterState::CONSTANT;
+        }
+        else
+        {
+            _state = EEstimatorParameterState::REFINED;
+        }
+    }
+
+    /**
+     * @brief accessor to estimator state
+     * @return a state
+     */
+    EEstimatorParameterState getState() const { return _state; }
+
+    /**
+     * @brief mutator for the estimator state
+     * @param state the new state of the intrinsic
+     */
+    void setState(EEstimatorParameterState state) { _state = state; }
+
   protected:
     /// initialization mode
     EInitMode _initializationMode = EInitMode::NONE;
     /// intrinsic lock
     bool _locked = false;
+    EEstimatorParameterState _state = EEstimatorParameterState::REFINED;
+
     unsigned int _w = 0;
     unsigned int _h = 0;
     double _sensorWidth = 36.0;
@@ -445,7 +488,7 @@ class IntrinsicBase
  * @brief Apply intrinsic and extrinsic parameters to unit vector
  * from the cameras focus to a point on the camera plane
  * @param[in] pose Extrinsic pose
- * @param[in] intrinsic Intrinsic camera paremeters
+ * @param[in] intrinsic Intrinsic camera parameters
  * @param[in] x Point in image
  * @return The unit vector in 3D space pointing out from the camera to the point
  */
@@ -509,81 +552,4 @@ inline double angleBetweenRays(const geometry::Pose3& pose1, const geometry::Pos
 
 }  // namespace camera
 
-template<size_t M, size_t N>
-Eigen::Matrix<double, M * N, M * N> getJacobian_At_wrt_A()
-{
-    Eigen::Matrix<double, M * N, M * N> ret;
-
-    /** vec(M1*M2*M3) = kron(M3.t, M1) * vec(M2) */
-    /** vec(IAtB) = kron(B.t, I) * vec(A) */
-    /** dvec(IAtB)/dA = kron(B.t, I) * dvec(At)/dA */
-
-    ret.fill(0);
-
-    size_t pos_at = 0;
-    for (size_t i = 0; i < M; i++)
-    {
-        for (size_t j = 0; j < N; j++)
-        {
-            size_t pos_a = N * j + i;
-            ret(pos_at, pos_a) = 1;
-
-            pos_at++;
-        }
-    }
-
-    return ret;
-}
-
-template<size_t M, size_t N, size_t K>
-Eigen::Matrix<double, M * K, M * N> getJacobian_AB_wrt_A(const Eigen::Matrix<double, M, N>& A, const Eigen::Matrix<double, N, K>& B)
-{
-    Eigen::Matrix<double, M * K, M * N> ret;
-
-    /** vec(M1*M2*M3) = kron(M3.t, M1) * vec(M2) */
-    /** vec(IAB) = kron(B.t, I) * vec(A) */
-    /** dvec(IAB)/dA = kron(B.t, I) * dvec(A)/dA */
-    /** dvec(IAB)/dA = kron(B.t, I) */
-
-    ret.fill(0);
-
-    Eigen::Matrix<double, K, N> Bt = B.transpose();
-
-    for (size_t row = 0; row < K; row++)
-    {
-        for (size_t col = 0; col < N; col++)
-        {
-            ret.template block<M, M>(row * M, col * M) = Bt(row, col) * Eigen::Matrix<double, M, M>::Identity();
-        }
-    }
-
-    return ret;
-}
-
-template<size_t M, size_t N, size_t K>
-Eigen::Matrix<double, M * K, M * N> getJacobian_AtB_wrt_A(const Eigen::Matrix<double, M, N>& A, const Eigen::Matrix<double, M, K>& B)
-{
-    return getJacobian_AB_wrt_A<M, N, K>(A.transpose(), B) * getJacobian_At_wrt_A<M, N>();
-}
-
-template<size_t M, size_t N, size_t K>
-Eigen::Matrix<double, M * K, N * K> getJacobian_AB_wrt_B(const Eigen::Matrix<double, M, N>& A, const Eigen::Matrix<double, N, K>& B)
-{
-    Eigen::Matrix<double, M * K, N * K> ret;
-
-    /** vec(M1*M2*M3) = kron(M3.t, M1) * vec(M2) */
-    /** vec(ABI) = kron(I, A) * vec(B) */
-    /** dvec(ABI)/dB = kron(I, A) * dvec(B)/dB */
-    /** dvec(ABI)/dB = kron(I, A) */
-
-    ret.fill(0);
-
-    for (size_t index = 0; index < K; index++)
-    {
-        ret.template block<M, N>(M * index, N * index) = A;
-    }
-
-    return ret;
-}
-
 }  // namespace aliceVision
