@@ -182,15 +182,15 @@ void exportSimilarityVolume(const CudaHostMemoryHeap<TSim, 3>& in_volumeSim_hmh,
                 if (simValue > maxValue)
                     continue;
                 const rgb c = getRGBFromJetColorMap(simValue / maxValue);
-                pointCloud.getLandmarks()[landmarkId] = sfmData::Landmark(
-                  Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, sfmData::Observations(), image::RGBColor(c.r, c.g, c.b));
+                pointCloud.getLandmarks()[landmarkId] =
+                  sfmData::Landmark(Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, image::RGBColor(c.r, c.g, c.b));
 
                 ++landmarkId;
             }
         }
     }
 
-    sfmDataIO::Save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
+    sfmDataIO::save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
 }
 
 void exportSimilarityVolumeCross(const CudaHostMemoryHeap<TSim, 3>& in_volumeSim_hmh,
@@ -234,15 +234,15 @@ void exportSimilarityVolumeCross(const CudaHostMemoryHeap<TSim, 3>& in_volumeSim
                     continue;
 
                 const rgb c = getRGBFromJetColorMap(simValue / maxValue);
-                pointCloud.getLandmarks()[landmarkId] = sfmData::Landmark(
-                  Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, sfmData::Observations(), image::RGBColor(c.r, c.g, c.b));
+                pointCloud.getLandmarks()[landmarkId] =
+                  sfmData::Landmark(Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, image::RGBColor(c.r, c.g, c.b));
 
                 ++landmarkId;
             }
         }
     }
 
-    sfmDataIO::Save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
+    sfmDataIO::save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
 }
 
 void exportSimilarityVolumeCross(const CudaHostMemoryHeap<TSimRefine, 3>& in_volumeSim_hmh,
@@ -292,15 +292,15 @@ void exportSimilarityVolumeCross(const CudaHostMemoryHeap<TSimRefine, 3>& in_vol
                 const Point3d p = mp.CArr[camIndex] + (mp.iCamArr[camIndex] * pix).normalize() * depth;
 
                 const rgb c = getRGBFromJetColorMap(simValue / maxValue);
-                pointCloud.getLandmarks()[landmarkId] = sfmData::Landmark(
-                  Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, sfmData::Observations(), image::RGBColor(c.r, c.g, c.b));
+                pointCloud.getLandmarks()[landmarkId] =
+                  sfmData::Landmark(Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, image::RGBColor(c.r, c.g, c.b));
 
                 ++landmarkId;
             }
         }
     }
 
-    sfmDataIO::Save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
+    sfmDataIO::save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
 }
 
 void exportSimilarityVolumeTopographicCut(const CudaHostMemoryHeap<TSim, 3>& in_volumeSim_hmh,
@@ -365,14 +365,14 @@ void exportSimilarityVolumeTopographicCut(const CudaHostMemoryHeap<TSim, 3>& in_
 
             const rgb c = getRGBFromJetColorMap(simValueNorm);
             pointCloud.getLandmarks()[landmarkId] =
-              sfmData::Landmark(Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, sfmData::Observations(), image::RGBColor(c.r, c.g, c.b));
+              sfmData::Landmark(Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, image::RGBColor(c.r, c.g, c.b));
 
             ++landmarkId;
         }
     }
 
     // write point cloud
-    sfmDataIO::Save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
+    sfmDataIO::save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
 }
 
 void exportSimilarityVolumeTopographicCut(const CudaHostMemoryHeap<TSimRefine, 3>& in_volumeSim_hmh,
@@ -430,14 +430,14 @@ void exportSimilarityVolumeTopographicCut(const CudaHostMemoryHeap<TSimRefine, 3
 
             const rgb c = getRGBFromJetColorMap(simValueColor);
             pointCloud.getLandmarks()[landmarkId] =
-              sfmData::Landmark(Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, sfmData::Observations(), image::RGBColor(c.r, c.g, c.b));
+              sfmData::Landmark(Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, image::RGBColor(c.r, c.g, c.b));
 
             ++landmarkId;
         }
     }
 
     // write point cloud
-    sfmDataIO::Save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
+    sfmDataIO::save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
 }
 
 inline unsigned char float_to_uchar(float v)
@@ -490,15 +490,15 @@ void exportColorVolume(const CudaHostMemoryHeap<float4, 3>& in_volumeSim_hmh,
 
                 float4 colorValue = *get3DBufferAt_h<float4>(in_volumeSim_hmh.getBuffer(), spitch, pitch, vx, vy, vz);
                 const rgb c = float4_to_rgb(colorValue);  // TODO: convert Lab color into sRGB color
-                pointCloud.getLandmarks()[landmarkId] = sfmData::Landmark(
-                  Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, sfmData::Observations(), image::RGBColor(c.r, c.g, c.b));
+                pointCloud.getLandmarks()[landmarkId] =
+                  sfmData::Landmark(Vec3(p.x, p.y, p.z), feature::EImageDescriberType::UNKNOWN, image::RGBColor(c.r, c.g, c.b));
 
                 ++landmarkId;
             }
         }
     }
 
-    sfmDataIO::Save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
+    sfmDataIO::save(pointCloud, filepath, sfmDataIO::ESfMData::STRUCTURE);
 }
 
 }  // namespace depthMap
