@@ -7,10 +7,20 @@
 
 #pragma once
 
+#ifdef __CUDA_FP16_HPP__
+#define __CUDA_FP16_HPP_BAK__ __CUDA_FP16_HPP__
+#undef __CUDA_FP16_HPP__
+#endif
+
 #include "Image.hpp"
 #include "pixelTypes.hpp"
 #include "colorspace.hpp"
 
+#ifdef __CUDA_FP16_HPP_BAK__
+#define __CUDA_FP16_HPP__ __CUDA_FP16_HPP_BAK__ 
+#undef __CUDA_FP16_HPP_BAK__
+#endif
+
 #include <aliceVision/types.hpp>
 
 #include <OpenImageIO/paramlist.h>
@@ -63,7 +73,7 @@ enum class EImageFileType
 };
 
 /**
- * @brief get informations about each image file type
+ * @brief get information about each image file type
  * @return String
  */
 std::string EImageFileType_informations();
@@ -174,7 +184,7 @@ enum class EImageQuality
 };
 
 /**
- * @brief get informations about each image quality
+ * @brief get information about each image quality
  * @return String
  */
 std::string EImageQuality_informations();
