@@ -7,21 +7,21 @@
 #include "KeyframeSelector.hpp"
 #include <aliceVision/sfmDataIO/viewIO.hpp>
 #include <aliceVision/system/Logger.hpp>
-
-#include <boost/filesystem.hpp>
+#include <aliceVision/utils/filesIO.hpp>
+#include <aliceVision/camera/Pinhole.hpp>
 
 #include <random>
 #include <tuple>
 #include <cassert>
 #include <cstdlib>
+#include <filesystem>
 #include <iomanip>
 #include <fstream>
 #include <thread>
 
-namespace fs = boost::filesystem;
+namespace fs = std::filesystem;
 
-namespace aliceVision {
-namespace keyframe {
+namespace aliceVision::keyframe {
 
 /**
  * @brief Get a random int in order to generate uid.
@@ -44,7 +44,7 @@ int getRandomInt()
 double findMedian(const std::vector<double>& vec)
 {
     std::vector<double> vecCopy = vec;
-    if (vecCopy.size() > 0 && vecCopy.size() % 2 == 0)
+    if (!vecCopy.empty() && vecCopy.size() % 2 == 0)
     {
         const auto medianIt1 = vecCopy.begin() + vecCopy.size() / 2 - 1;
         std::nth_element(vecCopy.begin(), medianIt1, vecCopy.end());
@@ -56,7 +56,7 @@ double findMedian(const std::vector<double>& vec)
 
         return (med1 + med2) / 2.0;
     }
-    else if (vecCopy.size() > 0)
+    else if (!vecCopy.empty())
     {
         const auto medianIt = vecCopy.begin() + vecCopy.size() / 2;
         std::nth_element(vecCopy.begin(), medianIt, vecCopy.end());
@@ -127,7 +127,7 @@ void KeyframeSelector::processRegular()
     // Check if minimum number of frame is zero
     if (nbFrames == 0)
     {
-        ALICEVISION_THROW(std::invalid_argument, "One or multiple medias can't be found or empty!");
+        ALICEVISION_THROW(std::invalid_argument, "One or multiple media can't be found or empty!");
     }
 
     // All frames are unselected so far
@@ -404,7 +404,7 @@ bool KeyframeSelector::computeScores(const std::size_t rescaledWidthSharpness,
     // Check if minimum number of frame is zero
     if (nbFrames == 0)
     {
-        ALICEVISION_THROW(std::invalid_argument, "One or multiple medias can't be found or is empty!");
+        ALICEVISION_THROW(std::invalid_argument, "One or multiple media can't be found or is empty!");
     }
 
     // With the number of threads available and the number of frames to process known,
@@ -415,7 +415,7 @@ bool KeyframeSelector::computeScores(const std::size_t rescaledWidthSharpness,
 
     // If a block contains less than _minBlockSize frames (when there are lots of available threads for a small number
     // of frames, for example), resize it: less threads will be spawned, but since new FeedProvider objects need to be
-    // created for each thread, we prevent spawing thread that will need to create FeedProvider objects
+    // created for each thread, we prevent spawning thread that will need to create FeedProvider objects
     // for very few frames.
     if (blockSize < _minBlockSize && nbFrames >= _minBlockSize)
     {
@@ -698,13 +698,13 @@ bool KeyframeSelector::writeSelection(const std::vector<std::string>& brands,
             if (_mediaPaths.size() > 1)
             {
                 const std::string rigFolder = _outputFolder + "/rig/";
-                if (!fs::exists(rigFolder))
+                if (!utils::exists(rigFolder))
                 {
                     fs::create_directory(rigFolder);
                 }
 
                 processedOutputFolder = rigFolder + std::to_string(id);
-                if (!fs::exists(processedOutputFolder))
+                if (!utils::exists(processedOutputFolder))
                 {
                     fs::create_directory(processedOutputFolder);
                 }
@@ -873,13 +873,13 @@ bool KeyframeSelector::exportFlowVisualisation(const std::size_t rescaledWidth)
         if (_mediaPaths.size() > 1)
         {
             const std::string rigFolder = _outputFolder + "/rig/";
-            if (!fs::exists(rigFolder))
+            if (!utils::exists(rigFolder))
             {
                 fs::create_directory(rigFolder);
             }
 
             processedOutputFolder = rigFolder + std::to_string(mediaIndex);
-            if (!fs::exists(processedOutputFolder))
+            if (!utils::exists(processedOutputFolder))
             {
                 fs::create_directory(processedOutputFolder);
             }
@@ -919,11 +919,10 @@ bool KeyframeSelector::exportFlowVisualisation(const std::size_t rescaledWidth)
             {
                 currentMat = readImage(feed, rescaledWidth);  // Read image and rescale it if requested
             }
-            catch (const std::invalid_argument& ex)
+            catch (const std::invalid_argument&)
             {
                 ALICEVISION_LOG_WARNING("Invalid or missing frame " << currentFrame + 1 << ", attempting to read frame " << currentFrame + 2 << ".");
-                bool success = feed.goToFrame(++currentFrame);
-                if (success)
+                if (feed.goToFrame(++currentFrame))
                     currentMat = readImage(feed, rescaledWidth);
                 else
                     ALICEVISION_THROW_ERROR("Could not go to frame " << currentFrame + 1 << " either. The feed might be corrupted.");
@@ -936,7 +935,9 @@ bool KeyframeSelector::exportFlowVisualisation(const std::size_t rescaledWidth)
 
                 cv::Mat flowParts[2];
                 cv::split(flow, flowParts);
-                cv::Mat magnitude, angle, magnNorm;
+                cv::Mat magnitude;
+                cv::Mat angle;
+                cv::Mat magnNorm;
                 cv::cartToPolar(flowParts[0], flowParts[1], magnitude, angle, true);
                 cv::normalize(magnitude, magnNorm, 0.0f, 1.0f, cv::NORM_MINMAX);
                 angle *= ((1.f / 360.f) * (180.f / 255.f));
@@ -1030,7 +1031,8 @@ double KeyframeSelector::computeSharpness(const cv::Mat& grayscaleImage, const s
     }
 
     double maxstd = 0.0;
-    int x, y;
+    int x = 1;
+    int y = 1;
 
     // Starts at 1 because the integral image is padded with 0s on the top and left borders
     for (y = 1; y < sum.rows - windowSize; y += windowSize / 4)
@@ -1064,7 +1066,7 @@ const double KeyframeSelector::computeSharpnessStd(const cv::Mat& sum,
                                                    const cv::Mat& squaredSum,
                                                    const int x,
                                                    const int y,
-                                                   const int windowSize,
+                                                   const std::size_t windowSize,
                                                    const cv::Mat& mask)
 {
     double totalCount = windowSize * windowSize;
@@ -1226,7 +1228,7 @@ bool KeyframeSelector::writeSfMData(const std::string& mediaPath,
         return false;
     }
 
-    if (!sfmDataIO::Save(_outputSfmKeyframes, _outputSfmKeyframesPath, sfmDataIO::ESfMData::ALL))
+    if (!sfmDataIO::save(_outputSfmKeyframes, _outputSfmKeyframesPath, sfmDataIO::ESfMData::ALL))
     {
         ALICEVISION_LOG_ERROR("The output SfMData file '" << _outputSfmKeyframesPath << "' could not be written.");
         return false;
@@ -1234,7 +1236,7 @@ bool KeyframeSelector::writeSfMData(const std::string& mediaPath,
 
     if (!feed.isVideo())
     {
-        if (!sfmDataIO::Save(_outputSfmFrames, _outputSfmFramesPath, sfmDataIO::ESfMData::ALL))
+        if (!sfmDataIO::save(_outputSfmFrames, _outputSfmFramesPath, sfmDataIO::ESfMData::ALL))
         {
             ALICEVISION_LOG_ERROR("The output SfMData file '" << _outputSfmFramesPath << "' could not be written.");
             return false;
@@ -1251,6 +1253,8 @@ bool KeyframeSelector::writeSfMData(const std::string& mediaPath,
 
 bool KeyframeSelector::writeSfMDataFromSfMData(const std::string& mediaPath)
 {
+    auto& keyframesPoses = _outputSfmKeyframes.getPoses();
+
     auto& keyframesViews = _outputSfmKeyframes.getViews();
     auto& framesViews = _outputSfmFrames.getViews();
 
@@ -1262,7 +1266,7 @@ bool KeyframeSelector::writeSfMDataFromSfMData(const std::string& mediaPath)
 
     sfmData::SfMData inputSfm;
     std::vector<std::shared_ptr<sfmData::View>> views;
-    if (!sfmDataIO::Load(inputSfm, mediaPath, sfmDataIO::ESfMData::ALL))
+    if (!sfmDataIO::load(inputSfm, mediaPath, sfmDataIO::ESfMData::ALL))
     {
         ALICEVISION_LOG_ERROR("Could not open input SfMData file " << mediaPath << ".");
         return false;
@@ -1291,6 +1295,18 @@ bool KeyframeSelector::writeSfMDataFromSfMData(const std::string& mediaPath)
     {
         viewId = views[i]->getViewId();
         intrinsicId = views[i]->getIntrinsicId();
+        IndexT poseId = views[i]->getPoseId();
+
+        bool hasPose = inputSfm.isPoseAndIntrinsicDefined(viewId);
+        if (hasPose)
+        {
+            ALICEVISION_LOG_INFO("A fully calibrated view (Id:" << viewId << ") is moved to keyframes");
+            _selectedFrames[i] = '1';
+
+            //Make sure to keep the pose
+            keyframesPoses.assign(poseId, inputSfm.getAbsolutePose(poseId));
+        }
+
         if (_selectedFrames[i] == '1')
         {
             keyframesViews.emplace(viewId, views[i]);
@@ -1368,7 +1384,7 @@ bool KeyframeSelector::writeSfMDataFromSequences(const std::string& mediaPath,
         }
 
         // Create the view
-        auto view = createView(currentImgName, intrinsicId, previousFrameId, image.Width(), image.Height());
+        auto view = createView(currentImgName, intrinsicId, previousFrameId, image.width(), image.height());
         previousFrameId = view->getFrameId();
 
         // If there is a rig, the view's rig and sub-pose IDs need to be set once it has been completed
@@ -1388,7 +1404,7 @@ bool KeyframeSelector::writeSfMDataFromSequences(const std::string& mediaPath,
         if (model.empty() && !models[mediaIndex].empty())
             model = models[mediaIndex];
 
-        const double imageRatio = static_cast<double>(image.Width()) / static_cast<double>(image.Height());
+        const double imageRatio = static_cast<double>(image.width()) / static_cast<double>(image.height());
         double sensorWidth = -1.0;
         sensorDB::Datasheet datasheet;
 
@@ -1485,7 +1501,13 @@ std::shared_ptr<camera::IntrinsicBase> KeyframeSelector::createIntrinsic(const s
                                                                          const double imageRatio,
                                                                          const std::size_t mediaIndex)
 {
-    auto intrinsic = sfmDataIO::getViewIntrinsic(view, focalLength, sensorWidth);
+    camera::EInitMode mode = camera::EInitMode::ESTIMATED;
+    if (sensorWidth <= 0)
+    {
+        mode = camera::EInitMode::UNKNOWN;
+    }
+    
+    auto intrinsic = sfmDataIO::getViewIntrinsic(view, mode, focalLength, sensorWidth);
     if (imageRatio > 1.0 && sensorWidth > -1.0)
     {
         intrinsic->setSensorWidth(sensorWidth);
@@ -1509,5 +1531,4 @@ std::shared_ptr<camera::IntrinsicBase> KeyframeSelector::createIntrinsic(const s
     return intrinsic;
 }
 
-}  // namespace keyframe
-}  // namespace aliceVision
+}  // namespace aliceVision::keyframe
