@@ -5,6 +5,7 @@
 // You can obtain one at https://mozilla.org/MPL/2.0/.
 
 #include "MultiViewParams.hpp"
+
 #include <aliceVision/sfmData/SfMData.hpp>
 #include <aliceVision/system/Logger.hpp>
 #include <aliceVision/image/io.hpp>
@@ -17,8 +18,8 @@
 #include <aliceVision/numeric/projection.hpp>
 #include <aliceVision/utils/filesIO.hpp>
 #include <aliceVision/camera/camera.hpp>
+#include <aliceVision/camera/Pinhole.hpp>
 
-#include <boost/filesystem.hpp>
 #include <boost/accumulators/accumulators.hpp>
 #include <boost/accumulators/statistics.hpp>
 #include <boost/property_tree/ini_parser.hpp>
@@ -26,19 +27,20 @@
 #include <boost/algorithm/string/classification.hpp>
 #include <boost/lexical_cast.hpp>
 
+#include <filesystem>
 #include <iostream>
 #include <set>
 
 namespace aliceVision {
 namespace mvsUtils {
 
-namespace fs = boost::filesystem;
+namespace fs = std::filesystem;
 
 MultiViewParams::MultiViewParams(const sfmData::SfMData& sfmData,
                                  const std::string& imagesFolder,
                                  const std::string& depthMapsFolder,
                                  const std::string& depthMapsFilterFolder,
-                                 bool readFromDepthMaps,
+                                 mvsUtils::EFileType fileType,
                                  int downscale)
   : _sfmData(sfmData),
     _imagesFolder(imagesFolder + "/"),
@@ -58,12 +60,12 @@ MultiViewParams::MultiViewParams(const sfmData::SfMData& sfmData,
         {
             const sfmData::View& view = *(viewPair.second.get());
 
-            if (!sfmData.isPoseAndIntrinsicDefined(&view))
+            if (!sfmData.isPoseAndIntrinsicDefined(view))
                 continue;
 
             std::string path = view.getImage().getImagePath();
 
-            if (readFromDepthMaps)
+            if (fileType == mvsUtils::EFileType::depthMap)
             {
                 if (depthMapsFolder.empty())
                 {
@@ -76,6 +78,10 @@ MultiViewParams::MultiViewParams(const sfmData::SfMData& sfmData,
                     path = getFileNameFromViewId(*this, view.getViewId(), mvsUtils::EFileType::depthMap);
                 }
             }
+            else if (fileType == mvsUtils::EFileType::normalMap)
+            {
+                path = getFileNameFromViewId(*this, view.getViewId(), mvsUtils::EFileType::normalMap);
+            }
             else if (_imagesFolder != "/" && !_imagesFolder.empty() && fs::is_directory(_imagesFolder) && !fs::is_empty(_imagesFolder))
             {
                 // find folder file extension
@@ -86,7 +92,7 @@ MultiViewParams::MultiViewParams(const sfmData::SfMData& sfmData,
                 // if path was not found
                 if (paths.empty())
                 {
-                    throw std::runtime_error("Cannot find image file coresponding to the view '" + std::to_string(view.getViewId()) +
+                    throw std::runtime_error("Cannot find image file corresponding to the view '" + std::to_string(view.getViewId()) +
                                              "' in folder '" + _imagesFolder + "'.");
                 }
                 else if (paths.size() > 1)
@@ -122,7 +128,7 @@ MultiViewParams::MultiViewParams(const sfmData::SfMData& sfmData,
         oiio::ParamValueList::const_iterator scaleIt = metadata.end();
         oiio::ParamValueList::const_iterator pIt = metadata.end();
 
-        const bool fileExists = fs::exists(imgParams.path);
+        const bool fileExists = utils::exists(imgParams.path);
         if (fileExists)
         {
             metadata = image::readImageMetadata(imgParams.path);
@@ -168,7 +174,7 @@ MultiViewParams::MultiViewParams(const sfmData::SfMData& sfmData,
             const std::string fileNameP = getFileNameFromIndex(*this, i, EFileType::P);
             const std::string fileNameD = getFileNameFromIndex(*this, i, EFileType::D);
 
-            if (fs::exists(fileNameP) && fs::exists(fileNameD))
+            if (utils::exists(fileNameP) && utils::exists(fileNameD))
             {
                 ALICEVISION_LOG_DEBUG("Reading view " << getViewId(i) << " projection matrix from file '" << fileNameP << "'.");
 
@@ -234,13 +240,13 @@ MultiViewParams::MultiViewParams(const sfmData::SfMData& sfmData,
 
 void MultiViewParams::loadMatricesFromTxtFile(int index, const std::string& fileNameP, const std::string& fileNameD)
 {
-    if (!fs::exists(fileNameP))
+    if (!utils::exists(fileNameP))
         throw std::runtime_error(std::string("mv_multiview_params: no such file: ") + fileNameP);
 
     std::ifstream in{fileNameP};
     char fc;
     in >> fc;
-    if (fc == 'C')  // FURUKAWA'S PROJCTION MATRIX FILE FORMAT
+    if (fc == 'C')  // FURUKAWA'S PROJECTION MATRIX FILE FORMAT
     {
         in >> fc;  // O
         in >> fc;  // N
@@ -269,7 +275,7 @@ void MultiViewParams::loadMatricesFromTxtFile(int index, const std::string& file
     iRArr[index] = RArr[index].inverse();
     iCamArr[index] = iRArr[index] * iKArr[index];
 
-    if (fs::exists(fileNameD))
+    if (utils::exists(fileNameD))
     {
         std::ifstream inD{fileNameD};
         inD >> FocK1K2Arr[index].x >> FocK1K2Arr[index].y >> FocK1K2Arr[index].z;
@@ -301,13 +307,13 @@ void MultiViewParams::loadMatricesFromSfM(int index)
 
     std::shared_ptr<camera::IntrinsicBase> ptrIntrinsic = intrinsicIt->second;
     std::shared_ptr<camera::Pinhole> ptrPinHole = std::dynamic_pointer_cast<camera::Pinhole>(ptrIntrinsic);
-    if (!ptrPinHole)
+
+    Mat34 P = _sfmData.getPose(view).getTransform().getHomogeneous().block<3, 4>(0, 0);
+    if (ptrPinHole)
     {
-        ALICEVISION_LOG_ERROR("Camera is not pinhole in loadMatricesFromRawProjectionMatrix");
-        return;
+        P = ptrPinHole->getProjectiveEquivalent(_sfmData.getPose(view).getTransform());        
     }
 
-    const Mat34 P = ptrPinHole->getProjectiveEquivalent(_sfmData.getPose(view).getTransform());
     std::vector<double> vP(P.size());
     Eigen::Map<RowMatrixXd>(vP.data(), P.rows(), P.cols()) = P;
 
@@ -484,7 +490,7 @@ bool MultiViewParams::isPixelInSourceImage(const Pixel& pixRC, int camId, int ma
     const camera::IntrinsicBase* intrinsicPtr = _sfmData.getIntrinsicPtr(view.getIntrinsicId());
 
     const double s = getDownscaleFactor(camId);
-    Vec2 pix_disto = intrinsicPtr->get_d_pixel({pixRC.x * s, pixRC.y * s}) / s;
+    Vec2 pix_disto = intrinsicPtr->getDistortedPixel({pixRC.x * s, pixRC.y * s}) / s;
     return isPixelInImage(Pixel(pix_disto.x(), pix_disto.y()), camId, margin);
 }
 
@@ -528,7 +534,7 @@ StaticVector<int> MultiViewParams::findNearestCamsFromLandmarks(int rc, int nbNe
 
     for (const auto& landmarkPair : _sfmData.getLandmarks())
     {
-        const auto& observations = landmarkPair.second.observations;
+        const auto& observations = landmarkPair.second.getObservations();
 
         auto viewObsIt = observations.find(viewId);
         if (viewObsIt == observations.end())
@@ -545,8 +551,8 @@ StaticVector<int> MultiViewParams::findNearestCamsFromLandmarks(int rc, int nbNe
             const geometry::Pose3 otherPose = _sfmData.getPose(otherView).getTransform();
             const camera::IntrinsicBase* otherIntrinsicPtr = _sfmData.getIntrinsicPtr(otherView.getIntrinsicId());
 
-            const double angle =
-              camera::angleBetweenRays(pose, intrinsicPtr, otherPose, otherIntrinsicPtr, viewObsIt->second.x, observationPair.second.x);
+            const double angle = camera::angleBetweenRays(
+              pose, intrinsicPtr, otherPose, otherIntrinsicPtr, viewObsIt->second.getCoordinates(), observationPair.second.getCoordinates());
 
             if (angle < _minViewAngle || angle > _maxViewAngle)
                 continue;
@@ -604,7 +610,7 @@ std::vector<int> MultiViewParams::findTileNearestCams(int rc, int nbNearestCams,
 
     for (const auto& landmarkPair : sfmData.getLandmarks())
     {
-        const auto& observations = landmarkPair.second.observations;
+        const auto& observations = landmarkPair.second.getObservations();
 
         auto viewObsIt = observations.find(viewId);
 
@@ -613,7 +619,7 @@ std::vector<int> MultiViewParams::findTileNearestCams(int rc, int nbNearestCams,
             continue;
 
         // landmark R camera observation is in the image full-size ROI
-        if (!fullsizeRoi.contains(viewObsIt->second.x.x(), viewObsIt->second.x.y()))
+        if (!fullsizeRoi.contains(viewObsIt->second.getX(), viewObsIt->second.getY()))
             continue;
 
         for (const auto& observationPair : observations)
@@ -634,8 +640,8 @@ std::vector<int> MultiViewParams::findTileNearestCams(int rc, int nbNearestCams,
             const geometry::Pose3 otherPose = sfmData.getPose(otherView).getTransform();
             const camera::IntrinsicBase* otherIntrinsicPtr = sfmData.getIntrinsicPtr(otherView.getIntrinsicId());
 
-            const double angle =
-              camera::angleBetweenRays(pose, intrinsicPtr, otherPose, otherIntrinsicPtr, viewObsIt->second.x, observationPair.second.x);
+            const double angle = camera::angleBetweenRays(
+              pose, intrinsicPtr, otherPose, otherIntrinsicPtr, viewObsIt->second.getCoordinates(), observationPair.second.getCoordinates());
 
             tcScore[tc] += plateauFunction(1, 10, 50, 150, angle);
         }
