@@ -7,7 +7,7 @@
 #include <aliceVision/image/io.hpp>
 #include <aliceVision/sfmData/Landmark.hpp>
 #include <aliceVision/sfmDataIO/sfmDataIO.hpp>
-
+#include <aliceVision/camera/Pinhole.hpp>
 #include <aliceVision/numeric/projection.hpp>
 #include <aliceVision/numeric/numeric.hpp>
 
@@ -95,10 +95,10 @@ void normalIntegration(const sfmData::SfMData& sfmData,
 
     if (sfmData.getPoses().size() > 0)
     {
-        for (auto& poseIt : sfmData.getPoses())
+        for (auto& [idPose, cameraPose] : sfmData.getPoses().valueRange())
         {
             // Read associated normal map :
-            image::readImage(inputPath + "/" + std::to_string(poseIt.first) + "_normals.png", normalsImPNG, image::EImageColorSpace::NO_CONVERSION);
+            image::readImage(inputPath + "/" + std::to_string(idPose) + "_normals.png", normalsImPNG, image::EImageColorSpace::NO_CONVERSION);
 
             int nbCols = normalsImPNG.cols();
             int nbRows = normalsImPNG.rows();
@@ -107,14 +107,14 @@ void normalIntegration(const sfmData::SfMData& sfmData,
             for (auto& viewIt : sfmData.getViews())
             {
                 poseId = viewIt.second->getPoseId();
-                if (poseId == poseIt.first)
+                if (poseId == idPose)
                 {
                     viewId = viewIt.first;
                     // Get intrinsics associated with this view :
                     intrinsicId = viewIt.second->getIntrinsicId();
-                    const float focalPx = sfmData.getIntrinsics().at(intrinsicId)->getParams().at(0);
-                    const float x_p = (nbCols) / 2 + sfmData.getIntrinsics().at(intrinsicId)->getParams().at(2);
-                    const float y_p = (nbRows) / 2 + sfmData.getIntrinsics().at(intrinsicId)->getParams().at(3);
+                    const float focalPx = sfmData.getIntrinsics().at(intrinsicId)->getParameters().at(0);
+                    const float x_p = (nbCols) / 2 + sfmData.getIntrinsics().at(intrinsicId)->getParameters().at(2);
+                    const float y_p = (nbRows) / 2 + sfmData.getIntrinsics().at(intrinsicId)->getParameters().at(3);
 
                     // Create K matrix
                     K(0, 0) = focalPx;
@@ -172,7 +172,7 @@ void normalIntegration(const sfmData::SfMData& sfmData,
                 nbCols = normalsImPNG2.cols();
                 nbRows = normalsImPNG2.rows();
             }
-            // Main fonction
+            // Main function
             image::Image<float> depthMap;
 
             aliceVision::image::Image<float> distanceMap;
@@ -184,10 +184,10 @@ void normalIntegration(const sfmData::SfMData& sfmData,
             // AliceVision uses distance-to-origin convention
             convertZtoDistance(depthMap, distanceMap, K);
 
-            std::string pathToDM = outputFolder + "/" + std::to_string(poseIt.first) + "_depthMap.exr";
+            std::string pathToDM = outputFolder + "/" + std::to_string(idPose) + "_depthMap.exr";
 
             // Create pose for metadata
-            const geometry::Pose3 pose = poseIt.second.getTransform();
+            const geometry::Pose3 pose = cameraPose.getTransform();
             std::shared_ptr<camera::IntrinsicBase> cam = sfmData.getIntrinsics().at(intrinsicId);
             std::shared_ptr<camera::Pinhole> camPinHole = std::dynamic_pointer_cast<camera::Pinhole>(cam);
             Mat34 P = camPinHole->getProjectiveEquivalent(pose);
@@ -219,9 +219,9 @@ void normalIntegration(const sfmData::SfMData& sfmData,
         {
             intrinsicId = sfmData.getViews().begin()->second->getIntrinsicId();
             // Get intrinsics associated with this view :
-            const float focalPx = sfmData.getIntrinsics().at(intrinsicId)->getParams().at(0);
-            const float x_p = (nbCols) / 2 + sfmData.getIntrinsics().at(intrinsicId)->getParams().at(2);
-            const float y_p = (nbRows) / 2 + sfmData.getIntrinsics().at(intrinsicId)->getParams().at(3);
+            const float focalPx = sfmData.getIntrinsics().at(intrinsicId)->getParameters().at(0);
+            const float x_p = (nbCols) / 2 + sfmData.getIntrinsics().at(intrinsicId)->getParameters().at(2);
+            const float y_p = (nbRows) / 2 + sfmData.getIntrinsics().at(intrinsicId)->getParameters().at(3);
 
             // Create K matrix
             K(0, 0) = focalPx;
@@ -260,7 +260,7 @@ void normalIntegration(const sfmData::SfMData& sfmData,
             nbRows = normalsImPNG2.rows();
         }
 
-        // Main fonction
+        // Main function
         image::Image<float> depthMap(nbCols, nbRows);
         DCTIntegration(normalsImPNG2, depthMap, perspective, K, normalsMask);
 
@@ -348,7 +348,7 @@ void DCTIntegration(const image::Image<image::RGBfColor>& normals,
         {
             double denom = 4 * (pow(sin(0.5 * M_PI * j / nbCols), 2) + pow(sin(0.5 * M_PI * i / nbRows), 2));
             denom = std::max(denom, 0.0001);
-            z_bar_bar.at<float>(i, j) = fcos.at<float>(i, j) / denom;
+            z_bar_bar.at<float>(i, j) = -fcos.at<float>(i, j) / denom;
         }
     }
 
@@ -543,10 +543,10 @@ void adjustScale(const sfmData::SfMData& sfmData, image::Image<float>& initDepth
         const sfmData::Landmark& currentLandmark = landmarks.at(currentLandmarkIndex);
         knownDepths(i) = pose.depth(currentLandmark.X);
 
-        sfmData::Observation observationInCurrentPicture = currentLandmark.observations.at(viewID);
+        sfmData::Observation observationInCurrentPicture = currentLandmark.getObservations().at(viewID);
 
-        int rowInd = observationInCurrentPicture.x(1);
-        int colInd = observationInCurrentPicture.x(0);
+        int rowInd = observationInCurrentPicture.getY();
+        int colInd = observationInCurrentPicture.getX();
 
         estimatedDepths(i) = initDepth(rowInd, colInd);
     }
@@ -576,10 +576,10 @@ void getZ0FromLandmarks(const sfmData::SfMData& sfmData,
     {
         size_t currentLandmarkIndex = visibleLandmarks.at(i);
         const sfmData::Landmark& currentLandmark = landmarks.at(currentLandmarkIndex);
-        sfmData::Observation observationInCurrentPicture = currentLandmark.observations.at(viewID);
+        sfmData::Observation observationInCurrentPicture = currentLandmark.getObservations().at(viewID);
 
-        int rowInd = observationInCurrentPicture.x(1);
-        int colInd = observationInCurrentPicture.x(0);
+        int rowInd = observationInCurrentPicture.getY();
+        int colInd = observationInCurrentPicture.getX();
 
         if (mask(rowInd, colInd) > 0.7)
         {
