@@ -5,16 +5,19 @@
 // You can obtain one at https://mozilla.org/MPL/2.0/.
 
 #include "LocalBundleAdjustmentGraph.hpp"
+
 #include <aliceVision/stl/stl.hpp>
+#include <aliceVision/system/Logger.hpp>
 #include <aliceVision/sfmData/SfMData.hpp>
-#include <boost/filesystem.hpp>
+#include <aliceVision/utils/filesIO.hpp>
 
 #include <lemon/bfs.h>
 
 #include <fstream>
+#include <filesystem>
 #include <algorithm>
 
-namespace fs = boost::filesystem;
+namespace fs = std::filesystem;
 
 namespace aliceVision {
 namespace sfm {
@@ -28,7 +31,7 @@ LocalBundleAdjustmentGraph::LocalBundleAdjustmentGraph(const sfmData::SfMData& s
 
         IntrinsicHistory intrinsicHistory;
         intrinsicHistory.nbPoses = 0;
-        intrinsicHistory.focalLength = intrinsicPtr->getParams().at(0);
+        intrinsicHistory.focalLength = intrinsicPtr->getParameters().at(0);
         intrinsicHistory.isConstant = intrinsicPtr->isLocked();
 
         _intrinsicsHistory[intrinsicId].push_back(intrinsicHistory);
@@ -59,16 +62,18 @@ void LocalBundleAdjustmentGraph::setAllParametersToRefine(const sfmData::SfMData
     _statePerLandmarkId.clear();
 
     // poses
-    for (sfmData::Poses::const_iterator itPose = sfmData.getPoses().begin(); itPose != sfmData.getPoses().end(); ++itPose)
-        _statePerPoseId[itPose->first] = BundleAdjustment::EParameterState::REFINED;
+    for (const auto & [poseId, _] : sfmData.getPoses())
+    {
+        _statePerPoseId[poseId] = EEstimatorParameterState::REFINED;
+    }
 
-    // instrinsics
+    // intrinsics
     for (const auto& itIntrinsic : sfmData.getIntrinsics())
-        _statePerIntrinsicId[itIntrinsic.first] = BundleAdjustment::EParameterState::REFINED;
+        _statePerIntrinsicId[itIntrinsic.first] = EEstimatorParameterState::REFINED;
 
     // landmarks
     for (const auto& itLandmark : sfmData.getLandmarks())
-        _statePerLandmarkId[itLandmark.first] = BundleAdjustment::EParameterState::REFINED;
+        _statePerLandmarkId[itLandmark.first] = EEstimatorParameterState::REFINED;
 }
 
 void LocalBundleAdjustmentGraph::saveIntrinsicsToHistory(const sfmData::SfMData& sfmData)
@@ -98,7 +103,7 @@ void LocalBundleAdjustmentGraph::saveIntrinsicsToHistory(const sfmData::SfMData&
 
         IntrinsicHistory intrinsicHistory;
         intrinsicHistory.nbPoses = intrinsicUsage[intrinsicId];
-        intrinsicHistory.focalLength = intrinsicPtr->getParams().at(0);
+        intrinsicHistory.focalLength = intrinsicPtr->getParameters().at(0);
         intrinsicHistory.isConstant = isFocalLengthConstant(intrinsicId);
 
         _intrinsicsHistory.at(intrinsicId).push_back(intrinsicHistory);
@@ -107,9 +112,10 @@ void LocalBundleAdjustmentGraph::saveIntrinsicsToHistory(const sfmData::SfMData&
 
 void LocalBundleAdjustmentGraph::exportIntrinsicsHistory(const std::string& folder, const std::string& filename)
 {
-    ALICEVISION_LOG_DEBUG("Exporting intrinsics history...");
+    const std::string filepath = (fs::path(folder) / filename).string();
+    ALICEVISION_LOG_DEBUG("Exporting intrinsics history: " << filepath);
     std::ofstream os;
-    os.open((fs::path(folder) / filename).string(), std::ios::app);
+    os.open(filepath, std::ios::app);
     os.seekp(0, std::ios::end);  // put the cursor at the end
 
     for (const auto& intrinsicHistoryPair : _intrinsicsHistory)
@@ -215,15 +221,15 @@ int LocalBundleAdjustmentGraph::getViewDistance(const IndexT viewId) const
     return _distancePerViewId.at(viewId);
 }
 
-BundleAdjustment::EParameterState LocalBundleAdjustmentGraph::getStateFromDistance(int distance) const
+EEstimatorParameterState LocalBundleAdjustmentGraph::getStateFromDistance(int distance) const
 {
     if (distance >= 0 && distance <= _graphDistanceLimit)  // [0; D]
-        return BundleAdjustment::EParameterState::REFINED;
+        return EEstimatorParameterState::REFINED;
     else if (distance == _graphDistanceLimit + 1)  // {D+1}
-        return BundleAdjustment::EParameterState::CONSTANT;
+        return EEstimatorParameterState::CONSTANT;
 
     // [-inf; 0[ U [D+2; +inf.[  (-1: not connected to the new views)
-    return BundleAdjustment::EParameterState::IGNORED;
+    return EEstimatorParameterState::IGNORED;
 }
 
 void LocalBundleAdjustmentGraph::updateGraphWithNewViews(const sfmData::SfMData& sfmData,
@@ -353,8 +359,10 @@ void LocalBundleAdjustmentGraph::computeGraphDistances(const sfmData::SfMData& s
     }
 }
 
-void LocalBundleAdjustmentGraph::convertDistancesToStates(const sfmData::SfMData& sfmData)
+void LocalBundleAdjustmentGraph::convertDistancesToStates(sfmData::SfMData& sfmData)
 {
+    sfmData.resetParameterStates();
+
     // reset the maps
     _statePerPoseId.clear();
     _statePerIntrinsicId.clear();
@@ -372,38 +380,45 @@ void LocalBundleAdjustmentGraph::convertDistancesToStates(const sfmData::SfMData
     //    - Ignored <=> else (dist = -1 U [D+2; +inf.[)
     //  - an intrinsic is set to:
     //    - Refined by default
-    //    - Constant <=> its focal lenght is considered as stable in its W last saved values
+    //    - Constant <=> its focal length is considered as stable in its W last saved values
     //    according to all of its values.
     //  - a landmarks is set to:
     //    - Ignored by default
     //    - Refined <=> its connected to a refined camera
 
     // poses
-    for (const auto& posePair : sfmData.getPoses())
+    for (auto& [poseId, pose] : sfmData.getPoses().valueRange())
     {
-        const IndexT poseId = posePair.first;
         const int distance = getPoseDistance(poseId);
-        const BundleAdjustment::EParameterState state = getStateFromDistance(distance);
+        const EEstimatorParameterState state = getStateFromDistance(distance);
+
+        pose.setState(state);
 
         _statePerPoseId[poseId] = state;
     }
 
-    // instrinsics
+    // intrinsics
     checkFocalLengthsConsistency(kWindowSize, kStdevPercentage);
 
-    for (const auto& itIntrinsic : sfmData.getIntrinsics())
+    for (auto& itIntrinsic : sfmData.getIntrinsics())
     {
         if (isFocalLengthConstant(itIntrinsic.first))
-            _statePerIntrinsicId[itIntrinsic.first] = BundleAdjustment::EParameterState::CONSTANT;
+        {
+            itIntrinsic.second->setState(EEstimatorParameterState::CONSTANT);
+            _statePerIntrinsicId[itIntrinsic.first] = EEstimatorParameterState::CONSTANT;
+        }
         else
-            _statePerIntrinsicId[itIntrinsic.first] = BundleAdjustment::EParameterState::REFINED;
+        {
+            itIntrinsic.second->setState(EEstimatorParameterState::REFINED);
+            _statePerIntrinsicId[itIntrinsic.first] = EEstimatorParameterState::REFINED;
+        }
     }
 
     // landmarks
-    for (const auto& itLandmark : sfmData.getLandmarks())
+    for (auto& itLandmark : sfmData.getLandmarks())
     {
         const IndexT landmarkId = itLandmark.first;
-        const sfmData::Observations& observations = itLandmark.second.observations;
+        const sfmData::Observations& observations = itLandmark.second.getObservations();
 
         assert(observations.size() >= 2);
 
@@ -411,21 +426,27 @@ void LocalBundleAdjustmentGraph::convertDistancesToStates(const sfmData::SfMData
         for (const auto& observationIt : observations)
         {
             const int distance = getViewDistance(observationIt.first);
-            const BundleAdjustment::EParameterState viewState = getStateFromDistance(distance);
+            const EEstimatorParameterState viewState = getStateFromDistance(distance);
             states.at(static_cast<std::size_t>(viewState)) = true;
         }
 
         // in the general case, a landmark can NOT have observations from refined AND ignored cameras.
-        // in pratice, there is a minimal number of common points to declare the connection between images.
+        // in practice, there is a minimal number of common points to declare the connection between images.
         // so we can have some points that are not declared in the graph of cameras connections.
         // for these particular cases, we can have landmarks with refined AND ignored cameras.
         // in this particular case, we prefer to ignore the landmark to avoid wrong/unconstraint refinements.
 
-        if (!states.at(static_cast<std::size_t>(BundleAdjustment::EParameterState::REFINED)) ||
-            states.at(static_cast<std::size_t>(BundleAdjustment::EParameterState::IGNORED)))
-            _statePerLandmarkId[landmarkId] = BundleAdjustment::EParameterState::IGNORED;
+        if (!states.at(static_cast<std::size_t>(EEstimatorParameterState::REFINED)) ||
+            states.at(static_cast<std::size_t>(EEstimatorParameterState::IGNORED)))
+        {
+            itLandmark.second.state = EEstimatorParameterState::IGNORED;
+            _statePerLandmarkId[landmarkId] = EEstimatorParameterState::IGNORED;
+        }
         else
-            _statePerLandmarkId[landmarkId] = BundleAdjustment::EParameterState::REFINED;
+        {
+            itLandmark.second.state = EEstimatorParameterState::REFINED;
+            _statePerLandmarkId[landmarkId] = EEstimatorParameterState::REFINED;
+        }
     }
 }
 
@@ -459,7 +480,7 @@ std::vector<Pair> LocalBundleAdjustmentGraph::getNewEdges(const sfmData::SfMData
         // retrieve the common track Ids
         for (IndexT landmarkId : newViewLandmarks)
         {
-            for (const auto& observations : sfmData.getLandmarks().at(landmarkId).observations)
+            for (const auto& observations : sfmData.getLandmarks().at(landmarkId).getObservations())
             {
                 if (observations.first == viewId)
                     continue;  // do not compare an observation with itself
@@ -593,7 +614,7 @@ double LocalBundleAdjustmentGraph::standardDeviation(const std::vector<T>& data)
 
 void LocalBundleAdjustmentGraph::drawGraph(const sfmData::SfMData& sfmData, const std::string& folder, const std::string& nameComplement)
 {
-    if (!fs::exists(folder))
+    if (!utils::exists(folder))
         fs::create_directory(folder);
 
     std::stringstream dotStream;
