@@ -7,14 +7,16 @@
 
 #pragma once
 
+#include <aliceVision/sfmData/SharedPtrMap.hpp>
 #include <aliceVision/sfmData/CameraPose.hpp>
 #include <aliceVision/sfmData/Landmark.hpp>
 #include <aliceVision/sfmData/Constraint2D.hpp>
+#include <aliceVision/sfmData/ConstraintPoint.hpp>
 #include <aliceVision/sfmData/RotationPrior.hpp>
+#include <aliceVision/sfmData/SurveyPoint.hpp>
 #include <aliceVision/sfmData/View.hpp>
 #include <aliceVision/sfmData/Rig.hpp>
 #include <aliceVision/camera/camera.hpp>
-#include <aliceVision/sfmData/HashMapPtr.hpp>
 #include <aliceVision/types.hpp>
 
 #include <stdexcept>
@@ -25,35 +27,43 @@ namespace aliceVision {
 namespace sfmData {
 
 /// Define a collection of View
-using Views = HashMapPtr<View>;
+using Views = SharedPtrMap<View>;
 
 /// Define a collection of Image Info
-using ImageInfos = HashMapPtr<ImageInfo>;
+using ImageInfos = SharedPtrMap<ImageInfo>;
 
 /// Define a collection of Pose (indexed by view.getPoseId())
-using Poses = HashMap<IndexT, CameraPose>;
+using Poses = SharedPtrMap<CameraPose>;
 
 /// Define a collection of IntrinsicParameter (indexed by view.getIntrinsicId())
-using Intrinsics = HashMapPtr<camera::IntrinsicBase>;
+using Intrinsics = SharedPtrMap<camera::IntrinsicBase>;
 
 /// Define a collection of landmarks are indexed by their TrackId
-using Landmarks = HashMap<IndexT, Landmark>;
+using Landmarks = std::map<IndexT, Landmark>;
 
 /// Define a collection of Rig
 using Rigs = std::map<IndexT, Rig>;
 
 /// Define uncertainty per pose
-using PosesUncertainty = HashMap<IndexT, Vec6>;
+using PosesUncertainty = std::map<IndexT, Vec6>;
 
 /// Define uncertainty per landmark
-using LandmarksUncertainty = HashMap<IndexT, Vec3>;
+using LandmarksUncertainty = std::map<IndexT, Vec3>;
 
 /// Define a collection of constraints
 using Constraints2D = std::vector<Constraint2D>;
 
+/// Define a collection of constraints
+using ConstraintsPoint = std::map<IndexT, ConstraintPoint>;
+
+/// Define a collection of surveyed points
+using SurveyPoints = std::map<IndexT, std::vector<SurveyPoint>>;
+
 /// Define a collection of rotation priors
 using RotationPriors = std::vector<RotationPrior>;
 
+
+
 /**
  * @brief SfMData container
  * Store structure and camera properties
@@ -65,13 +75,24 @@ class SfMData
     PosesUncertainty _posesUncertainty;
     /// Uncertainty per landmark
     LandmarksUncertainty _landmarksUncertainty;
-    /// 2D Constraints
-    Constraints2D constraints2d;
-    /// Rotation priors
-    RotationPriors rotationpriors;
+
+    SfMData() = default;
+    
+    /**
+     * @brief Copy constructor 
+     * @param other the copied sfmData
+     * @param unused a parameter to make sure we explicitly want this copy (for legacy)
+     * 
+    */
+    SfMData(const SfMData & other, bool unused);
+
+    /**
+     * @brief Copy constructor 
+     * Use a bounding box to restrict the copied landmarks to the selected region
+    */
+    SfMData(const SfMData & other, const Eigen::Vector3d & bbMin, const Eigen::Vector3d & bbMax);
 
     // Operators
-
     bool operator==(const SfMData& other) const;
 
     inline bool operator!=(const SfMData& other) const { return !(*this == other); }
@@ -117,22 +138,36 @@ class SfMData
      * @brief Get landmarks
      * @return landmarks
      */
-    const Landmarks& getLandmarks() const { return _structure; }
-    Landmarks& getLandmarks() { return _structure; }
+    const Landmarks& getLandmarks() const { return _landmarks; }
+    Landmarks& getLandmarks() { return _landmarks; }
 
     /**
      * @brief Get Constraints2D
      * @return Constraints2D
      */
-    const Constraints2D& getConstraints2D() const { return constraints2d; }
-    Constraints2D& getConstraints2D() { return constraints2d; }
+    const Constraints2D& getConstraints2D() const { return _constraints2d; }
+    Constraints2D& getConstraints2D() { return _constraints2d; }
+
+    /**
+     * @brief Get ConstraintsPoints
+     * @return ConstraintsPoints
+     */
+    const ConstraintsPoint& getConstraintsPoint() const { return _constraintsPoint; }
+    ConstraintsPoint& getConstraintsPoint() { return _constraintsPoint; }
+
+    /**
+     * @brief Get SurveyPoints
+     * @return SurveyPoints
+     */
+    const SurveyPoints & getSurveyPoints() const { return _surveyPoints; }
+    SurveyPoints& getSurveyPoints() { return _surveyPoints; }
 
     /**
      * @brief Get RotationPriors
      * @return RotationPriors
      */
-    const RotationPriors& getRotationPriors() const { return rotationpriors; }
-    RotationPriors& getRotationPriors() { return rotationpriors; }
+    const RotationPriors& getRotationPriors() const { return _rotationpriors; }
+    RotationPriors& getRotationPriors() { return _rotationpriors; }
 
     /**
      * @brief Get relative features folder paths
@@ -172,7 +207,7 @@ class SfMData
 
     /**
      * @brief Return a pointer to an intrinsic if available or nullptr otherwise.
-     * @param[in] intrinsicId
+     * @param[in] intrinsicId the ID of the intrinsic to get
      */
     const camera::IntrinsicBase* getIntrinsicPtr(IndexT intrinsicId) const
     {
@@ -183,7 +218,7 @@ class SfMData
 
     /**
      * @brief Return a pointer to an intrinsic if available or nullptr otherwise.
-     * @param[in] intrinsicId
+     * @param[in] intrinsicId the ID of the intrinsic to get
      */
     camera::IntrinsicBase* getIntrinsicPtr(IndexT intrinsicId)
     {
@@ -194,9 +229,9 @@ class SfMData
 
     /**
      * @brief Return a shared pointer to an intrinsic if available or nullptr otherwise.
-     * @param[in] intrinsicId
+     * @param[in] intrinsicId the ID of the intrinsic to get
      */
-    std::shared_ptr<camera::IntrinsicBase> getIntrinsicsharedPtr(IndexT intrinsicId)
+    std::shared_ptr<camera::IntrinsicBase> getIntrinsicSharedPtr(IndexT intrinsicId)
     {
         if (_intrinsics.count(intrinsicId))
             return _intrinsics.at(intrinsicId);
@@ -205,15 +240,55 @@ class SfMData
 
     /**
      * @brief Return a shared pointer to an intrinsic if available or nullptr otherwise.
-     * @param[in] intrinsicId
+     * @param[in] v the view to get the intrinsic from
      */
-    const std::shared_ptr<camera::IntrinsicBase> getIntrinsicsharedPtr(IndexT intrinsicId) const
+    std::shared_ptr<camera::IntrinsicBase> getIntrinsicSharedPtr(const View& v)
+    {
+        IndexT intrinsicId = v.getIntrinsicId();
+
+        if (_intrinsics.count(intrinsicId))
+            return _intrinsics.at(intrinsicId);
+        return nullptr;
+    }
+
+    /**
+     * @brief Return a shared pointer to an intrinsic if available or nullptr otherwise.
+     * @param[in] intrinsicId the ID of the intrinsic to get
+     */
+    const std::shared_ptr<camera::IntrinsicBase> getIntrinsicSharedPtr(IndexT intrinsicId) const
     {
         if (_intrinsics.count(intrinsicId))
             return _intrinsics.at(intrinsicId);
         return nullptr;
     }
 
+    /**
+     * @brief Return a shared pointer to an intrinsic if available or nullptr otherwise.
+     * @param[in] v the view to get the intrinsic from
+     */
+    const std::shared_ptr<camera::IntrinsicBase> getIntrinsicSharedPtr(const View& v) const
+    {
+        IndexT intrinsicId = v.getIntrinsicId();
+
+        if (_intrinsics.count(intrinsicId))
+            return _intrinsics.at(intrinsicId);
+        return nullptr;
+    }
+
+    /**
+     * @brief Gives the intrinsic of the input intrinsic id.
+     * @param[in] intrinsicId The given intrinsic ID
+     * @return the corresponding intrinsic reference
+     */
+    const camera::IntrinsicBase& getIntrinsic(IndexT intrinsicId) const { return *(_intrinsics.at(intrinsicId)); }
+
+    /**
+     * @brief Gives the intrinsic of the input intrinsic id.
+     * @param[in] intrinsicId The given intrinsic ID
+     * @return the corresponding intrinsic reference
+     */
+    camera::IntrinsicBase& getIntrinsic(IndexT intrinsicId) { return *(_intrinsics.at(intrinsicId)); }
+
     /**
      * @brief Get a set of views keys
      * @return set of views keys
@@ -229,15 +304,12 @@ class SfMData
     /**
      * @brief Check if the given view have defined intrinsic and pose
      * @param[in] view The given view
-     * @return true if intrinsic and pose defined
+     * @return true if intrinsic  defined
      */
-    bool isPoseAndIntrinsicDefined(const View* view) const
+    bool isIntrinsicDefined(const View & view) const
     {
-        if (view == nullptr)
-            return false;
-        return (view->getIntrinsicId() != UndefinedIndexT && view->getPoseId() != UndefinedIndexT &&
-                (!view->isPartOfRig() || view->isPoseIndependant() || getRigSubPose(*view).status != ERigSubPoseStatus::UNINITIALIZED) &&
-                _intrinsics.find(view->getIntrinsicId()) != _intrinsics.end() && _poses.find(view->getPoseId()) != _poses.end());
+        return (view.getIntrinsicId() != UndefinedIndexT  
+                && _intrinsics.find(view.getIntrinsicId()) != _intrinsics.end());
     }
 
     /**
@@ -245,6 +317,70 @@ class SfMData
      * @param[in] viewID The given viewID
      * @return true if intrinsic and pose defined
      */
+    bool isIntrinsicDefined(IndexT viewId) const 
+    { 
+        return isIntrinsicDefined(*_views.at(viewId)); 
+    }
+
+    /**
+     * @brief Check if the given view have defined intrinsi
+     * @param[in] view The given view
+     * @return true if intrinsic and pose defined
+     */
+    bool isPoseAndIntrinsicDefined(const View & view) const
+    {        
+        const IndexT poseId = view.getPoseId();
+        if (poseId == UndefinedIndexT)
+        {
+            return false;
+        }
+
+        const IndexT intrinsicId = view.getIntrinsicId();
+        if (intrinsicId == UndefinedIndexT)
+        {
+            return false;
+        }
+
+        if (_intrinsics.find(view.getIntrinsicId()) == _intrinsics.end())
+        {
+            return false;
+        }
+        
+        auto it = _poses.find(poseId);
+        if (it == _poses.end())
+        {
+            return false;
+        }
+
+        bool rigValid = ((!view.isPartOfRig() || view.isPoseIndependant() || getRigSubPose(view).status != ERigSubPoseStatus::UNINITIALIZED));
+        if (!rigValid)
+        {
+            return false;
+        }
+
+        return true;
+    }
+
+    /**
+     * @brief Check if the given view have defined intrinsi
+     * @param[in] view The given view
+     * @return true if intrinsic and pose defined
+     */
+    bool isPoseAndIntrinsicDefined(const View* view) const
+    {
+        if (view == nullptr)
+        {
+            return false;
+        }
+
+        return isPoseAndIntrinsicDefined(*view);
+    }
+
+    /**
+     * @brief Check if the given view have defined intrinsic and pose
+     * @param[in] viewID The given view ID
+     * @return true if intrinsic and pose defined
+     */
     bool isPoseAndIntrinsicDefined(IndexT viewId) const { return isPoseAndIntrinsicDefined(_views.at(viewId).get()); }
 
     /**
@@ -256,27 +392,53 @@ class SfMData
 
     /**
      * @brief Gives the view of the input view id.
-     * @param[in] viewId The given view id
+     * @param[in] viewId The given view ID
      * @return the corresponding view reference
      */
     const View& getView(IndexT viewId) const { return *(_views.at(viewId)); }
+
+    /**
+     * @brief Gives the view of the input view id.
+     * @param[in] viewId The given view ID
+     * @return the corresponding view reference
+     */
     View& getView(IndexT viewId) { return *(_views.at(viewId)); }
 
     /**
      * @brief Gives the view of the input view id.
-     * @param[in] viewId The given view id
+     * @param[in] viewId The given view ID
      * @return the corresponding view ptr
      */
     const View::ptr getViewPtr(IndexT viewId) const { return _views.at(viewId).get(); }
+
+    /**
+     * @brief Gives the view of the input view id.
+     * @param[in] viewId The given view ID
+     * @return the corresponding view ptr
+     */
     View::ptr getViewPtr(IndexT viewId) { return _views.at(viewId).get(); }
 
     /**
      * @brief Gives the view of the input view id.
-     * @param[in] viewId The given view id
+     * @param[in] viewId The given view ID
      * @return the corresponding view ptr
      */
     View::sptr getViewSharedPtr(IndexT viewId) { return _views.at(viewId); }
 
+    /**
+     * @brief Gives the view of the input view id.
+     * @param[in] viewId The given view ID
+     * @return the corresponding view ptr
+     */
+    const View::sptr getViewSharedPtr(IndexT viewId) const { return _views.at(viewId); }
+
+    /**
+     * @brief Retrieve the view id in the sfmData from the image filename.
+     * @param[in] name the image name to find (uid or filename or path)
+     * @return a view Id if a view is found or UndefinedIndexT
+     */
+    IndexT findView(const std::string & imageName) const;
+
     /**
      * @brief Gives the pose of the input view. If this view is part of a rig, it returns rigPose + rigSubPose.
      * @param[in] view The given view
@@ -289,7 +451,7 @@ class SfMData
         // check the view has valid pose / rig etc
         if (!view.isPartOfRig() || view.isPoseIndependant())
         {
-            return _poses.at(view.getPoseId());
+            return *_poses.at(view.getPoseId());
         }
 
         // get the pose of the rig
@@ -305,7 +467,13 @@ class SfMData
      * @brief  Gives the pose with the given pose id.
      * @param[in] poseId The given pose id
      */
-    const CameraPose& getAbsolutePose(IndexT poseId) const { return _poses.at(poseId); }
+    const CameraPose& getAbsolutePose(IndexT poseId) const { return *_poses.at(poseId); }
+
+    /**
+     * @brief  Gives the pose with the given pose id.
+     * @param[in] poseId The given pose id
+     */
+    CameraPose & getAbsolutePose(IndexT poseId) { return *_poses.at(poseId); }
 
     /**
      * @brief Get the rig of the given view
@@ -448,10 +616,13 @@ class SfMData
      * @param[in] poseId The given poseId
      * @param[in] pose The given pose
      */
-    void setAbsolutePose(IndexT poseId, const CameraPose& pose) { _poses[poseId] = pose; }
+    void setAbsolutePose(IndexT poseId, const CameraPose& pose) 
+    { 
+        _poses.assign(poseId, pose); 
+    }
 
     /**
-     * @brief Erase yhe pose for the given poseId
+     * @brief Erase the pose for the given poseId
      * @param[in] poseId The given poseId
      * @param[in] noThrow If false, throw exception if no pose found
      */
@@ -459,9 +630,13 @@ class SfMData
     {
         auto it = _poses.find(poseId);
         if (it != _poses.end())
+        {
             _poses.erase(it);
+        }
         else if (!noThrow)
+        {
             throw std::out_of_range(std::string("Can't erase unfind pose ") + std::to_string(poseId));
+        }
     }
 
     /**
@@ -470,11 +645,15 @@ class SfMData
     void resetRigs()
     {
         for (auto rigIt : _rigs)
+        {
             rigIt.second.reset();
+        }
     }
 
     /**
      * @brief Add an ancestor image
+     * @param[in] ancestorId The ID of the ancestor that will be added
+     * @param[in] image The image that will be added as the ancestor
      */
     void addAncestor(IndexT ancestorId, std::shared_ptr<ImageInfo> image) { _ancestors.emplace(ancestorId, image); }
 
@@ -487,9 +666,22 @@ class SfMData
 
     void clear();
 
+    /**
+     * @Brief For all required items, update the
+     * state with respect to the associated lock
+     */
+    void resetParameterStates();
+
+    /**
+     * Compute the landmarks axis aligned bounding box
+     * @param bbMin the output minimal values of the bounding box
+     * @param bbMax the output maximal values of the bounding box
+    */
+    void getBoundingBox(Eigen::Vector3d & bbMin, Eigen::Vector3d & bbMax);
+
   private:
     /// Structure (3D points with their 2D observations)
-    Landmarks _structure;
+    Landmarks _landmarks;
     /// Considered camera intrinsics (indexed by view.getIntrinsicId())
     Intrinsics _intrinsics;
     /// Considered views
@@ -506,13 +698,24 @@ class SfMData
     Poses _poses;
     /// Considered rigs
     Rigs _rigs;
+    /// 2D Constraints
+    Constraints2D _constraints2d;
+    /// Point constraints
+    ConstraintsPoint _constraintsPoint;
+    /// Rotation priors
+    RotationPriors _rotationpriors;
+    /// Survey points
+    SurveyPoints _surveyPoints;
 
     /**
      * @brief Get Rig pose of a given camera view
      * @param[in] view The given view
      * @return Rig pose of the given camera view
      */
-    const CameraPose& getRigPose(const View& view) const { return _poses.at(view.getPoseId()); }
+    const CameraPose& getRigPose(const View& view) const 
+    { 
+        return *_poses.at(view.getPoseId()); 
+    }
 
     /**
      * @brief Get Rig subPose of a given camera view
@@ -531,7 +734,10 @@ class SfMData
      * @param[in] view The given view
      * @return Rig pose of the given camera view
      */
-    CameraPose& getRigPose(const View& view) { return _poses.at(view.getPoseId()); }
+    CameraPose& getRigPose(const View& view) 
+    { 
+        return *_poses.at(view.getPoseId()); 
+    }
 
     /**
      * @brief Get Rig subPose of a given camera view
