@@ -12,11 +12,12 @@
 #include <Alembic/AbcCoreOgawa/All.h>
 #include <Alembic/Abc/OObject.h>
 
-#include <boost/filesystem.hpp>
+#include <aliceVision/camera/Equidistant.hpp>
 
 #include <numeric>
+#include <filesystem>
 
-namespace fs = boost::filesystem;
+namespace fs = std::filesystem;
 
 namespace aliceVision {
 namespace sfmDataIO {
@@ -37,6 +38,7 @@ struct AlembicExporter::DataImpl
         _mvgCloud = Alembic::AbcGeom::OXform(_mvgRoot, "mvgCloud");
         _mvgPointCloud = Alembic::AbcGeom::OXform(_mvgCloud, "mvgPointCloud");
         _mvgAncestors = Alembic::AbcGeom::OXform(_mvgRoot, "mvgAncestors");
+        _mvgSurveys = Alembic::AbcGeom::OXform(_mvgCloud, "mvgSurveys");
 
         // add version as custom property
         const std::vector<::uint32_t> abcVersion = {
@@ -77,6 +79,7 @@ struct AlembicExporter::DataImpl
     Alembic::AbcGeom::OXform _mvgAncestors;
     Alembic::AbcGeom::OXform _mvgCloud;
     Alembic::AbcGeom::OXform _mvgPointCloud;
+    Alembic::AbcGeom::OXform _mvgSurveys;
     Alembic::AbcGeom::OXform _xform;
     Alembic::AbcGeom::OCamera _camObj;
     Alembic::AbcGeom::OUInt32ArrayProperty _propSensorSize_pix;
@@ -112,6 +115,8 @@ void AlembicExporter::DataImpl::addCamera(const std::string& name,
     if (pose != nullptr)
     {
         OBoolProperty(userProps, "mvg_poseLocked").set(pose->isLocked());
+        OBoolProperty(userProps, "mvg_rotationOnly").set(pose->isRotationOnly());
+        OBoolProperty(userProps, "mvg_removable").set(pose->isRemovable());
 
         // Convert from computer vision convention to computer graphics (opengl-like)
         Eigen::Matrix4d M = Eigen::Matrix4d::Identity();
@@ -184,15 +189,19 @@ void AlembicExporter::DataImpl::addCamera(const std::string& name,
     {
         CameraSample camSample;
 
+        const Vec2 & scale = intrinsicCasted->getScale();
+        const Vec2 & offset = intrinsicCasted->getOffset();
+        
         // Take the max of the image size to handle the case where the image is in portrait mode
         const float imgWidth = intrinsicCasted->w();
         const float imgHeight = intrinsicCasted->h();
         const float sensorWidth = intrinsicCasted->sensorWidth();
         const float sensorHeight = intrinsicCasted->sensorHeight();
         const float sensorWidth_pix = std::max(imgWidth, imgHeight);
-        const float focalLengthX_pix = static_cast<const float>(intrinsicCasted->getScale()(0));
-        const float focalLengthY_pix = static_cast<const float>(intrinsicCasted->getScale()(1));
+        const float focalLengthX_pix = static_cast<const float>(scale(0));
+        const float focalLengthY_pix = static_cast<const float>(scale(1));
         const float focalLength_mm = sensorWidth * focalLengthX_pix / sensorWidth_pix;
+        const float shiftX_mm = sensorWidth * focalLengthX_pix / sensorWidth_pix;
         const float squeeze = focalLengthX_pix / focalLengthY_pix;
         const float pix2mm = sensorWidth / sensorWidth_pix;
 
@@ -201,26 +210,32 @@ void AlembicExporter::DataImpl::addCamera(const std::string& name,
         // Following values are in cm, hence the 0.1 multiplier
         const float haperture_cm = static_cast<const float>(0.1 * imgWidth * pix2mm);
         const float vaperture_cm = static_cast<const float>(0.1 * imgHeight * pix2mm);
+        const float offsetX_cm = static_cast<const float>(0.1 * offset(0) * pix2mm);
+        const float offsetY_cm = static_cast<const float>(0.1 * (-offset(1)) * pix2mm);
 
         camSample.setFocalLength(focalLength_mm);
         camSample.setHorizontalAperture(haperture_cm);
         camSample.setVerticalAperture(vaperture_cm);
         camSample.setLensSqueezeRatio(squeeze);
+        camSample.setHorizontalFilmOffset(offsetX_cm);
+        camSample.setVerticalFilmOffset(offsetY_cm);
 
         // Add sensor width (largest image side) in pixels as custom property
         std::vector<::uint32_t> sensorSize_pix = {intrinsicCasted->w(), intrinsicCasted->h()};
         std::vector<double> sensorSize_mm = {sensorWidth, sensorHeight};
 
-        double initialFocalLength =
-          (intrinsicCasted->getInitialScale().x() > 0) ? (intrinsicCasted->getInitialScale().x() * sensorWidth / double(intrinsicCasted->w())) : -1;
+        double initialFocalLength = intrinsicCasted->getInitialFocalLength();
 
         OUInt32ArrayProperty(userProps, "mvg_sensorSizePix").set(sensorSize_pix);
         ODoubleArrayProperty(userProps, "mvg_sensorSizeMm").set(sensorSize_mm);
         OStringProperty(userProps, "mvg_intrinsicType").set(intrinsicCasted->getTypeStr());
         OStringProperty(userProps, "mvg_intrinsicInitializationMode").set(camera::EInitMode_enumToString(intrinsicCasted->getInitializationMode()));
         ODoubleProperty(userProps, "mvg_initialFocalLength").set(initialFocalLength);
+        OStringProperty(userProps, "mvg_intrinsicSerialNumber").set(intrinsicCasted->serialNumber());
         OBoolProperty(userProps, "mvg_intrinsicLocked").set(intrinsicCasted->isLocked());
         OBoolProperty(userProps, "mvg_intrinsicPixelRatioLocked").set(intrinsicCasted->isRatioLocked());
+        OBoolProperty(userProps, "mvg_intrinsicOffsetLocked").set(intrinsicCasted->isOffsetLocked());
+        OBoolProperty(userProps, "mvg_intrinsicScaleLocked").set(intrinsicCasted->isScaleLocked());
         OStringProperty(userProps, "mvg_intrinsicDistortionInitializationMode")
           .set(camera::EInitMode_enumToString(intrinsicCasted->getDistortionInitializationMode()));
 
@@ -231,20 +246,34 @@ void AlembicExporter::DataImpl::addCamera(const std::string& name,
             std::vector<double> params = {scale(0), scale(1), offset(0), offset(1)};
             ODoubleArrayProperty(userProps, "mvg_intrinsicParams").set(params);
         }
+
         // Distortion parameters
+        camera::EDISTORTION distortionType = camera::EDISTORTION::DISTORTION_NONE;
         std::shared_ptr<camera::Distortion> distortion = intrinsicCasted->getDistortion();
         if (distortion)
         {
+            distortionType = distortion->getType();
             ODoubleArrayProperty(userProps, "mvg_distortionParams").set(distortion->getParameters());
+            OBoolProperty(userProps, "mvg_distortionLocked").set(distortion->isLocked());
         }
+
         // Undistortion parameters and offset
+        camera::EUNDISTORTION undistortionType = camera::EUNDISTORTION::UNDISTORTION_NONE;
         std::shared_ptr<camera::Undistortion> undistortion = intrinsicCasted->getUndistortion();
         if (undistortion)
         {
+            undistortionType = undistortion->getType();
             ODoubleArrayProperty(userProps, "mvg_undistortionParams").set(undistortion->getParameters());
             ODoubleProperty(userProps, "mvg_undistortionOffsetX").set(undistortion->getOffset().x());
             ODoubleProperty(userProps, "mvg_undistortionOffsetY").set(undistortion->getOffset().y());
+            ODoubleProperty(userProps, "mvg_undistortionDiagonal").set(undistortion->getDiagonal());
+            ODoubleProperty(userProps, "mvg_undistortionPixelAspectRatio").set(undistortion->getPixelAspectRatio());
+            OBoolProperty(userProps, "mvg_undistortionDesqueezed").set(undistortion->isDesqueezed());
+            OBoolProperty(userProps, "mvg_undistortionLocked").set(undistortion->isLocked());
         }
+        
+        OStringProperty(userProps, "mvg_distortionType").set(EDISTORTION_enumToString(distortionType));
+        OStringProperty(userProps, "mvg_undistortionType").set(EUNDISTORTION_enumToString(undistortionType));
 
         camObj.getSchema().set(camSample);
     }
@@ -333,6 +362,11 @@ void AlembicExporter::addSfM(const sfmData::SfMData& sfmData, ESfMData flagsPart
                      (flagsPart & ESfMData::OBSERVATIONS_WITH_FEATURES));
     }
 
+    if (flagsPart & ESfMData::SURVEYS)
+    {
+        addSurveys(sfmData.getSurveyPoints());
+    }
+
     if (flagsPart & ESfMData::VIEWS || flagsPart & ESfMData::EXTRINSICS)
     {
         std::map<IndexT, std::map<IndexT, std::vector<IndexT>>> rigsViewIds;  // map<rigId,map<poseId,viewId>>
@@ -372,11 +406,11 @@ void AlembicExporter::addSfMSingleCamera(const sfmData::SfMData& sfmData, const
 {
     const std::string name = fs::path(view.getImage().getImagePath()).stem().string();
     const sfmData::CameraPose* pose =
-      ((flagsPart & ESfMData::EXTRINSICS) && sfmData.existsPose(view)) ? &(sfmData.getPoses().at(view.getPoseId())) : nullptr;
+      ((flagsPart & ESfMData::EXTRINSICS) && sfmData.existsPose(view)) ? sfmData.getPoses().at(view.getPoseId()).get() : nullptr;
     const std::shared_ptr<camera::IntrinsicBase> intrinsic =
-      (flagsPart & ESfMData::INTRINSICS) ? sfmData.getIntrinsicsharedPtr(view.getIntrinsicId()) : nullptr;
+      (flagsPart & ESfMData::INTRINSICS) ? sfmData.getIntrinsicSharedPtr(view.getIntrinsicId()) : nullptr;
 
-    if (sfmData.isPoseAndIntrinsicDefined(&view) && (flagsPart & ESfMData::EXTRINSICS))
+    if (sfmData.isPoseAndIntrinsicDefined(view) && (flagsPart & ESfMData::EXTRINSICS))
         _dataImpl->addCamera(name, view, pose, intrinsic, nullptr, &_dataImpl->_mvgCameras);
     else
         _dataImpl->addCamera(name, view, pose, intrinsic, nullptr, &_dataImpl->_mvgCamerasUndefined);
@@ -435,7 +469,7 @@ void AlembicExporter::addSfMCameraRig(const sfmData::SfMData& sfmData, IndexT ri
         const bool isReconstructed = (rigSubPose.status != sfmData::ERigSubPoseStatus::UNINITIALIZED);
         const std::string name = fs::path(view.getImage().getImagePath()).stem().string();
         const std::shared_ptr<camera::IntrinsicBase> intrinsic =
-          (flagsPart & ESfMData::INTRINSICS) ? sfmData.getIntrinsicsharedPtr(view.getIntrinsicId()) : nullptr;
+          (flagsPart & ESfMData::INTRINSICS) ? sfmData.getIntrinsicSharedPtr(view.getIntrinsicId()) : nullptr;
         std::unique_ptr<sfmData::CameraPose> subPosePtr;
 
         if (isReconstructed && (flagsPart & ESfMData::EXTRINSICS))
@@ -476,8 +510,10 @@ void AlembicExporter::addLandmarks(const sfmData::Landmarks& landmarks,
     std::vector<V3f> positions;
     std::vector<Imath::C3f> colors;
     std::vector<Alembic::Util::uint32_t> descTypes;
+    std::vector<Alembic::Util::bool_t> isParallaxRobust;
     positions.reserve(landmarks.size());
     descTypes.reserve(landmarks.size());
+    isParallaxRobust.reserve(landmarks.size());
 
     // For all the 3d points in the hash_map
     for (const auto& landmark : landmarks)
@@ -488,6 +524,7 @@ void AlembicExporter::addLandmarks(const sfmData::Landmarks& landmarks,
         positions.emplace_back(pt[0], -pt[1], -pt[2]);
         colors.emplace_back(color.r() / 255.f, color.g() / 255.f, color.b() / 255.f);
         descTypes.emplace_back(static_cast<Alembic::Util::uint8_t>(landmark.second.descType));
+        isParallaxRobust.emplace_back(static_cast<Alembic::Util::bool_t>(landmark.second.isParallaxRobust()));
     }
 
     std::vector<Alembic::Util::uint64_t> ids(positions.size());
@@ -510,6 +547,7 @@ void AlembicExporter::addLandmarks(const sfmData::Landmarks& landmarks,
     OCompoundProperty userProps = pSchema.getUserProperties();
 
     OUInt32ArrayProperty(userProps, "mvg_describerType").set(descTypes);
+    OBoolArrayProperty(userProps, "mvg_isParallaxRobust").set(isParallaxRobust);
 
     if (withVisibility)
     {
@@ -517,7 +555,7 @@ void AlembicExporter::addLandmarks(const sfmData::Landmarks& landmarks,
         visibilitySize.reserve(positions.size());
         for (const auto& landmark : landmarks)
         {
-            visibilitySize.emplace_back(landmark.second.observations.size());
+            visibilitySize.emplace_back(landmark.second.getObservations().size());
         }
         std::size_t nbObservations = std::accumulate(visibilitySize.begin(), visibilitySize.end(), 0);
 
@@ -529,16 +567,18 @@ void AlembicExporter::addLandmarks(const sfmData::Landmarks& landmarks,
 
         std::vector<float> featPos2d;
         std::vector<float> featScale;
+        std::vector<float> featDepth;
         if (withFeatures)
         {
             featPos2d.reserve(nbObservations * 2);
             visibilityFeatId.reserve(nbObservations);
             featScale.reserve(nbObservations);
+            featDepth.reserve(nbObservations);
         }
 
         for (const auto& landmark : landmarks)
         {
-            const sfmData::Observations& observations = landmark.second.observations;
+            const sfmData::Observations& observations = landmark.second.getObservations();
             for (const auto& vObs : observations)
             {
                 const sfmData::Observation& obs = vObs.second;
@@ -549,13 +589,14 @@ void AlembicExporter::addLandmarks(const sfmData::Landmarks& landmarks,
                 if (withFeatures)
                 {
                     // featureId
-                    visibilityFeatId.emplace_back(obs.id_feat);
+                    visibilityFeatId.emplace_back(obs.getFeatureId());
 
                     // feature 2D position (x, y))
-                    featPos2d.emplace_back(obs.x[0]);
-                    featPos2d.emplace_back(obs.x[1]);
+                    featPos2d.emplace_back(obs.getX());
+                    featPos2d.emplace_back(obs.getY());
 
-                    featScale.emplace_back(obs.scale);
+                    featScale.emplace_back(obs.getScale());
+                    featDepth.emplace_back(obs.getDepth());
                 }
             }
         }
@@ -568,6 +609,7 @@ void AlembicExporter::addLandmarks(const sfmData::Landmarks& landmarks,
             OUInt32ArrayProperty(userProps, "mvg_visibilityFeatId").set(visibilityFeatId);
             OFloatArrayProperty(userProps, "mvg_visibilityFeatPos").set(featPos2d);  // feature position (x,y)
             OFloatArrayProperty(userProps, "mvg_visibilityFeatScale").set(featScale);
+            OFloatArrayProperty(userProps, "mvg_visibilityFeatDepth").set(featDepth);
         }
     }
     if (!landmarksUncertainty.empty())
@@ -587,6 +629,51 @@ void AlembicExporter::addLandmarks(const sfmData::Landmarks& landmarks,
     }
 }
 
+void AlembicExporter::addSurveys(const sfmData::SurveyPoints & points)
+{
+    OPoints outPoints(_dataImpl->_mvgSurveys, "surveys");
+    OPointsSchema& pSchema = outPoints.getSchema();
+
+    //Build positions for abc visualisation
+    std::vector<V3f> positions;
+    for (const auto & [viewId, vsp] : points)
+    {
+        for (const auto & sp : vsp)
+        {
+            positions.emplace_back(sp.point3d[0], -sp.point3d[1], -sp.point3d[2]);
+        }
+    }
+
+    //Fake indices
+    std::vector<Alembic::Util::uint64_t> ids(positions.size());
+    std::iota(begin(ids), end(ids), 0);
+    
+    OPointsSchema::Sample psamp(std::move(V3fArraySample(positions)), std::move(UInt64ArraySample(ids)));
+    pSchema.set(psamp);
+
+    //Now, store information useful for AliceVision
+    OCompoundProperty userProps = pSchema.getUserProperties();
+
+    std::vector<IndexT> indices;
+    std::vector<double> data;
+
+    for (const auto & [viewId, vsp] : points)
+    {
+        for (const auto & sp : vsp)
+        {
+            indices.push_back(viewId);
+            data.push_back(sp.point3d.x());
+            data.push_back(sp.point3d.y());
+            data.push_back(sp.point3d.z());
+            data.push_back(sp.survey.x());
+            data.push_back(sp.survey.y());
+        }
+    }
+
+    OUInt32ArrayProperty(userProps, "mvg_surveyIds").set(indices);
+    ODoubleArrayProperty(userProps, "mvg_surveyData").set(data);
+}
+
 void AlembicExporter::addCamera(const std::string& name,
                                 const sfmData::View& view,
                                 const sfmData::CameraPose* pose,
@@ -596,11 +683,11 @@ void AlembicExporter::addCamera(const std::string& name,
     _dataImpl->addCamera(name, view, pose, intrinsic, uncertainty);
 }
 
-void AlembicExporter::initAnimatedCamera(const std::string& cameraName, std::size_t startFrame)
+void AlembicExporter::initAnimatedCamera(const std::string& cameraName, std::size_t startFrame, double frameRate)
 {
     // Sample the time in order to have one keyframe every frame
     // nb: it HAS TO be attached to EACH keyframed properties
-    TimeSamplingPtr tsp(new TimeSampling(1.0 / 24.0, startFrame / 24.0));
+    TimeSamplingPtr tsp(new TimeSampling(1.0 / frameRate, startFrame / frameRate));
 
     // Create the camera transform object
     std::stringstream ss;
@@ -638,8 +725,7 @@ void AlembicExporter::addCameraKeyframe(const geometry::Pose3& pose,
                                         const camera::Pinhole* cam,
                                         const std::string& imagePath,
                                         IndexT viewId,
-                                        IndexT intrinsicId,
-                                        float sensorWidthMM)
+                                        IndexT intrinsicId)
 {
     Eigen::Matrix4d M = Eigen::Matrix4d::Identity();
     M(1, 1) = -1;
@@ -672,23 +758,37 @@ void AlembicExporter::addCameraKeyframe(const geometry::Pose3& pose,
     // Camera intrinsic parameters
     CameraSample camSample;
 
+    const Vec2 & scale = cam->getScale();
+    const Vec2 & offset = cam->getOffset();
+    
     // Take the max of the image size to handle the case where the image is in portrait mode
     const float imgWidth = cam->w();
     const float imgHeight = cam->h();
+    const float sensorWidth = cam->sensorWidth();
+    const float sensorHeight = cam->sensorHeight();
     const float sensorWidth_pix = std::max(imgWidth, imgHeight);
-    const float focalLength_pix = static_cast<const float>(cam->getScale()(0));
-    const float focalLength_mm = sensorWidthMM * focalLength_pix / sensorWidth_pix;
-    const float pix2mm = sensorWidthMM / sensorWidth_pix;
-
+    const float focalLengthX_pix = static_cast<const float>(scale(0));
+    const float focalLengthY_pix = static_cast<const float>(scale(1));
+    const float focalLength_mm = sensorWidth * focalLengthX_pix / sensorWidth_pix;
+    const float squeeze = focalLengthX_pix / focalLengthY_pix;
+    const float pix2mm = sensorWidth / sensorWidth_pix;
+    
     // aliceVision: origin is (top,left) corner and orientation is (bottom,right)
     // ABC: origin is centered and orientation is (up,right)
     // Following values are in cm, hence the 0.1 multiplier
     const float haperture_cm = static_cast<const float>(0.1 * imgWidth * pix2mm);
     const float vaperture_cm = static_cast<const float>(0.1 * imgHeight * pix2mm);
+    
+    //Alembic Offset is the 2d motion of the camera which create the offset (opposite)
+    const float offsetX_cm = static_cast<const float>(-0.1 * offset(0) * pix2mm);
+    const float offsetY_cm = static_cast<const float>(-0.1 * (-offset(1)) * pix2mm);
 
     camSample.setFocalLength(focalLength_mm);
     camSample.setHorizontalAperture(haperture_cm);
     camSample.setVerticalAperture(vaperture_cm);
+    camSample.setLensSqueezeRatio(squeeze);
+    camSample.setHorizontalFilmOffset(offsetX_cm);
+    camSample.setVerticalFilmOffset(offsetY_cm);
 
     // Add sensor size in pixels as custom property
     std::vector<::uint32_t> sensorSize_pix = {cam->w(), cam->h()};
@@ -705,7 +805,7 @@ void AlembicExporter::addCameraKeyframe(const geometry::Pose3& pose,
     // Intrinsic type
     _dataImpl->_mvgIntrinsicType.set(cam->getTypeStr());
     // Intrinsic parameters
-    std::vector<double> intrinsicParams = cam->getParams();
+    std::vector<double> intrinsicParams = cam->getParameters();
     _dataImpl->_mvgIntrinsicParams.set(intrinsicParams);
 
     // Attach intrinsic parameters to camera object
