@@ -12,6 +12,9 @@
 #include <Alembic/AbcCoreOgawa/All.h>
 
 #include <aliceVision/version.hpp>
+#include <aliceVision/system/Logger.hpp>
+
+#include <aliceVision/camera/Equidistant.hpp>
 
 namespace aliceVision {
 namespace sfmDataIO {
@@ -185,6 +188,19 @@ bool readPointCloud(const Version& abcVersion, IObject iObj, M44d mat, sfmData::
         }
     }
 
+    BoolArraySamplePtr sampleIsParallaxRobust;
+    if (userProps && userProps.getPropertyHeader("mvg_isParallaxRobust"))
+    {
+        IBoolArrayProperty propIsParallaxRobust(userProps, "mvg_isParallaxRobust");
+        propIsParallaxRobust.get(sampleIsParallaxRobust);
+
+        if (sampleIsParallaxRobust->size() != positions->size())
+        {
+            ALICEVISION_LOG_WARNING("[Alembic Importer] isParallaxRobust property will be ignored.");
+            sampleIsParallaxRobust->reset();
+        }
+    }
+
     // Number of points before adding the Alembic data
     const std::size_t nbPointsInit = sfmdata.getLandmarks().size();
     for (std::size_t point3d_i = 0; point3d_i < positions->size(); ++point3d_i)
@@ -216,6 +232,12 @@ bool readPointCloud(const Version& abcVersion, IObject iObj, M44d mat, sfmData::
             const std::size_t descType_i = sampleDescs[point3d_i];
             landmark.descType = static_cast<feature::EImageDescriberType>(descType_i);
         }
+
+        if (sampleIsParallaxRobust)
+        {
+            const bool isParallaxRobust = sampleIsParallaxRobust->get()[point3d_i];
+            landmark.setParallaxRobust(isParallaxRobust);
+        }
     }
 
     // for compatibility with files generated with a previous version
@@ -262,13 +284,12 @@ bool readPointCloud(const Version& abcVersion, IObject iObj, M44d mat, sfmData::
             {
                 const int viewID = sampleVisibilityIds[obsGlobal_i];
                 const int featID = sampleVisibilityIds[obsGlobal_i + 1];
-                sfmData::Observation& observations = landmark.observations[viewID];
-                observations.id_feat = featID;
+                sfmData::Observation& observations = landmark.getObservations()[viewID];
+                observations.setFeatureId(featID);
 
                 const float posX = (*sampleFeatPos2d)[obsGlobal_i];
                 const float posY = (*sampleFeatPos2d)[obsGlobal_i + 1];
-                observations.x[0] = posX;
-                observations.x[1] = posY;
+                observations.setCoordinates(posX, posY);
             }
         }
     }
@@ -293,6 +314,7 @@ bool readPointCloud(const Version& abcVersion, IObject iObj, M44d mat, sfmData::
         AV_UInt32ArraySamplePtr sampleVisibilityFeatId;
         FloatArraySamplePtr sampleVisibilityFeatPos;
         FloatArraySamplePtr sampleVisibilityFeatScale;
+        FloatArraySamplePtr sampleVisibilityFeatDepth;
 
         if (userProps.getPropertyHeader("mvg_visibilityFeatId") && userProps.getPropertyHeader("mvg_visibilityFeatPos") &&
             flags_part & ESfMData::OBSERVATIONS_WITH_FEATURES)
@@ -308,6 +330,12 @@ bool readPointCloud(const Version& abcVersion, IObject iObj, M44d mat, sfmData::
                 propVisibilityFeatScale.get(sampleVisibilityFeatScale);
             }
 
+            if (userProps && userProps.getPropertyHeader("mvg_visibilityFeatDepth"))
+            {
+                IFloatArrayProperty propVisibilityFeatDepth(userProps, "mvg_visibilityFeatDepth");
+                propVisibilityFeatDepth.get(sampleVisibilityFeatDepth);
+            }
+
             if (sampleVisibilityViewId.size() != sampleVisibilityFeatId.size() ||
                 2 * sampleVisibilityViewId.size() != sampleVisibilityFeatPos->size())
             {
@@ -349,23 +377,27 @@ bool readPointCloud(const Version& abcVersion, IObject iObj, M44d mat, sfmData::
                 if (hasFeatures)
                 {
                     const std::size_t featId = sampleVisibilityFeatId[obsGlobalIndex];
-                    sfmData::Observation& observation = landmark.observations[viewId];
-                    observation.id_feat = featId;
+                    sfmData::Observation& observation = landmark.getObservations()[viewId];
+                    observation.setFeatureId(featId);
 
                     const float posX = (*sampleVisibilityFeatPos)[2 * obsGlobalIndex];
                     const float posY = (*sampleVisibilityFeatPos)[2 * obsGlobalIndex + 1];
-                    observation.x[0] = posX;
-                    observation.x[1] = posY;
+                    observation.setCoordinates(posX, posY);
 
                     // for compatibility with previous version without scale
                     if (sampleVisibilityFeatScale)
                     {
-                        observation.scale = (*sampleVisibilityFeatScale)[obsGlobalIndex];
+                        observation.setScale((*sampleVisibilityFeatScale)[obsGlobalIndex]);
+                    }
+
+                    if (sampleVisibilityFeatDepth)
+                    {
+                        observation.setDepth((*sampleVisibilityFeatDepth)[obsGlobalIndex]);
                     }
                 }
                 else
                 {
-                    landmark.observations[viewId] = sfmData::Observation();
+                    landmark.getObservations()[viewId] = sfmData::Observation();
                 }
             }
         }
@@ -374,6 +406,53 @@ bool readPointCloud(const Version& abcVersion, IObject iObj, M44d mat, sfmData::
     return true;
 }
 
+bool readSurveys(IObject iObj, sfmData::SfMData& sfmdata)
+{
+    using namespace aliceVision::geometry;
+
+    IPoints points(iObj, kWrapExisting);
+    IPointsSchema& ms = points.getSchema();
+    ICompoundProperty userProps = getAbcUserProperties(ms);
+
+    if (!(userProps.getPropertyHeader("mvg_surveyIds") && userProps.getPropertyHeader("mvg_surveyData")))
+    {
+        return false;
+    }
+
+    AV_UInt32ArraySamplePtr sampleId;
+    DoubleArraySamplePtr sampleData;
+
+    sampleId.read(userProps, "mvg_surveyIds");
+
+    IDoubleArrayProperty propData(userProps, "mvg_surveyData");
+    propData.get(sampleData);
+
+    const int sampleDataSize = 5;
+
+    if (sampleId.size() * sampleDataSize != sampleData->size())
+    {
+        return false;
+    }
+
+    sfmData::SurveyPoints & output = sfmdata.getSurveyPoints();
+    for (int pos = 0; pos < sampleId.size(); pos++)
+    {
+        IndexT viewId = sampleId[pos];
+
+        sfmData::SurveyPoint pt;
+        pt.point3d.x() = (*sampleData)[pos * sampleDataSize + 0];
+        pt.point3d.y() = (*sampleData)[pos * sampleDataSize + 1];
+        pt.point3d.z() = (*sampleData)[pos * sampleDataSize + 2];
+        pt.survey.x() = (*sampleData)[pos * sampleDataSize + 3];
+        pt.survey.y() = (*sampleData)[pos * sampleDataSize + 4];
+
+        output[viewId].push_back(pt);
+    }
+
+    return true;
+}
+
+
 bool readCamera(const Version& abcVersion,
                 const ICamera& camera,
                 const M44d& mat,
@@ -400,6 +479,8 @@ bool readCamera(const Version& abcVersion,
     std::string mvg_intrinsicType = EINTRINSIC_enumToString(EINTRINSIC::PINHOLE_CAMERA);
     std::string mvg_intrinsicInitializationMode = EInitMode_enumToString(EInitMode::NONE);
     std::string mvg_intrinsicDistortionInitializationMode = EInitMode_enumToString(EInitMode::NONE);
+    std::string mvg_distortionType = EDISTORTION_enumToString(EDISTORTION::DISTORTION_NONE);
+    std::string mvg_undistortionType = EDISTORTION_enumToString(EDISTORTION::DISTORTION_NONE);
     std::vector<double> mvg_intrinsicParams;
     std::vector<IndexT> mvg_ancestorImagesParams;
     Vec2 initialFocalLengthPix = {-1, -1};
@@ -416,11 +497,21 @@ bool readCamera(const Version& abcVersion,
     IndexT resectionId = UndefinedIndexT;
     bool intrinsicLocked = false;
     bool poseLocked = false;
+    bool rotationOnly = false;
+    bool removable = true;
     bool poseIndependant = true;
     bool lockRatio = true;
+    bool lockOffset = false;
+    bool lockScale = false;
+    bool lockDistortion = false;
     std::vector<double> distortionParams;
     std::vector<double> undistortionParams;
     Vec2 undistortionOffset = {0, 0};
+    double undistortionDiagonal = 0.0;
+    double undistortionPixelAspectRatio = 1.0;
+    bool undistortionDesqueezed = false;
+    bool undistortionLocked = false;
+    std::string serialNumber = "";
 
     if (userProps)
     {
@@ -457,6 +548,10 @@ bool readCamera(const Version& abcVersion,
             {
                 resectionId = getAbcProp_uint(userProps, *propHeader, "mvg_resectionId", sampleFrame);
             }
+            if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_intrinsicSerialNumber"))
+            {
+                serialNumber = getAbcProp<Alembic::Abc::IStringProperty>(userProps, *propHeader, "mvg_intrinsicSerialNumber", sampleFrame);
+            }
             if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_intrinsicLocked"))
             {
                 intrinsicLocked = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_intrinsicLocked", sampleFrame);
@@ -465,10 +560,26 @@ bool readCamera(const Version& abcVersion,
             {
                 lockRatio = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_intrinsicPixelRatioLocked", sampleFrame);
             }
+            if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_intrinsicOffsetLocked"))
+            {
+                lockOffset = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_intrinsicOffsetLocked", sampleFrame);
+            }
+            if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_intrinsicScaleLocked"))
+            {
+                lockScale = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_intrinsicScaleLocked", sampleFrame);
+            }
             if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_poseLocked"))
             {
                 poseLocked = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_poseLocked", sampleFrame);
             }
+            if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_rotationOnly"))
+            {
+                rotationOnly = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_rotationOnly", sampleFrame);
+            }
+            if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_removable"))
+            {
+                removable = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_removable", sampleFrame);
+            }
             if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_poseIndependant"))
             {
                 poseIndependant = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_poseIndependant", sampleFrame);
@@ -508,6 +619,14 @@ bool readCamera(const Version& abcVersion,
             {
                 mvg_intrinsicType = getAbcProp<Alembic::Abc::IStringProperty>(userProps, *propHeader, "mvg_intrinsicType", sampleFrame);
             }
+            if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_distortionType"))
+            {
+                mvg_distortionType = getAbcProp<Alembic::Abc::IStringProperty>(userProps, *propHeader, "mvg_distortionType", sampleFrame);
+            }
+            if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_undistortionType"))
+            {
+                mvg_undistortionType = getAbcProp<Alembic::Abc::IStringProperty>(userProps, *propHeader, "mvg_undistortionType", sampleFrame);
+            }
             if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_intrinsicInitializationMode"))
             {
                 mvg_intrinsicInitializationMode =
@@ -565,6 +684,10 @@ bool readCamera(const Version& abcVersion,
                 prop.get(sample, ISampleSelector(sampleFrame));
                 distortionParams.assign(sample->get(), sample->get() + sample->size());
             }
+            if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_distortionLocked"))
+            {
+                lockDistortion = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_distortionLocked", sampleFrame);
+            }
             if (userProps.getPropertyHeader("mvg_undistortionParams"))
             {
                 // Undistortion parameters
@@ -581,6 +704,22 @@ bool readCamera(const Version& abcVersion,
                 {
                     undistortionOffset(1) = getAbcProp<Alembic::Abc::IDoubleProperty>(userProps, *propHeader, "mvg_undistortionOffsetY", sampleFrame);
                 }
+                if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_undistortionDiagonal"))
+                {
+                    undistortionDiagonal = getAbcProp<Alembic::Abc::IDoubleProperty>(userProps, *propHeader, "mvg_undistortionDiagonal", sampleFrame);
+                }
+                if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_undistortionPixelAspectRatio"))
+                {
+                    undistortionPixelAspectRatio = getAbcProp<Alembic::Abc::IDoubleProperty>(userProps, *propHeader, "mvg_undistortionPixelAspectRatio", sampleFrame);
+                }
+                if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_undistortionDesqueezed"))
+                {
+                    undistortionDesqueezed = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_undistortionDesqueezed", sampleFrame);
+                }
+                if (const Alembic::Abc::PropertyHeader* propHeader = userProps.getPropertyHeader("mvg_undistortionLocked"))
+                {
+                    undistortionLocked = getAbcProp<Alembic::Abc::IBoolProperty>(userProps, *propHeader, "mvg_undistortionLocked", sampleFrame);
+                }
             }
         }
     }
@@ -595,13 +734,30 @@ bool readCamera(const Version& abcVersion,
         // const float mm2pix = sensorSize_pix.at(0) / sensorWidth_mm;
         // imgWidth = haperture_cm * 10.0 * mm2pix;
         // imgHeight = vaperture_cm * 10.0 * mm2pix;
+        
+        camera::EINTRINSIC intrinsicType;
+        camera::EDISTORTION distortionType;
+        camera::EUNDISTORTION undistortionType;
+        if (abcVersion < Version(1, 2, 8))
+        {
+            compatibilityStringToEnums(mvg_intrinsicType, intrinsicType, distortionType, undistortionType);
+        }
+        else 
+        {
+            intrinsicType = EINTRINSIC_stringToEnum(mvg_intrinsicType);
+            distortionType = EDISTORTION_stringToEnum(mvg_distortionType);
+            undistortionType = EUNDISTORTION_stringToEnum(mvg_undistortionType);
+        }
 
         // create intrinsic parameters object
         std::shared_ptr<camera::IntrinsicBase> intrinsic = createIntrinsic(
-          /*intrinsic type*/ EINTRINSIC_stringToEnum(mvg_intrinsicType),
+          /*intrinsic type*/ intrinsicType,
+          /*distortion type*/ distortionType,
+          /*undistortion type*/ undistortionType,
           /*width*/ sensorSize_pix.at(0),
           /*height*/ sensorSize_pix.at(1));
 
+        intrinsic->setSerialNumber(serialNumber);
         intrinsic->setSensorWidth(sensorSize_mm.at(0));
         intrinsic->setSensorHeight(sensorSize_mm.at(1));
         intrinsic->importFromParams(mvg_intrinsicParams, abcVersion);
@@ -612,23 +768,47 @@ bool readCamera(const Version& abcVersion,
         if (intrinsicCasted)
         {
             // fy_pix = fx_pix * fy/fx
-            initialFocalLengthPix(1) =
-              (initialFocalLengthPix(0) > 0) ? initialFocalLengthPix(0) * mvg_intrinsicParams[1] / mvg_intrinsicParams[0] : -1;
+            initialFocalLengthPix(1) = initialFocalLengthPix(0);
+            if (initialFocalLengthPix(0) > 0.0)
+            {
+                initialFocalLengthPix(0) = initialFocalLengthPix(0) / intrinsicCasted->getPixelAspectRatio();
+            }
+
             intrinsicCasted->setInitialScale(initialFocalLengthPix);
             intrinsicCasted->setRatioLocked(lockRatio);
+            intrinsicCasted->setOffsetLocked(lockOffset);
+            intrinsicCasted->setScaleLocked(lockScale);
+
             std::shared_ptr<camera::Distortion> distortion = intrinsicCasted->getDistortion();
             if (distortion)
             {
-                distortion->setParameters(distortionParams);
-            }
+                distortion->setParameters(distortionParams);    
 
+                if (abcVersion >= Version(1, 2, 10))
+                {
+                    distortion->setLocked(lockDistortion);
+                }
+            }
 
             std::shared_ptr<camera::Undistortion> undistortion = intrinsicCasted->getUndistortion();
             if (undistortion)
             {
                 undistortion->setParameters(undistortionParams);
                 undistortion->setOffset(undistortionOffset);
-                //If undistortion exists, distortion does not
+                undistortion->setLocked(undistortionLocked);
+
+                if (abcVersion >= Version(1, 2, 7))
+                {
+                    undistortion->setDiagonal(undistortionDiagonal);
+                }
+
+                if (abcVersion >= Version(1, 2, 9))
+                {
+                    undistortion->setPixelAspectRatio(undistortionPixelAspectRatio);
+                    undistortion->setDesqueezed(undistortionDesqueezed);
+                }
+
+                // If undistortion exists, distortion does not
                 intrinsicCasted->setDistortionObject(nullptr);
             }
         }
@@ -642,9 +822,13 @@ bool readCamera(const Version& abcVersion,
         }
 
         if (intrinsicLocked)
+        {
             intrinsic->lock();
+        }
         else
+        {
             intrinsic->unlock();
+        }
 
         sfmData.getIntrinsics().emplace(intrinsicId, intrinsic);
     }
@@ -717,7 +901,10 @@ bool readCamera(const Version& abcVersion,
         }
         else
         {
-            sfmData.setPose(*view, sfmData::CameraPose(pose, poseLocked));
+            sfmData::CameraPose cp(pose, poseLocked);
+            cp.setRotationOnly(rotationOnly);
+            cp.setRemovable(removable);
+            sfmData.setPose(*view, cp);
         }
     }
 
@@ -755,8 +942,7 @@ bool readAncestor(const Version& abcVersion, const ICamera& camera, sfmData::SfM
         std::map<std::string, std::string> metadata;
         for (size_t mIndex = 0; mIndex < rawMetadata.size() / 2; mIndex++)
         {
-            metadata.insert(
-                std::pair<std::string, std::string>(rawMetadata[2 * mIndex], rawMetadata[2 * mIndex + 1]));
+            metadata.insert(std::pair<std::string, std::string>(rawMetadata[2 * mIndex], rawMetadata[2 * mIndex + 1]));
         }
 
         sfmData::ImageInfo ancestor(imagePath, width, height, metadata);
@@ -880,7 +1066,7 @@ bool readXform(const Version& abcVersion, IXform& xform, M44d& mat, sfmData::SfM
 
         if (sfmData.getPoses().find(poseId) == sfmData.getPoses().end())
         {
-            sfmData.getPoses().emplace(poseId, sfmData::CameraPose(pose, rigPoseLocked));
+            sfmData.getPoses().assign(poseId, sfmData::CameraPose(pose, rigPoseLocked));
         }
     }
 
@@ -899,9 +1085,22 @@ void visitObject(const Version& abcVersion, IObject iObj, M44d mat, sfmData::SfM
         isReconstructed = false;
 
     const MetaData& md = iObj.getMetaData();
-    if (IPoints::matches(md) && (flagsPart & ESfMData::STRUCTURE))
+    if (IPoints::matches(md))
     {
-        readPointCloud(abcVersion, iObj, mat, sfmdata, flagsPart);
+        if (iObj.getName() == "surveys")
+        {
+            if (flagsPart & ESfMData::SURVEYS)
+            {
+                readSurveys(iObj, sfmdata);
+            }
+        }
+        else 
+        {
+            if (flagsPart & ESfMData::STRUCTURE )
+            {
+                readPointCloud(abcVersion, iObj, mat, sfmdata, flagsPart);
+            }
+        }
     }
     else if (IXform::matches(md))
     {
@@ -979,6 +1178,12 @@ void AlembicImporter::populateSfM(sfmData::SfMData& sfmdata, ESfMData flagsPart)
 
     Version abcVersion(vecAbcVersion[0], vecAbcVersion[1], vecAbcVersion[2]);
 
+    const Vec3i currentVersion = {ALICEVISION_SFMDATAIO_VERSION_MAJOR, ALICEVISION_SFMDATAIO_VERSION_MINOR, ALICEVISION_SFMDATAIO_VERSION_REVISION};
+    if (Version(currentVersion) < abcVersion)
+    {
+        ALICEVISION_THROW_ERROR("File has a version more recent than this library");
+    }
+
     if (userProps.getPropertyHeader("mvg_featuresFolders"))
     {
         std::vector<std::string> featuresFolders;
