@@ -7,13 +7,14 @@
 #include "colmap.hpp"
 #include <aliceVision/geometry/Pose3.hpp>
 #include <aliceVision/camera/cameraCommon.hpp>
+#include <aliceVision/camera/Pinhole.hpp>
+#include <aliceVision/system/Logger.hpp>
 
-#include <boost/filesystem.hpp>
-
-#include <sstream>
+#include <filesystem>
 #include <fstream>
+#include <sstream>
 
-namespace fs = boost::filesystem;
+namespace fs = std::filesystem;
 
 namespace aliceVision {
 namespace sfmDataIO {
@@ -29,22 +30,30 @@ ColmapConfig::ColmapConfig(const std::string& basePath)
     _points3DPath = (fs::path(_sparseDirectory) / fs::path("points3D.txt")).string();
 }
 
-const std::set<camera::EINTRINSIC>& colmapCompatibleIntrinsics()
+
+bool isColmapCompatible(camera::EINTRINSIC intrinsicType, camera::EDISTORTION distortionType)
 {
-    static const std::set<camera::EINTRINSIC> compatibleIntrinsics{camera::PINHOLE_CAMERA,
-                                                                   camera::PINHOLE_CAMERA_RADIAL1,
-                                                                   camera::PINHOLE_CAMERA_RADIAL3,
-                                                                   camera::PINHOLE_CAMERA_BROWN,
-                                                                   camera::PINHOLE_CAMERA_FISHEYE,
-                                                                   camera::PINHOLE_CAMERA_FISHEYE1};
-    return compatibleIntrinsics;
+    if (intrinsicType != camera::EINTRINSIC::PINHOLE_CAMERA) 
+    {
+        return false;
+    }
+
+    switch (distortionType)
+    {
+    case camera::EDISTORTION::DISTORTION_NONE:
+    case camera::EDISTORTION::DISTORTION_RADIALK1:
+    case camera::EDISTORTION::DISTORTION_RADIALK3:
+    case camera::EDISTORTION::DISTORTION_BROWN:
+    case camera::EDISTORTION::DISTORTION_FISHEYE:
+    case camera::EDISTORTION::DISTORTION_FISHEYE1:
+        return true;
+    default:
+        break;
+    };
+
+    return false;
 }
 
-bool isColmapCompatible(camera::EINTRINSIC intrinsicType)
-{
-    const auto compatible = colmapCompatibleIntrinsics();
-    return compatible.find(intrinsicType) != compatible.end();
-}
 
 CompatibleList getColmapCompatibleIntrinsics(const sfmData::SfMData& sfMData)
 {
@@ -54,7 +63,10 @@ CompatibleList getColmapCompatibleIntrinsics(const sfmData::SfMData& sfMData)
         const auto& intrinsics = iter.second;
         const auto intrID = iter.first;
         const auto intrType = intrinsics->getType();
-        if (isColmapCompatible(intrType))
+
+        camera::EDISTORTION distoType = camera::getDistortionType(*intrinsics);
+
+        if (isColmapCompatible(intrType, distoType))
         {
             compatible.insert(intrID);
         }
@@ -93,9 +105,19 @@ std::string convertIntrinsicsToColmapString(const IndexT intrinsicsID, std::shar
     std::stringstream intrString;
 
     camera::EINTRINSIC current_type = intrinsic->getType();
-    switch (current_type)
+
+    camera::EDISTORTION distoType = camera::getDistortionType(*intrinsic);    
+
+    if (current_type != camera::EINTRINSIC::PINHOLE_CAMERA)
     {
-        case camera::PINHOLE_CAMERA:
+        throw std::invalid_argument("The intrinsics " + EINTRINSIC_enumToString(current_type) + 
+                                    " for camera " + std::to_string(intrinsicsID) +
+                                    " are not supported in Colmap");
+    }
+
+    switch (distoType)
+    {
+        case camera::DISTORTION_NONE:
             // PINHOLE_CAMERA corresponds to Colmap's PINHOLE
             // Parameters: f, cx, cy
             {
@@ -104,101 +126,120 @@ std::string convertIntrinsicsToColmapString(const IndexT intrinsicsID, std::shar
                 intrString << intrinsicsID << " "
                            << "PINHOLE"
                            << " " << pinhole_intrinsic->w() << " " << pinhole_intrinsic->h() << " " << pinhole_intrinsic->getFocalLengthPixX() << " "
-                           << pinhole_intrinsic->getFocalLengthPixY() << " " << pinhole_intrinsic->getPrincipalPoint().x() << " "
+                           << pinhole_intrinsic->getFocalLengthPixY() << " " 
+                           << pinhole_intrinsic->getPrincipalPoint().x() << " "
                            << pinhole_intrinsic->getPrincipalPoint().y() << "\n";
             }
             break;
-        case camera::PINHOLE_CAMERA_RADIAL1:
+        case camera::DISTORTION_RADIALK1:
             // PINHOLE_CAMERA_RADIAL1 can only be modeled by Colmap's FULL_OPENCV setting the unused parameters to 0
             // Parameters: fx, fy, cx, cy, k1, k2, p1, p2, k3, k4, k5, k6
             {
                 std::shared_ptr<camera::Pinhole> pinhole_intrinsic_radial = std::dynamic_pointer_cast<camera::Pinhole>(intrinsic);
 
+                auto distortion = pinhole_intrinsic_radial->getDistortion();
+
                 intrString << intrinsicsID << " "
                            << "FULL_OPENCV"
-                           << " " << pinhole_intrinsic_radial->w() << " " << pinhole_intrinsic_radial->h() << " "
-                           << pinhole_intrinsic_radial->getFocalLengthPixX() << " " << pinhole_intrinsic_radial->getFocalLengthPixY() << " "
-                           << pinhole_intrinsic_radial->getPrincipalPoint().x() << " " << pinhole_intrinsic_radial->getPrincipalPoint().y() << " "
-                           << pinhole_intrinsic_radial->getParams().at(4)
+                           << " " << pinhole_intrinsic_radial->w() << " " 
+                           << pinhole_intrinsic_radial->h() << " "
+                           << pinhole_intrinsic_radial->getFocalLengthPixX() << " " 
+                           << pinhole_intrinsic_radial->getFocalLengthPixY() << " "
+                           << pinhole_intrinsic_radial->getPrincipalPoint().x() << " " 
+                           << pinhole_intrinsic_radial->getPrincipalPoint().y() << " "
+                           << distortion->getParameters().at(0)
                            << " "
                            // k2, p1, p2, k3, k4, k5, k6
                            << "0.0 0.0 0.0 0.0 0.0 0.0 0.0"
                            << "\n";
             }
             break;
-        case camera::PINHOLE_CAMERA_RADIAL3:
+        case camera::DISTORTION_RADIALK3:
             // PINHOLE_CAMERA_RADIAL3 can only be modeled by Colmap's FULL_OPENCV setting the unused parameters to 0
             // Parameters: fx, fy, cx, cy, k1, k2, p1, p2, k3, k4, k5, k6
             {
                 std::shared_ptr<camera::Pinhole> pinhole_intrinsic_radial = std::dynamic_pointer_cast<camera::Pinhole>(intrinsic);
+                auto distortion = pinhole_intrinsic_radial->getDistortion();
 
                 intrString << intrinsicsID << " "
                            << "FULL_OPENCV"
-                           << " " << pinhole_intrinsic_radial->w() << " " << pinhole_intrinsic_radial->h() << " "
-                           << pinhole_intrinsic_radial->getFocalLengthPixX() << " " << pinhole_intrinsic_radial->getFocalLengthPixY() << " "
-                           << pinhole_intrinsic_radial->getPrincipalPoint().x() << " " << pinhole_intrinsic_radial->getPrincipalPoint().y() << " "
-                           << pinhole_intrinsic_radial->getParams().at(4) << " " << pinhole_intrinsic_radial->getParams().at(5)
-                           << " "
+                           << " " << pinhole_intrinsic_radial->w() << " " 
+                           << pinhole_intrinsic_radial->h() << " "
+                           << pinhole_intrinsic_radial->getFocalLengthPixX() << " " 
+                           << pinhole_intrinsic_radial->getFocalLengthPixY() << " "
+                           << pinhole_intrinsic_radial->getPrincipalPoint().x() << " " 
+                           << pinhole_intrinsic_radial->getPrincipalPoint().y() << " "
+                           << distortion->getParameters().at(0) << " " 
+                           << distortion->getParameters().at(1) << " "
                            // tangential params p1 and p2
                            << 0.0 << " " << 0.0
                            << " "
                            // k3
-                           << pinhole_intrinsic_radial->getParams().at(6)
-                           << " "
+                           << distortion->getParameters().at(2) << " "
                            // remaining radial params k4-k6
                            << 0.0 << " " << 0.0 << " " << 0.0 << "\n";
             }
             break;
-        case camera::PINHOLE_CAMERA_BROWN:
+        case camera::DISTORTION_BROWN:
             // PINHOLE_CAMERA_BROWN can only be modeled by Colmap's FULL_OPENCV setting the unused parameters to 0
             // Parameters: fx, fy, cx, cy, k1, k2, p1, p2, k3, k4, k5, k6
             {
                 std::shared_ptr<camera::Pinhole> pinholeCameraBrownIntrinsics = std::dynamic_pointer_cast<camera::Pinhole>(intrinsic);
+                auto distortion = pinholeCameraBrownIntrinsics->getDistortion();
 
                 intrString << intrinsicsID << " "
                            << "FULL_OPENCV"
                            << " " << pinholeCameraBrownIntrinsics->w() << " " << pinholeCameraBrownIntrinsics->h() << " "
-                           << pinholeCameraBrownIntrinsics->getFocalLengthPixX() << " " << pinholeCameraBrownIntrinsics->getFocalLengthPixY() << " "
-                           << pinholeCameraBrownIntrinsics->getPrincipalPoint().x() << " " << pinholeCameraBrownIntrinsics->getPrincipalPoint().y()
-                           << " " << pinholeCameraBrownIntrinsics->getParams().at(4) << " " << pinholeCameraBrownIntrinsics->getParams().at(5)
-                           << " "
+                           << pinholeCameraBrownIntrinsics->getFocalLengthPixX() << " " 
+                           << pinholeCameraBrownIntrinsics->getFocalLengthPixY() << " "
+                           << pinholeCameraBrownIntrinsics->getPrincipalPoint().x() << " " 
+                           << pinholeCameraBrownIntrinsics->getPrincipalPoint().y() << " " 
+                           << distortion->getParameters().at(0) << " " 
+                           << distortion->getParameters().at(1) << " "
                            // tangential params p1 and p2
-                           << pinholeCameraBrownIntrinsics->getParams().at(7) << " " << pinholeCameraBrownIntrinsics->getParams().at(8)
-                           << " "
+                           << distortion->getParameters().at(3) << " " 
+                           << distortion->getParameters().at(4) << " "
                            // k3
-                           << pinholeCameraBrownIntrinsics->getParams().at(6)
-                           << " "
+                           << distortion->getParameters().at(2) << " "
                            // remaining radial params k4-k6
                            << 0.0 << " " << 0.0 << " " << 0.0 << "\n";
             }
             break;
-        case camera::PINHOLE_CAMERA_FISHEYE:
+        case camera::DISTORTION_FISHEYE:
             // PINHOLE_CAMERA_FISHEYE is modeled by Colmap's OPENCV_FISHEYE
             // Parameters: fx, fy, cx, cy, k1, k2, k3, k4
             {
                 std::shared_ptr<camera::Pinhole> pinholeIntrinsicFisheye = std::dynamic_pointer_cast<camera::Pinhole>(intrinsic);
+                auto distortion = pinholeIntrinsicFisheye->getDistortion();
 
                 intrString << intrinsicsID << " "
                            << "OPENCV_FISHEYE"
                            << " " << pinholeIntrinsicFisheye->w() << " " << pinholeIntrinsicFisheye->h() << " "
-                           << pinholeIntrinsicFisheye->getFocalLengthPixX() << " " << pinholeIntrinsicFisheye->getFocalLengthPixY() << " "
-                           << pinholeIntrinsicFisheye->getPrincipalPoint().x() << " " << pinholeIntrinsicFisheye->getPrincipalPoint().y() << " "
-                           << pinholeIntrinsicFisheye->getParams().at(4) << " " << pinholeIntrinsicFisheye->getParams().at(5) << " "
-                           << pinholeIntrinsicFisheye->getParams().at(6) << " " << pinholeIntrinsicFisheye->getParams().at(7) << "\n";
+                           << pinholeIntrinsicFisheye->getFocalLengthPixX() << " " 
+                           << pinholeIntrinsicFisheye->getFocalLengthPixY() << " "
+                           << pinholeIntrinsicFisheye->getPrincipalPoint().x() << " " 
+                           << pinholeIntrinsicFisheye->getPrincipalPoint().y() << " "
+                           << distortion->getParameters().at(0) << " " 
+                           << distortion->getParameters().at(1) << " "
+                           << distortion->getParameters().at(2) << " " 
+                           << distortion->getParameters().at(3) << "\n";
             }
             break;
-        case camera::PINHOLE_CAMERA_FISHEYE1:
+        case camera::DISTORTION_FISHEYE1:
             // PINHOLE_CAMERA_FISHEYE corresponds to Colmap's FOV
             // Parameters: fx, fy, cx, cy, k1, k2, k3, k4
             {
                 std::shared_ptr<camera::Pinhole> pinholeIntrinsicFisheye = std::dynamic_pointer_cast<camera::Pinhole>(intrinsic);
+                auto distortion = pinholeIntrinsicFisheye->getDistortion();
 
                 intrString << intrinsicsID << " "
                            << "FOV"
                            << " " << pinholeIntrinsicFisheye->w() << " " << pinholeIntrinsicFisheye->h() << " "
-                           << pinholeIntrinsicFisheye->getFocalLengthPixX() << " " << pinholeIntrinsicFisheye->getFocalLengthPixY() << " "
-                           << pinholeIntrinsicFisheye->getPrincipalPoint().x() << " " << pinholeIntrinsicFisheye->getPrincipalPoint().y() << " "
-                           << pinholeIntrinsicFisheye->getParams().at(4) << "\n";
+                           << pinholeIntrinsicFisheye->getFocalLengthPixX() << " " 
+                           << pinholeIntrinsicFisheye->getFocalLengthPixY() << " "
+                           << pinholeIntrinsicFisheye->getPrincipalPoint().x() << " " 
+                           << pinholeIntrinsicFisheye->getPrincipalPoint().y() << " "
+                           << distortion->getParameters().at(0) << "\n";
             }
             break;
         default:
@@ -233,7 +274,9 @@ void generateColmapCamerasTxtFile(const sfmData::SfMData& sfmData, const std::st
         const IndexT intrID = iter.first;
         std::shared_ptr<camera::IntrinsicBase> intrinsic = iter.second;
 
-        if (isColmapCompatible(intrinsic->getType()))
+        camera::EDISTORTION distoType = camera::getDistortionType(*intrinsic);
+
+        if (isColmapCompatible(intrinsic->getType(), distoType))
         {
             outfile << convertIntrinsicsToColmapString(intrID, intrinsic);
         }
@@ -247,7 +290,7 @@ PerViewVisibility computePerViewVisibility(const sfmData::SfMData& sfmData, cons
     for (const auto& land : sfmData.getLandmarks())
     {
         const IndexT landID = land.first;
-        const auto& observations = land.second.observations;
+        const auto& observations = land.second.getObservations();
 
         for (const auto& iter : observations)
         {
@@ -257,7 +300,7 @@ PerViewVisibility computePerViewVisibility(const sfmData::SfMData& sfmData, cons
             if (viewSelections.find(viewID) != viewSelections.end())
             {
                 // for the current viewID add the feature point and its associate 3D point's ID
-                perCameraVisibility[viewID][landID] = obs.x;
+                perCameraVisibility[viewID][landID] = obs.getCoordinates();
             }
         }
     }
@@ -362,10 +405,10 @@ void generateColmapPoints3DTxtFile(const sfmData::SfMData& sfmData, const Compat
 
         outfile << defaultError;
 
-        for (const auto& itObs : iter.second.observations)
+        for (const auto& itObs : iter.second.getObservations())
         {
             const IndexT viewId = itObs.first;
-            const IndexT featId = itObs.second.id_feat;
+            const IndexT featId = itObs.second.getFeatureId();
 
             if (viewSelections.find(viewId) != viewSelections.end())
             {
