@@ -7,27 +7,11 @@
 #pragma once
 
 #include <aliceVision/track/Track.hpp>
-
 #include <boost/json.hpp>
 
 namespace aliceVision {
 namespace track {
 
-template<class T>
-stl::flat_map<size_t, T> flat_map_value_to(const boost::json::value& jv)
-{
-    stl::flat_map<size_t, T> ret;
-
-    const boost::json::array obj = jv.as_array();
-
-    for (const auto& item : obj)
-    {
-        const boost::json::array inner = item.as_array();
-        ret.insert({boost::json::value_to<std::size_t>(inner[0]), boost::json::value_to<T>(inner[1])});
-    }
-
-    return ret;
-}
 
 /**
  * @brief Serialize track to JSON object.
@@ -39,5 +23,21 @@ void tag_invoke(const boost::json::value_from_tag&, boost::json::value& jv, alic
  */
 aliceVision::track::Track tag_invoke(boost::json::value_to_tag<aliceVision::track::Track>, boost::json::value const& jv);
 
+/**
+ * @brief load tracks from file
+ * @param mapTracks the result container
+ * @param filename the input file path
+ * @return false if the load failed
+*/
+bool loadTracks(TracksMap& mapTracks, const std::string& filename);
+
+/**
+ * @brief save tracks to file
+ * @param mapTracks the input container
+ * @param filename the input file path
+ * @return false if the save failed
+*/
+bool saveTracks(const TracksMap& mapTracks, const std::string& filename);
+
 }  // namespace track
 }  // namespace aliceVision
