@@ -6,18 +6,12 @@
 
 #pragma once
 
-#include <Eigen/Core>
-
 #include <cstdint>
 #include <limits>
 #include <map>
 #include <set>
 #include <vector>
 
-#ifdef ALICEVISION_STD_UNORDERED_MAP
-    #include <unordered_map>
-#endif
-
 namespace aliceVision {
 
 typedef uint32_t IndexT;
@@ -27,14 +21,6 @@ typedef std::pair<IndexT, IndexT> Pair;
 typedef std::set<Pair> PairSet;
 typedef std::vector<Pair> PairVec;
 
-#ifdef ALICEVISION_UNORDERED_MAP
-template<typename Key, typename Value>
-using HashMap = std::unordered_map<Key, Value>;
-#else
-template<typename K, typename V>
-using HashMap = std::map<K, V, std::less<K>, Eigen::aligned_allocator<std::pair<const K, V>>>;
-#endif
-
 struct EstimationStatus
 {
     EstimationStatus(bool valid, bool strongSupport)
@@ -46,4 +32,14 @@ struct EstimationStatus
     bool hasStrongSupport = false;
 };
 
+/**
+ * @brief Defines the state of a parameter for an estimator
+ */
+enum class EEstimatorParameterState : std::uint8_t
+{
+    REFINED = 0,   //< will be adjusted by the estimator
+    CONSTANT = 1,  //< will be set as constant in the estimator
+    IGNORED = 2    //< will not be set into the estimator
+};
+
 }  // namespace aliceVision
