@@ -659,7 +659,7 @@ vl_swap_host_big_endianness_2 (void *dst, void* src)
 }
 
 /* Linux: limit glibc to old versions for compatibility */
-#if defined(VL_COMPILER_GNUC) & defined(VL_OS_LINUX) & ! defined(__DOXYGEN__) & ! defined(ANDROID)
+#if defined(VL_COMPILER_GNUC) & defined(VL_OS_LINUX) & ! defined(__DOXYGEN__) & ! defined(ANDROID) & ! defined(__aarch64__)
 __asm__(".symver memcpy,memcpy@GLIBC_2.2.5");
 #endif
 
