@@ -4,8 +4,9 @@
 // v. 2.0. If a copy of the MPL was not distributed with this file,
 // You can obtain one at https://mozilla.org/MPL/2.0/.
 
-#include <aliceVision/image/all.hpp>
+#include <aliceVision/image/Image.hpp>
 #include <aliceVision/image/io.hpp>
+#include <aliceVision/image/conversion.hpp>
 #include <aliceVision/system/Logger.hpp>
 #include <aliceVision/cmdline/cmdline.hpp>
 #include <aliceVision/system/main.hpp>
@@ -29,13 +30,11 @@
 // Command line parameters
 #include <boost/algorithm/string.hpp>
 #include <boost/program_options.hpp>
-#include <boost/filesystem.hpp>
-
-#include <sstream>
 
+#include <filesystem>
 #include <fstream>
 #include <map>
-
+#include <sstream>
 
 // These constants define the current software version.
 // They must be updated when the command line is changed.
@@ -46,7 +45,7 @@ using namespace aliceVision;
 using namespace aliceVision::hdr;
 
 namespace po = boost::program_options;
-namespace fs = boost::filesystem;
+namespace fs = std::filesystem;
 
 struct luminanceInfo
 {
@@ -70,7 +69,8 @@ void computeLuminanceStatFromSamples(const std::vector<hdr::ImageSample>& sample
         {
             const IndexT key = samples[i].descriptions[j].srcId;
 
-            const double lum = image::Rgb2GrayLinear(samples[i].descriptions[j].mean[0], samples[i].descriptions[j].mean[1], samples[i].descriptions[j].mean[2]);
+            const double lum =
+              image::Rgb2GrayLinear(samples[i].descriptions[j].mean[0], samples[i].descriptions[j].mean[1], samples[i].descriptions[j].mean[2]);
 
             if (luminanceInfos.find(key) == luminanceInfos.end())
             {
@@ -103,8 +103,8 @@ void computeLuminanceInfoFromImage(image::Image<image::RGBfColor>& image, lumina
     double minLuminance = 1000.0;
     int sampleNb = 0;
 
-    const int imgH = image.Height();
-    const int imgW = image.Width();
+    const int imgH = image.height();
+    const int imgW = image.width();
 
     const int a1 = (imgH <= imgW) ? imgW / 2 : imgH / 2;
     const int a2 = (imgH <= imgW) ? imgW / 2 : imgW - (imgH / 2);
@@ -153,7 +153,7 @@ int aliceVision_main(int argc, char** argv)
     bool byPass = false;
 
     // Command line parameters
-
+    // clang-format off
     po::options_description requiredParams("Required parameters");
     requiredParams.add_options()
         ("input,i", po::value<std::string>(&sfmInputDataFilename)->required(),
@@ -182,12 +182,12 @@ int aliceVision_main(int argc, char** argv)
          ("Working color space: " + image::EImageColorSpace_informations()).c_str())
         ("maxTotalPoints", po::value<std::size_t>(&maxTotalPoints)->default_value(maxTotalPoints),
          "Maximum number of points used from the sampling. This ensures that the number of pixels values extracted by "
-         "the sampling can be managed by the calibration step (in terms of computation time and memory usage).")
-        ;
+         "the sampling can be managed by the calibration step (in terms of computation time and memory usage).");
+    // clang-format on
 
     CmdLine cmdline("This program recovers the Camera Response Function (CRF) from samples extracted from LDR images with multi-bracketing.\n"
                     "AliceVision LdrToHdrCalibration");
-                  
+
     cmdline.add(requiredParams);
     cmdline.add(optionalParams);
     if (!cmdline.execute(argc, argv))
@@ -201,7 +201,7 @@ int aliceVision_main(int argc, char** argv)
 
     // Read SfMData
     sfmData::SfMData sfmData;
-    if (!sfmDataIO::Load(sfmData, sfmInputDataFilename, sfmDataIO::ESfMData::ALL))
+    if (!sfmDataIO::load(sfmData, sfmInputDataFilename, sfmDataIO::ESfMData::ALL))
     {
         ALICEVISION_LOG_ERROR("The input SfMData file '" << sfmInputDataFilename << "' cannot be read.");
         return EXIT_FAILURE;
@@ -228,7 +228,7 @@ int aliceVision_main(int argc, char** argv)
     }
 
     std::set<std::size_t> sizeOfGroups;
-    for(auto& group : globalGroupedViews)
+    for (auto& group : globalGroupedViews)
     {
         sizeOfGroups.insert(group.size());
     }
@@ -241,9 +241,8 @@ int aliceVision_main(int argc, char** argv)
             // Nothing to calibrate, export a linear CRF.
             calibrationMethod = ECalibrationMethod::LINEAR;
         }
-        ALICEVISION_LOG_INFO("Number of brackets automatically detected: "
-                             << usedNbBrackets << ". It will generate " << globalGroupedViews.size()
-                             << " HDR images.");
+        ALICEVISION_LOG_INFO("Number of brackets automatically detected: " << usedNbBrackets << ". It will generate " << globalGroupedViews.size()
+                                                                           << " HDR images.");
     }
     else
     {
@@ -252,11 +251,11 @@ int aliceVision_main(int argc, char** argv)
     }
 
     std::map<IndexT, std::vector<std::vector<std::shared_ptr<sfmData::View>>>> groupedViewsPerIntrinsics;
-    for (const auto & group : globalGroupedViews)
+    for (const auto& group : globalGroupedViews)
     {
         IndexT intrinsicId = UndefinedIndexT;
 
-        for (const auto & v : group)
+        for (const auto& v : group)
         {
             IndexT lid = v->getIntrinsicId();
             if (intrinsicId == UndefinedIndexT)
@@ -280,10 +279,10 @@ int aliceVision_main(int argc, char** argv)
         groupedViewsPerIntrinsics[intrinsicId].push_back(group);
     }
 
-    for (const auto & intrinsicGroups: groupedViewsPerIntrinsics)
-    {        
+    for (const auto& intrinsicGroups : groupedViewsPerIntrinsics)
+    {
         IndexT intrinsicId = intrinsicGroups.first;
-        const auto & groupedViews = intrinsicGroups.second;
+        const auto& groupedViews = intrinsicGroups.second;
 
         std::vector<std::map<int, luminanceInfo>> v_luminanceInfos;
         std::vector<std::vector<hdr::ImageSample>> calibrationSamples;
@@ -359,7 +358,7 @@ int aliceVision_main(int argc, char** argv)
                     if (luminanceInfos.find(v->getViewId()) == luminanceInfos.end())
                     {
                         luminanceInfo lumaInfo;
-                        lumaInfo.exposure = -1.0; // Dummy exposure used later indicating a dummy info
+                        lumaInfo.exposure = -1.0;  // Dummy exposure used later indicating a dummy info
                         luminanceInfos[v->getViewId()] = lumaInfo;
                     }
                 }
@@ -428,15 +427,15 @@ int aliceVision_main(int argc, char** argv)
                 {
                     switch (calibrationMethod)
                     {
-                    case ECalibrationMethod::DEBEVEC:
-                        calibrationWeightFunction = hdr::EFunctionType_enumToString(hdr::EFunctionType::TRIANGLE);
-                        break;
-                    case ECalibrationMethod::LINEAR:
-                    case ECalibrationMethod::GROSSBERG:
-                    case ECalibrationMethod::LAGUERRE:
-                    default:
-                        calibrationWeightFunction = hdr::EFunctionType_enumToString(hdr::EFunctionType::GAUSSIAN);
-                        break;
+                        case ECalibrationMethod::DEBEVEC:
+                            calibrationWeightFunction = hdr::EFunctionType_enumToString(hdr::EFunctionType::TRIANGLE);
+                            break;
+                        case ECalibrationMethod::LINEAR:
+                        case ECalibrationMethod::GROSSBERG:
+                        case ECalibrationMethod::LAGUERRE:
+                        default:
+                            calibrationWeightFunction = hdr::EFunctionType_enumToString(hdr::EFunctionType::GAUSSIAN);
+                            break;
                     }
                 }
                 calibrationWeight.setFunction(hdr::EFunctionType_stringToEnum(calibrationWeightFunction));
@@ -450,47 +449,48 @@ int aliceVision_main(int argc, char** argv)
 
             switch (calibrationMethod)
             {
-            case ECalibrationMethod::LINEAR:
-            {
-                // Set the response function to linear
-                response.setLinear();
-                break;
-            }
-            case ECalibrationMethod::DEBEVEC:
-            {
-                hdr::DebevecCalibrate debevec;
-                const float lambda = channelQuantization;
-                bool res = debevec.process(calibrationSamples, groupedExposures, channelQuantization, calibrationWeight, lambda, response);
-                if (!res) {
-                    ALICEVISION_LOG_ERROR("Calibration failed.");
+                case ECalibrationMethod::LINEAR:
+                {
+                    // Set the response function to linear
+                    response.setLinear();
+                    break;
+                }
+                case ECalibrationMethod::DEBEVEC:
+                {
+                    hdr::DebevecCalibrate debevec;
+                    const float lambda = channelQuantization;
+                    bool res = debevec.process(calibrationSamples, groupedExposures, channelQuantization, calibrationWeight, lambda, response);
+                    if (!res)
+                    {
+                        ALICEVISION_LOG_ERROR("Calibration failed.");
+                        return EXIT_FAILURE;
+                    }
+
+                    response.exponential();
+                    response.scale();
+                    break;
+                }
+                case ECalibrationMethod::GROSSBERG:
+                {
+                    hdr::GrossbergCalibrate calibration(5);
+                    calibration.process(calibrationSamples, groupedExposures, channelQuantization, response);
+                    break;
+                }
+                case ECalibrationMethod::LAGUERRE:
+                {
+                    hdr::LaguerreBACalibration calibration;
+                    calibration.process(calibrationSamples, groupedExposures, channelQuantization, false, response);
+                    break;
+                }
+                case ECalibrationMethod::AUTO:
+                {
+                    ALICEVISION_LOG_ERROR("The calibration method cannot be automatically selected.");
                     return EXIT_FAILURE;
                 }
-
-                response.exponential();
-                response.scale();
-                break;
-            }
-            case ECalibrationMethod::GROSSBERG:
-            {
-                hdr::GrossbergCalibrate calibration(5);
-                calibration.process(calibrationSamples, groupedExposures, channelQuantization, response);
-                break;
-            }
-            case ECalibrationMethod::LAGUERRE:
-            {
-                hdr::LaguerreBACalibration calibration;
-                calibration.process(calibrationSamples, groupedExposures, channelQuantization, false, response);
-                break;
-            }
-            case ECalibrationMethod::AUTO:
-            {
-                ALICEVISION_LOG_ERROR("The calibration method cannot be automatically selected.");
-                return EXIT_FAILURE;
-            }
             }
 
             const std::string methodName = ECalibrationMethod_enumToString(calibrationMethod);
-            
+
             const std::string baseName = (fs::path(outputResponsePath).parent_path() / std::string("response_")).string();
             const std::string intrinsicName = baseName + std::to_string(intrinsicId);
             const std::string htmlName = intrinsicName + "_" + methodName + std::string(".html");
@@ -500,7 +500,8 @@ int aliceVision_main(int argc, char** argv)
         }
 
         const std::string lumastatBasename = "luminanceStatistics";
-        const std::string lumastatFilename = (fs::path(outputResponsePath).parent_path() / (lumastatBasename + "_" + std::to_string(intrinsicId) + ".txt")).string();
+        const std::string lumastatFilename =
+          (fs::path(outputResponsePath).parent_path() / (lumastatBasename + "_" + std::to_string(intrinsicId) + ".txt")).string();
         std::ofstream file(lumastatFilename);
         if (!file)
         {
@@ -531,7 +532,8 @@ int aliceVision_main(int argc, char** argv)
                     }
                     // write in file
                     file << srcIdWithMinimalExposure << " ";
-                    file << v_luminanceInfos[i][srcIdWithMinimalExposure].exposure << " " << v_luminanceInfos[i][srcIdWithMinimalExposure].itemNb << " ";
+                    file << v_luminanceInfos[i][srcIdWithMinimalExposure].exposure << " " << v_luminanceInfos[i][srcIdWithMinimalExposure].itemNb
+                         << " ";
                     if (v_luminanceInfos[i][srcIdWithMinimalExposure].itemNb > 0)
                     {
                         file << v_luminanceInfos[i][srcIdWithMinimalExposure].meanLum / v_luminanceInfos[i][srcIdWithMinimalExposure].itemNb << " ";
@@ -540,7 +542,8 @@ int aliceVision_main(int argc, char** argv)
                     {
                         file << "0.0 ";
                     }
-                    file << v_luminanceInfos[i][srcIdWithMinimalExposure].minLum << " " << v_luminanceInfos[i][srcIdWithMinimalExposure].maxLum << std::endl;
+                    file << v_luminanceInfos[i][srcIdWithMinimalExposure].minLum << " " << v_luminanceInfos[i][srcIdWithMinimalExposure].maxLum
+                         << std::endl;
                     // erase from map
                     v_luminanceInfos[i].erase(srcIdWithMinimalExposure);
                 }
