@@ -7,7 +7,10 @@
 #include <aliceVision/sfmData/SfMData.hpp>
 #include <aliceVision/sfmDataIO/sfmDataIO.hpp>
 
-#include <aliceVision/image/all.hpp>
+#include <aliceVision/image/Image.hpp>
+#include <aliceVision/image/conversionOpenCV.hpp>
+#include <aliceVision/image/io.hpp>
+
 #include <aliceVision/cmdline/cmdline.hpp>
 #include <aliceVision/system/main.hpp>
 #include <aliceVision/config.hpp>
@@ -20,6 +23,7 @@
 #include <boost/program_options.hpp>
 #include <boost/property_tree/ptree.hpp>
 #include <boost/property_tree/json_parser.hpp>
+#include <boost/regex.hpp>
 
 #include <opencv2/core.hpp>
 #include <opencv2/imgproc/imgproc.hpp>
@@ -33,26 +37,86 @@
 
 // These constants define the current software version.
 // They must be updated when the command line is changed.
-#define ALICEVISION_SOFTWARE_VERSION_MAJOR 1
+#define ALICEVISION_SOFTWARE_VERSION_MAJOR 2
 #define ALICEVISION_SOFTWARE_VERSION_MINOR 0
 
 using namespace aliceVision;
 
-namespace fs = boost::filesystem;
+namespace fs = std::filesystem;
 namespace bpt = boost::property_tree;
 namespace po = boost::program_options;
 
-// Match values used in OpenCV MCC
-// See https://github.com/opencv/opencv_contrib/blob/342f8924cca88fe6ce979024b7776f6815c89978/modules/mcc/src/dictionary.hpp#L72
-const std::vector< cv::Point2f > MACBETH_CCHART_CORNERS_POS = {
-    {0.f, 0.f}, {1675.f, 0.f}, {1675.f, 1125.f}, {0.f, 1125.f},
+enum class ECCType
+{
+    MCC24,
+    SG140,
+    VINYL18
 };
 
-const std::vector< cv::Point2f > MACBETH_CCHART_CELLS_POS_CENTER =  {
-    {150.f, 150.f}, {425.f, 150.f}, {700.f, 150.f}, {975.f, 150.f}, {1250.f, 150.f}, {1525.f, 150.f},
-    {150.f, 425.f}, {425.f, 425.f}, {700.f, 425.f}, {975.f, 425.f}, {1250.f, 425.f}, {1525.f, 425.f},
-    {150.f, 700.f}, {425.f, 700.f}, {700.f, 700.f}, {975.f, 700.f}, {1250.f, 700.f}, {1525.f, 700.f},
-    {150.f, 975.f}, {425.f, 975.f}, {700.f, 975.f}, {975.f, 975.f}, {1250.f, 975.f}, {1525.f, 975.f}
+inline std::string ECCType_enumToString(ECCType ccType)
+{
+    switch (ccType)
+    {
+        case ECCType::MCC24:
+            return "mcc24";
+        case ECCType::SG140:
+            return "sg140";
+        case ECCType::VINYL18:
+            return "vinyl18";
+    }
+    throw std::invalid_argument("Invalid openCV color checker type enum");
+}
+
+inline ECCType ECCType_stringToEnum(std::string ccType)
+{
+    boost::to_lower(ccType);
+    if (ccType == "mcc24")
+        return ECCType::MCC24;
+    if (ccType == "sg140")
+        return ECCType::SG140;
+    if (ccType == "vinyl18")
+        return ECCType::VINYL18;
+
+    throw std::invalid_argument("Unrecognized color checker type '" + ccType + "'");
+}
+
+inline std::ostream& operator<<(std::ostream& os, ECCType e) { return os << ECCType_enumToString(e); }
+
+inline std::istream& operator>>(std::istream& in, ECCType& e)
+{
+    std::string token;
+    in >> token;
+    e = ECCType_stringToEnum(token);
+    return in;
+}
+
+inline cv::mcc::TYPECHART ECCType_to_OpenCVECCType(ECCType ccType)
+{
+    switch (ccType)
+    {
+        case ECCType::MCC24:
+            return cv::mcc::TYPECHART::MCC24;
+        case ECCType::SG140:
+            return cv::mcc::TYPECHART::SG140;
+        case ECCType::VINYL18:
+            return cv::mcc::TYPECHART::VINYL18;
+    }
+    throw std::invalid_argument("Invalid openCV color checker type enum");
+}
+
+// Match values used in OpenCV MCC
+// See https://github.com/opencv/opencv_contrib/blob/342f8924cca88fe6ce979024b7776f6815c89978/modules/mcc/src/dictionary.hpp#L72
+const std::vector<cv::Point2f> MACBETH_CCHART_CORNERS_POS = {
+    {0.f, 0.f},
+    {1675.f, 0.f},
+    {1675.f, 1125.f},
+    {0.f, 1125.f},
+};
+
+const std::vector<cv::Point2f> MACBETH_CCHART_CELLS_POS_CENTER = {
+    {150.f, 150.f},  {425.f, 150.f},  {700.f, 150.f},  {975.f, 150.f},  {1250.f, 150.f}, {1525.f, 150.f}, {150.f, 425.f},  {425.f, 425.f},
+    {700.f, 425.f},  {975.f, 425.f},  {1250.f, 425.f}, {1525.f, 425.f}, {150.f, 700.f},  {425.f, 700.f},  {700.f, 700.f},  {975.f, 700.f},
+    {1250.f, 700.f}, {1525.f, 700.f}, {150.f, 975.f},  {425.f, 975.f},  {700.f, 975.f},  {975.f, 975.f},  {1250.f, 975.f}, {1525.f, 975.f}
 };
 
 const float MACBETH_CCHART_CELLS_SIZE = 250.f * .5f;
@@ -71,12 +135,12 @@ struct QuadSVG
             ALICEVISION_LOG_ERROR("Invalid color checker box: size is not equal to 4");
             exit(EXIT_FAILURE);
         }
-        for(const auto& p : points)
+        for (const auto& p : points)
         {
             xCoords.push_back(p.x);
             yCoords.push_back(p.y);
         }
-        // close polyline
+        // Close polyline
         xCoords.push_back(points[0].x);
         yCoords.push_back(points[0].y);
     }
@@ -93,24 +157,24 @@ struct QuadSVG
     }
 };
 
-void drawSVG(const cv::Ptr<cv::mcc::CChecker> &checker, const std::string& outputPath)
+void drawSVG(const cv::Ptr<cv::mcc::CChecker>& checker, const std::string& outputPath)
 {
-    std::vector< QuadSVG > quadsToDraw;
+    std::vector<QuadSVG> quadsToDraw;
 
     // Push back the quad representing the color checker
-    quadsToDraw.push_back( QuadSVG(checker->getBox()) );
+    quadsToDraw.push_back(QuadSVG(checker->getBox()));
 
     // Transform matrix from 'theoric' to 'measured'
-    cv::Matx33f tMatrix = cv::getPerspectiveTransform(MACBETH_CCHART_CORNERS_POS,checker->getBox());
+    cv::Matx33f tMatrix = cv::getPerspectiveTransform(MACBETH_CCHART_CORNERS_POS, checker->getBox());
 
     // Push back quads representing color checker cells
     for (const auto& center : MACBETH_CCHART_CELLS_POS_CENTER)
     {
         QuadSVG quad({
-            cv::Point2f( center.x - MACBETH_CCHART_CELLS_SIZE * .5, center.y - MACBETH_CCHART_CELLS_SIZE * .5 ),
-            cv::Point2f( center.x + MACBETH_CCHART_CELLS_SIZE * .5, center.y - MACBETH_CCHART_CELLS_SIZE * .5 ),
-            cv::Point2f( center.x + MACBETH_CCHART_CELLS_SIZE * .5, center.y + MACBETH_CCHART_CELLS_SIZE * .5 ),
-            cv::Point2f( center.x - MACBETH_CCHART_CELLS_SIZE * .5, center.y + MACBETH_CCHART_CELLS_SIZE * .5 ),
+          cv::Point2f(center.x - MACBETH_CCHART_CELLS_SIZE * .5, center.y - MACBETH_CCHART_CELLS_SIZE * .5),
+          cv::Point2f(center.x + MACBETH_CCHART_CELLS_SIZE * .5, center.y - MACBETH_CCHART_CELLS_SIZE * .5),
+          cv::Point2f(center.x + MACBETH_CCHART_CELLS_SIZE * .5, center.y + MACBETH_CCHART_CELLS_SIZE * .5),
+          cv::Point2f(center.x - MACBETH_CCHART_CELLS_SIZE * .5, center.y + MACBETH_CCHART_CELLS_SIZE * .5),
         });
         quad.transform(tMatrix);
         quadsToDraw.push_back(quad);
@@ -119,10 +183,7 @@ void drawSVG(const cv::Ptr<cv::mcc::CChecker> &checker, const std::string& outpu
     svg::svgDrawer svgSurface;
     for (const auto& quad : quadsToDraw)
     {
-        svgSurface.drawPolyline(
-            quad.xCoords.begin(), quad.xCoords.end(),
-            quad.yCoords.begin(), quad.yCoords.end(),
-            svg::svgStyle().stroke("red", 2));
+        svgSurface.drawPolyline(quad.xCoords.begin(), quad.xCoords.end(), quad.yCoords.begin(), quad.yCoords.end(), svg::svgStyle().stroke("red", 2));
     }
 
     std::ofstream svgFile(outputPath);
@@ -130,8 +191,8 @@ void drawSVG(const cv::Ptr<cv::mcc::CChecker> &checker, const std::string& outpu
     svgFile.close();
 }
 
-
-struct ImageOptions {
+struct ImageOptions
+{
     fs::path imgFsPath;
     std::string viewId;
     std::string lensSerialNumber;
@@ -139,15 +200,14 @@ struct ImageOptions {
     image::ImageReadOptions readOptions;
 };
 
-
-struct CCheckerDetectionSettings {
+struct CCheckerDetectionSettings
+{
     cv::mcc::TYPECHART typechart;
     unsigned int maxCountByImage;
     std::string outputData;
     bool debug;
 };
 
-
 struct Quad
 {
     struct BoundingBox
@@ -156,8 +216,8 @@ struct Quad
         cv::Point2f max;
 
         BoundingBox()
-            : min(cv::Point2f(std::numeric_limits<double>::infinity(), std::numeric_limits<double>::infinity()))
-            , max(cv::Point2f(0.f, 0.f))
+          : min(cv::Point2f(std::numeric_limits<double>::infinity(), std::numeric_limits<double>::infinity())),
+            max(cv::Point2f(0.f, 0.f))
         {}
 
         float sizeX() const { return max.x - min.x; }
@@ -166,52 +226,52 @@ struct Quad
         bool contains(cv::Point2f p) const { return contains(p.x, p.y); }
     };
 
-    std::vector< cv::Point > _corners;
+    std::vector<cv::Point> _corners;
     BoundingBox _bbox;
 
     Quad() = default;
 
     Quad(const std::vector<cv::Point2f>& corners)
     {
-        if(corners.size() != 4)
+        if (corners.size() != 4)
         {
             ALICEVISION_LOG_ERROR("Invalid points count, expected 4.");
             exit(EXIT_FAILURE);
         }
 
-        for(const auto& c : corners)
+        for (const auto& c : corners)
             _corners.push_back(c);
         updateBBox();
     }
 
     Quad(cv::Point2f center, float halfHeight, float halfWidth)
-        : _corners( std::vector< cv::Point >(4) )
+      : _corners(std::vector<cv::Point>(4))
     {
-        _corners[0] = cv::Point2f( center.x - halfWidth, center.y - halfHeight );
-        _corners[1] = cv::Point2f( center.x + halfWidth, center.y - halfHeight );
-        _corners[2] = cv::Point2f( center.x + halfWidth, center.y + halfHeight );
-        _corners[3] = cv::Point2f( center.x - halfWidth, center.y + halfHeight );
+        _corners[0] = cv::Point2f(center.x - halfWidth, center.y - halfHeight);
+        _corners[1] = cv::Point2f(center.x + halfWidth, center.y - halfHeight);
+        _corners[2] = cv::Point2f(center.x + halfWidth, center.y + halfHeight);
+        _corners[3] = cv::Point2f(center.x - halfWidth, center.y + halfHeight);
         updateBBox();
     }
 
     void updateBBox()
     {
-        for(auto const &c : _corners)
+        for (auto const& c : _corners)
         {
-            if(c.x < _bbox.min.x)
+            if (c.x < _bbox.min.x)
                 _bbox.min.x = c.x;
-            if(c.y < _bbox.min.y)
+            if (c.y < _bbox.min.y)
                 _bbox.min.y = c.y;
-            if(c.x > _bbox.max.x)
+            if (c.x > _bbox.max.x)
                 _bbox.max.x = c.x;
-            if(c.y > _bbox.max.y)
+            if (c.y > _bbox.max.y)
                 _bbox.max.y = c.y;
         }
     }
 
     void transform(const cv::Matx33f& transformMatrix)
     {
-        for (auto &c : _corners)
+        for (auto& c : _corners)
         {
             cv::Point3f p(c.x, c.y, 1.);
             p = transformMatrix * p;
@@ -222,7 +282,7 @@ struct Quad
 
     void translate(float dx, float dy)
     {
-        for (auto &c : _corners)
+        for (auto& c : _corners)
         {
             c.x += dx;
             c.y += dy;
@@ -230,37 +290,32 @@ struct Quad
     }
 };
 
-
-struct MacbethCCheckerQuad : Quad {
+struct MacbethCCheckerQuad : Quad
+{
     cv::Ptr<cv::mcc::CChecker> _cchecker;
     cv::Mat _colorData;
     cv::Mat _transformMat;
-    std::vector< cv::Mat > _cellMasks;
+    std::vector<cv::Mat> _cellMasks;
     ImageOptions _imgOpt;
 
     MacbethCCheckerQuad() = default;
 
-    MacbethCCheckerQuad(
-        cv::Ptr<cv::mcc::CChecker> cchecker,
-        const image::Image<image::RGBAfColor> &img,
-        const ImageOptions& imgOpt)
-        : Quad(cchecker->getBox())
-        , _cchecker(cchecker)
-        , _imgOpt(imgOpt)
-        , _cellMasks(std::vector< cv::Mat >(24))
+    MacbethCCheckerQuad(cv::Ptr<cv::mcc::CChecker> cchecker, const image::Image<image::RGBAfColor>& img, const ImageOptions& imgOpt)
+      : Quad(cchecker->getBox()),
+        _cchecker(cchecker),
+        _imgOpt(imgOpt),
+        _cellMasks(std::vector<cv::Mat>(24))
     {
         // Transform matrix from 'theoric' to 'measured'
         _transformMat = cv::getPerspectiveTransform(MACBETH_CCHART_CORNERS_POS, _cchecker->getBox());
 
         // Create an image boolean mask for each cchecker cell
-        for(int i = 0; i < _cellMasks.size(); ++i)
+        for (int i = 0; i < _cellMasks.size(); ++i)
         {
             _cellMasks[i] = cv::Mat::zeros(_bbox.sizeY(), _bbox.sizeX(), CV_8UC1);
-            Quad q(MACBETH_CCHART_CELLS_POS_CENTER[i],
-                   MACBETH_CCHART_CELLS_SIZE * .5,
-                   MACBETH_CCHART_CELLS_SIZE * .5);
+            Quad q(MACBETH_CCHART_CELLS_POS_CENTER[i], MACBETH_CCHART_CELLS_SIZE * .5, MACBETH_CCHART_CELLS_SIZE * .5);
             q.transform(_transformMat);
-            q.translate(- _bbox.min.x, - _bbox.min.y);
+            q.translate(-_bbox.min.x, -_bbox.min.y);
             cv::fillConvexPoly(_cellMasks[i], q._corners.data(), 4, cv::Scalar(255));
         }
 
@@ -268,25 +323,28 @@ struct MacbethCCheckerQuad : Quad {
         _colorData = cv::Mat::zeros(24, 1, CV_64FC3);
         cv::Mat pixelsCount = cv::Mat::zeros(24, 1, CV_32S);
 
-        for(int y = 0; y < (int) _bbox.sizeY(); ++y)
+        for (int y = 0; y < static_cast<int>(_bbox.sizeY()); ++y)
         {
-            for(int x = 0; x < (int) _bbox.sizeX(); ++x)
+            for (int x = 0; x < static_cast<int>(_bbox.sizeX()); ++x)
             {
-                for(int i = 0; i < _cellMasks.size(); ++i)
+                for (int i = 0; i < static_cast<int>(_cellMasks.size()); ++i)
                 {
+                    const int coordX = x + _bbox.min.x;
+                    const int coordY = y + _bbox.min.y;
+
                     // Check current pixel for the current image mask
-                    if(_cellMasks[i].at<uchar>(y,x) == 255)
+                    if (_cellMasks[i].at<uchar>(y, x) == 255 && coordX >= 0 && coordX < img.width() && coordY >= 0 && coordY < img.height())
                     {
-                        const image::RGBAfColor& px = img(y + _bbox.min.y, x + _bbox.min.x);
-                        _colorData.at< cv::Vec3d >(i,0) += cv::Vec3d(px.r(), px.g(), px.b());
+                        const image::RGBAfColor& px = img(coordY, coordX);
+                        _colorData.at<cv::Vec3d>(i, 0) += cv::Vec3d(px.r(), px.g(), px.b());
                         ++pixelsCount.at<int>(i);
                     }
                 }
             }
         }
 
-        for(int i = 0; i < _colorData.rows; ++i)
-            _colorData.at<cv::Vec3d>(i, 0) /= pixelsCount.at<int>(i); // average value
+        for (int i = 0; i < _colorData.rows; ++i)
+            _colorData.at<cv::Vec3d>(i, 0) /= pixelsCount.at<int>(i);  // average value
     }
 
     bpt::ptree ptree() const
@@ -304,7 +362,7 @@ struct MacbethCCheckerQuad : Quad {
             bpt::ptree ptPoint;
             ptPoint.put("x", point.x);
             ptPoint.put("y", point.y);
-            ptPositions.push_back( std::make_pair("", ptPoint) );
+            ptPositions.push_back(std::make_pair("", ptPoint));
         }
         pt.add_child("positions", ptPositions);
 
@@ -312,13 +370,13 @@ struct MacbethCCheckerQuad : Quad {
         for (int i = 0; i < _transformMat.rows; ++i)
         {
             bpt::ptree row;
-            for(int j = 0; j < _transformMat.cols; ++j)
+            for (int j = 0; j < _transformMat.cols; ++j)
             {
                 bpt::ptree cell;
                 cell.put_value(_transformMat.at<double>(i, j));
                 row.push_back(std::make_pair("", cell));
             }
-            ptTransform.push_back( std::make_pair("", row) );
+            ptTransform.push_back(std::make_pair("", row));
         }
         pt.add_child("transform", ptTransform);
 
@@ -326,10 +384,10 @@ struct MacbethCCheckerQuad : Quad {
         for (int i = 0; i < _colorData.rows; ++i)
         {
             bpt::ptree ptColor;
-            ptColor.put("r", _colorData.at<cv::Vec3d>(i,0)[0]);
-            ptColor.put("g", _colorData.at<cv::Vec3d>(i,0)[1]);
-            ptColor.put("b", _colorData.at<cv::Vec3d>(i,0)[2]);
-            ptColors.push_back( std::make_pair("", ptColor) );
+            ptColor.put("r", _colorData.at<cv::Vec3d>(i, 0)[0]);
+            ptColor.put("g", _colorData.at<cv::Vec3d>(i, 0)[1]);
+            ptColor.put("b", _colorData.at<cv::Vec3d>(i, 0)[2]);
+            ptColors.push_back(std::make_pair("", ptColor));
         }
         pt.add_child("colors", ptColors);
 
@@ -337,11 +395,10 @@ struct MacbethCCheckerQuad : Quad {
     }
 };
 
-
-void detectColorChecker(
-    std::vector<MacbethCCheckerQuad> &detectedCCheckers,
-    ImageOptions& imgOpt,
-    CCheckerDetectionSettings &settings)
+void detectColorChecker(std::vector<MacbethCCheckerQuad>& detectedCCheckers,
+                        ImageOptions& imgOpt,
+                        CCheckerDetectionSettings& settings,
+                        cv::Ptr<cv::mcc::CCheckerDetector> cnnDetector = nullptr)
 {
     const std::string outputFolder = fs::path(settings.outputData).parent_path().string() + "/";
     const std::string imgSrcPath = imgOpt.imgFsPath.string();
@@ -353,15 +410,24 @@ void detectColorChecker(
     image::readImage(imgSrcPath, img, imgOpt.readOptions);
     cv::Mat imgBGR = image::imageRGBAToCvMatBGR(img, CV_8UC3);
 
-    if(imgBGR.cols == 0 || imgBGR.rows == 0)
+    if (imgBGR.cols == 0 || imgBGR.rows == 0)
     {
         ALICEVISION_LOG_ERROR("Image at: '" << imgSrcPath << "'.\n" << "is empty.");
         exit(EXIT_FAILURE);
     }
 
-    cv::Ptr<cv::mcc::CCheckerDetector> detector = cv::mcc::CCheckerDetector::create();
+    cv::Ptr<cv::mcc::CCheckerDetector> detector;
 
-    if(!detector->process(imgBGR, settings.typechart, settings.maxCountByImage))
+    if (cnnDetector != nullptr)
+    {
+        detector = cnnDetector;
+    }
+    else
+    {
+        detector = cv::mcc::CCheckerDetector::create();
+    }
+
+    if (!detector->process(imgBGR, settings.typechart, settings.maxCountByImage, cnnDetector != nullptr))
     {
         ALICEVISION_LOG_INFO("Checker not detected in image at: '" << imgSrcPath << "'");
         return;
@@ -369,16 +435,16 @@ void detectColorChecker(
 
     int counter = 0;
 
-    for(const cv::Ptr<cv::mcc::CChecker> cchecker : detector->getListColorChecker())
+    for (const cv::Ptr<cv::mcc::CChecker> cchecker : detector->getListColorChecker())
     {
         const std::string counterStr = "_" + std::to_string(++counter);
 
-        ALICEVISION_LOG_INFO("Checker #" << counter <<" successfully detected in '" << imgSrcStem << "'");
+        ALICEVISION_LOG_INFO("Checker #" << counter << " successfully detected in '" << imgSrcStem << "'");
 
         MacbethCCheckerQuad ccq(cchecker, img, imgOpt);
         detectedCCheckers.push_back(ccq);
-        
-        if(settings.debug)
+
+        if (settings.debug)
         {
             // Output debug data
             drawSVG(cchecker, outputFolder + imgDestStem + counterStr + ".svg");
@@ -396,7 +462,6 @@ void detectColorChecker(
     }
 }
 
-
 int aliceVision_main(int argc, char** argv)
 {
     // command-line parameters
@@ -406,20 +471,34 @@ int aliceVision_main(int argc, char** argv)
     // user optional parameters
     bool debug = false;
     unsigned int maxCountByImage = 1;
+    bool processAllImages = true;
+    std::string filter = "*_macbeth.*";
+    std::string modelFolder = "";
+    ECCType ccType = ECCType::MCC24;
 
+    // clang-format off
     po::options_description inputParams("Required parameters");
     inputParams.add_options()
         ("input,i", po::value<std::string>(&inputExpression)->required(),
-         "SfMData file input, image filenames or regex(es) on the image file path (supported regex: '#' matches a single digit, '@' one or more digits, '?' one character and '*' zero or more).")
+         "SfMData file input, image filenames or regex(es) on the image file path "
+         "(supported regex: '#' matches a single digit, '@' one or more digits, '?' one character and '*' zero or more).")
         ("outputData", po::value<std::string>(&outputData)->required(),
          "Output path for the color checker data.");
 
     po::options_description optionalParams("Optional parameters");
     optionalParams.add_options()
-        ("debug", po::value<bool>(&debug),
-         "Output debug data.")
+        ("debug", po::value<bool>(&debug), "Output debug data.")
+        ("processAllImages", po::value<bool>(&processAllImages)->default_value(processAllImages),
+         "If True, process all available images.")
+        ("filter", po::value<std::string>(&filter)->default_value(filter),
+         "Regular expression to select images to be processed.")
+        ("modelFolder", po::value<std::string>(&modelFolder)->default_value(modelFolder),
+         "Path to folder containing a cnn model.")
         ("maxCount", po::value<unsigned int>(&maxCountByImage),
-         "Maximum color charts count to detect in a single image.");
+         "Maximum color charts count to detect in a single image.")
+        ("ccType", po::value<ECCType>(&ccType)->default_value(ccType),
+         "Color chart type: mcc24 (Classical macbeth 24 patches), sg140 (Digital SG 140 patches), vinyl18 (DKK colorchart 12 patches + 6 rectangles).");
+    // clang-format on
 
     CmdLine cmdline("This program is used to perform Macbeth color checker chart detection.\n"
                     "AliceVision colorCheckerDetection");
@@ -431,21 +510,45 @@ int aliceVision_main(int argc, char** argv)
     }
 
     CCheckerDetectionSettings settings;
-    settings.typechart = cv::mcc::TYPECHART::MCC24;
+    settings.typechart = ECCType_to_OpenCVECCType(ccType);
     settings.maxCountByImage = maxCountByImage;
     settings.outputData = outputData;
     settings.debug = debug;
 
-    std::vector< MacbethCCheckerQuad > detectedCCheckers;
+    std::vector<MacbethCCheckerQuad> detectedCCheckers;
+
+    cv::Ptr<cv::mcc::CCheckerDetector> detectorCNN = nullptr;
+
+    const std::string modelPath = modelFolder + "/frozen_inference_graph.pb";
+    const std::string pbtxtPath = modelFolder + "/graph.pbtxt";
+
+    if (fs::exists(fs::path(modelPath)) && fs::exists(fs::path(pbtxtPath)))
+    {
+        cv::dnn::Net net = cv::dnn::readNetFromTensorflow(modelPath, pbtxtPath);
+
+        net.setPreferableBackend(cv::dnn::DNN_BACKEND_CUDA);
+        net.setPreferableTarget(cv::dnn::DNN_TARGET_CUDA);
+
+        detectorCNN = cv::mcc::CCheckerDetector::create();
+        if (!detectorCNN->setNet(net))
+        {
+            ALICEVISION_LOG_INFO("Loading Model failed: Aborting");
+            detectorCNN = nullptr;
+        }
+        else
+        {
+            ALICEVISION_LOG_INFO("Loading Model OK");
+        }
+    }
 
     // Check if inputExpression is recognized as sfm data file
     const std::string inputExt = boost::to_lower_copy(fs::path(inputExpression).extension().string());
     static const std::array<std::string, 2> sfmSupportedExtensions = {".sfm", ".abc"};
-    if(std::find(sfmSupportedExtensions.begin(), sfmSupportedExtensions.end(), inputExt) != sfmSupportedExtensions.end())
+    if (std::find(sfmSupportedExtensions.begin(), sfmSupportedExtensions.end(), inputExt) != sfmSupportedExtensions.end())
     {
-        // load input as sfm data file
+        // Load input as SfMData file
         sfmData::SfMData sfmData;
-        if (!sfmDataIO::Load(sfmData, inputExpression, sfmDataIO::ESfMData(sfmDataIO::VIEWS)))
+        if (!sfmDataIO::load(sfmData, inputExpression, sfmDataIO::ESfMData(sfmDataIO::VIEWS)))
         {
             ALICEVISION_LOG_ERROR("The input SfMData file '" << inputExpression << "' cannot be read.");
             return EXIT_FAILURE;
@@ -454,48 +557,51 @@ int aliceVision_main(int argc, char** argv)
         int counter = 0;
 
         // Detect color checker for each images
-        for(const auto& viewIt : sfmData.getViews())
+        for (const auto& viewIt : sfmData.getViews())
         {
             const sfmData::View& view = *(viewIt.second);
 
-            ALICEVISION_LOG_INFO(++counter << "/" << sfmData.getViews().size() << " - Process image at: '" << view.getImage().getImagePath() << "'.");
-            ImageOptions imgOpt = {
-                view.getImage().getImagePath(),
-                std::to_string(view.getViewId()),
-                view.getImage().getMetadataBodySerialNumber(),
-                view.getImage().getMetadataLensSerialNumber() };
-            imgOpt.readOptions.workingColorSpace = image::EImageColorSpace::SRGB;
-            imgOpt.readOptions.rawColorInterpretation = image::ERawColorInterpretation_stringToEnum(view.getImage().getRawColorInterpretation());
-            detectColorChecker(detectedCCheckers, imgOpt, settings);
+            boost::filesystem::path p(view.getImage().getImagePath());
+            const std::regex regex = utils::filterToRegex(filter);
+            if (processAllImages || std::regex_match(p.generic_string(), regex))
+            {
+                ALICEVISION_LOG_INFO(++counter << "/" << sfmData.getViews().size() << " - Process image at: '" << view.getImage().getImagePath()
+                                               << "'.");
+                ImageOptions imgOpt = {view.getImage().getImagePath(),
+                                       std::to_string(view.getViewId()),
+                                       view.getImage().getMetadataBodySerialNumber(),
+                                       view.getImage().getMetadataLensSerialNumber()};
+                imgOpt.readOptions.workingColorSpace = image::EImageColorSpace::SRGB;
+                imgOpt.readOptions.rawColorInterpretation = image::ERawColorInterpretation_stringToEnum(view.getImage().getRawColorInterpretation());
+                detectColorChecker(detectedCCheckers, imgOpt, settings, detectorCNN);
+            }
         }
-
     }
     else
     {
-        // load input as image file or image folder
+        // Load input as image file or image folder
         const fs::path inputPath(inputExpression);
         std::vector<std::string> filesStrPaths;
 
-        if(fs::is_regular_file(inputPath))
+        if (fs::is_regular_file(inputPath))
         {
             filesStrPaths.push_back(inputPath.string());
         }
         else
         {
-            ALICEVISION_LOG_INFO("Working directory Path '" + inputPath.parent_path().generic_string() + "'.");
+            ALICEVISION_LOG_INFO("Working directory Path '" + inputPath.generic_string() + "'.");
 
-            const std::regex regex = utils::filterToRegex(inputExpression);
+            const std::regex regex = utils::filterToRegex(processAllImages ? "" : filter);
             // Get supported files in inputPath directory which matches our regex filter
-            filesStrPaths = utils::getFilesPathsFromFolder(inputPath.parent_path().generic_string(),
-               [&regex](const boost::filesystem::path& path) {
-                 return image::isSupported(path.extension().string()) && std::regex_match(path.generic_string(), regex);
-               }
-            );
+            filesStrPaths = utils::getFilesPathsFromFolder(inputPath.generic_string(), [&regex](const fs::path& path) {
+                ALICEVISION_LOG_INFO(path);
+                return image::isSupported(path.extension().string()) && std::regex_match(path.generic_string(), regex);
+            });
         }
 
         const int size = filesStrPaths.size();
 
-        if(!size)
+        if (!size)
         {
             ALICEVISION_LOG_ERROR("Any images was found.");
             ALICEVISION_LOG_ERROR("Input folders or input expression '" << inputExpression << "' may be incorrect ?");
@@ -507,15 +613,19 @@ int aliceVision_main(int argc, char** argv)
         }
 
         int counter = 0;
-        for(const std::string& imgSrcPath : filesStrPaths)
+        for (const std::string& imgSrcPath : filesStrPaths)
         {
-            ALICEVISION_LOG_INFO(++counter << "/" << size << " - Process image at: '" << imgSrcPath << "'.");
-            ImageOptions imgOpt;
-            imgOpt.imgFsPath = imgSrcPath;
-            imgOpt.readOptions.workingColorSpace = image::EImageColorSpace::SRGB;
-            detectColorChecker(detectedCCheckers, imgOpt, settings);
+            boost::filesystem::path p(imgSrcPath);
+            const std::regex regex = utils::filterToRegex(filter);
+            if (processAllImages || std::regex_match(p.generic_string(), regex))
+            {
+                ALICEVISION_LOG_INFO(++counter << "/" << size << " - Process image at: '" << imgSrcPath << "'.");
+                ImageOptions imgOpt;
+                imgOpt.imgFsPath = imgSrcPath;
+                imgOpt.readOptions.workingColorSpace = image::EImageColorSpace::SRGB;
+                detectColorChecker(detectedCCheckers, imgOpt, settings, detectorCNN);
+            }
         }
-
     }
 
     if (detectedCCheckers.empty())
